<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'бӯса: калонсол, калонсол, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'бӯса: калонсол, калонсол, ранги равшани пӯст, ранги миёнаи пӯст',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'бӯса: калонсол, калонсол, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'бӯса: калонсол, калонсол, ранги равшани пӯст, ранги торики пӯст',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'бӯса: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'бӯса: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'бӯса: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'бӯса: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'бӯса: калонсол, калонсол, ранги миёнаи пӯст, ранги равшани пӯст',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'бӯса: калонсол, калонсол, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'бӯса: калонсол, калонсол, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'бӯса: калонсол, калонсол, ранги миёнаи пӯст, ранги торики пӯст',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'бӯса: калонсол, калонсол, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'бӯса: калонсол, калонсол, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'бӯса: калонсол, калонсол, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'бӯса: калонсол, калонсол, ранги торики миёнаи пӯст, ранги торики пӯст',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'бӯса: калонсол, калонсол, ранги торики пӯст, ранги равшани пӯст',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'бӯса: калонсол, калонсол, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'бӯса: калонсол, калонсол, ранги торики пӯст, ранги миёнаи пӯст',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'бӯса: калонсол, калонсол, ранги торики пӯст, ранги торики миёнаи пӯст',
    '👨🏻‍❤‍💋‍👨🏻' => 'бӯса: мард, мард, ранги равшани пӯст',
    '👨🏻‍❤‍💋‍👨🏼' => 'бӯса: мард, мард, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '👨🏻‍❤‍💋‍👨🏽' => 'бӯса: мард, мард, ранги равшани пӯст, ранги миёнаи пӯст',
    '👨🏻‍❤‍💋‍👨🏾' => 'бӯса: мард, мард, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '👨🏻‍❤‍💋‍👨🏿' => 'бӯса: мард, мард, ранги равшани пӯст, ранги торики пӯст',
    '👨🏼‍❤‍💋‍👨🏻' => 'бӯса: мард, мард, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '👨🏼‍❤‍💋‍👨🏼' => 'бӯса: мард, мард, ранги равшании миёнаи пӯст',
    '👨🏼‍❤‍💋‍👨🏽' => 'бӯса: мард, мард, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '👨🏼‍❤‍💋‍👨🏾' => 'бӯса: мард, мард, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '👨🏼‍❤‍💋‍👨🏿' => 'бӯса: мард, мард, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '👨🏽‍❤‍💋‍👨🏻' => 'бӯса: мард, мард, ранги миёнаи пӯст, ранги равшани пӯст',
    '👨🏽‍❤‍💋‍👨🏼' => 'бӯса: мард, мард, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👨🏽‍❤‍💋‍👨🏽' => 'бӯса: мард, мард, ранги миёнаи пӯст',
    '👨🏽‍❤‍💋‍👨🏾' => 'бӯса: мард, мард, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '👨🏽‍❤‍💋‍👨🏿' => 'бӯса: мард, мард, ранги миёнаи пӯст, ранги торики пӯст',
    '👨🏾‍❤‍💋‍👨🏻' => 'бӯса: мард, мард, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '👨🏾‍❤‍💋‍👨🏼' => 'бӯса: мард, мард, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👨🏾‍❤‍💋‍👨🏽' => 'бӯса: мард, мард, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '👨🏾‍❤‍💋‍👨🏾' => 'бӯса: мард, мард, ранги торики миёнаи пӯст',
    '👨🏾‍❤‍💋‍👨🏿' => 'бӯса: мард, мард, ранги торики миёнаи пӯст, ранги торики пӯст',
    '👨🏿‍❤‍💋‍👨🏻' => 'бӯса: мард, мард, ранги торики пӯст, ранги равшани пӯст',
    '👨🏿‍❤‍💋‍👨🏼' => 'бӯса: мард, мард, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '👨🏿‍❤‍💋‍👨🏽' => 'бӯса: мард, мард, ранги торики пӯст, ранги миёнаи пӯст',
    '👨🏿‍❤‍💋‍👨🏾' => 'бӯса: мард, мард, ранги торики пӯст, ранги торики миёнаи пӯст',
    '👨🏿‍❤‍💋‍👨🏿' => 'бӯса: мард, мард, ранги торики пӯст',
    '👩🏻‍❤‍💋‍👨🏻' => 'бӯса: зан, мард, ранги равшани пӯст',
    '👩🏻‍❤‍💋‍👨🏼' => 'бӯса: зан, мард, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '👩🏻‍❤‍💋‍👨🏽' => 'бӯса: зан, мард, ранги равшани пӯст, ранги миёнаи пӯст',
    '👩🏻‍❤‍💋‍👨🏾' => 'бӯса: зан, мард, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '👩🏻‍❤‍💋‍👨🏿' => 'бӯса: зан, мард, ранги равшани пӯст, ранги торики пӯст',
    '👩🏼‍❤‍💋‍👨🏻' => 'бӯса: зан, мард, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '👩🏼‍❤‍💋‍👨🏼' => 'бӯса: зан, мард, ранги равшании миёнаи пӯст',
    '👩🏼‍❤‍💋‍👨🏽' => 'бӯса: зан, мард, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏼‍❤‍💋‍👨🏾' => 'бӯса: зан, мард, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏼‍❤‍💋‍👨🏿' => 'бӯса: зан, мард, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '👩🏽‍❤‍💋‍👨🏻' => 'бӯса: зан, мард, ранги миёнаи пӯст, ранги равшани пӯст',
    '👩🏽‍❤‍💋‍👨🏼' => 'бӯса: зан, мард, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏽‍❤‍💋‍👨🏽' => 'бӯса: зан, мард, ранги миёнаи пӯст',
    '👩🏽‍❤‍💋‍👨🏾' => 'бӯса: зан, мард, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏽‍❤‍💋‍👨🏿' => 'бӯса: зан, мард, ранги миёнаи пӯст, ранги торики пӯст',
    '👩🏾‍❤‍💋‍👨🏻' => 'бӯса: зан, мард, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '👩🏾‍❤‍💋‍👨🏼' => 'бӯса: зан, мард, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏾‍❤‍💋‍👨🏽' => 'бӯса: зан, мард, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏾‍❤‍💋‍👨🏾' => 'бӯса: зан, мард, ранги торики миёнаи пӯст',
    '👩🏾‍❤‍💋‍👨🏿' => 'бӯса: зан, мард, ранги торики миёнаи пӯст, ранги торики пӯст',
    '👩🏿‍❤‍💋‍👨🏻' => 'бӯса: зан, мард, ранги торики пӯст, ранги равшани пӯст',
    '👩🏿‍❤‍💋‍👨🏼' => 'бӯса: зан, мард, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '👩🏿‍❤‍💋‍👨🏽' => 'бӯса: зан, мард, ранги торики пӯст, ранги миёнаи пӯст',
    '👩🏿‍❤‍💋‍👨🏾' => 'бӯса: зан, мард, ранги торики пӯст, ранги торики миёнаи пӯст',
    '👩🏿‍❤‍💋‍👨🏿' => 'бӯса: зан, мард, ранги торики пӯст',
    '👩🏻‍❤‍💋‍👩🏻' => 'бӯса: зан, зан, ранги равшани пӯст',
    '👩🏻‍❤‍💋‍👩🏼' => 'бӯса: зан, зан, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '👩🏻‍❤‍💋‍👩🏽' => 'бӯса: зан, зан, ранги равшани пӯст, ранги миёнаи пӯст',
    '👩🏻‍❤‍💋‍👩🏾' => 'бӯса: зан, зан, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '👩🏻‍❤‍💋‍👩🏿' => 'бӯса: зан, зан, ранги равшани пӯст, ранги торики пӯст',
    '👩🏼‍❤‍💋‍👩🏻' => 'бӯса: зан, зан, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '👩🏼‍❤‍💋‍👩🏼' => 'бӯса: зан, зан, ранги равшании миёнаи пӯст',
    '👩🏼‍❤‍💋‍👩🏽' => 'бӯса: зан, зан, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏼‍❤‍💋‍👩🏾' => 'бӯса: зан, зан, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏼‍❤‍💋‍👩🏿' => 'бӯса: зан, зан, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '👩🏽‍❤‍💋‍👩🏻' => 'бӯса: зан, зан, ранги миёнаи пӯст, ранги равшани пӯст',
    '👩🏽‍❤‍💋‍👩🏼' => 'бӯса: зан, зан, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏽‍❤‍💋‍👩🏽' => 'бӯса: зан, зан, ранги миёнаи пӯст',
    '👩🏽‍❤‍💋‍👩🏾' => 'бӯса: зан, зан, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏽‍❤‍💋‍👩🏿' => 'бӯса: зан, зан, ранги миёнаи пӯст, ранги торики пӯст',
    '👩🏾‍❤‍💋‍👩🏻' => 'бӯса: зан, зан, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '👩🏾‍❤‍💋‍👩🏼' => 'бӯса: зан, зан, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏾‍❤‍💋‍👩🏽' => 'бӯса: зан, зан, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏾‍❤‍💋‍👩🏾' => 'бӯса: зан, зан, ранги торики миёнаи пӯст',
    '👩🏾‍❤‍💋‍👩🏿' => 'бӯса: зан, зан, ранги торики миёнаи пӯст, ранги торики пӯст',
    '👩🏿‍❤‍💋‍👩🏻' => 'бӯса: зан, зан, ранги торики пӯст, ранги равшани пӯст',
    '👩🏿‍❤‍💋‍👩🏼' => 'бӯса: зан, зан, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '👩🏿‍❤‍💋‍👩🏽' => 'бӯса: зан, зан, ранги торики пӯст, ранги миёнаи пӯст',
    '👩🏿‍❤‍💋‍👩🏾' => 'бӯса: зан, зан, ранги торики пӯст, ранги торики миёнаи пӯст',
    '👩🏿‍❤‍💋‍👩🏿' => 'бӯса: зан, зан, ранги торики пӯст',
    '🧑🏻‍🫯‍🧑🏼' => 'нафарони гуштингирӣ карда истода: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏻‍🫯‍🧑🏽' => 'нафарони гуштингирӣ карда истода: ранги равшани пӯст ва ранги миёнаи пӯст',
    '🧑🏻‍🫯‍🧑🏾' => 'нафарони гуштингирӣ карда истода: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '🧑🏻‍🫯‍🧑🏿' => 'нафарони гуштингирӣ карда истода: ранги равшани пӯст ва ранги торики пӯст',
    '🧑🏼‍🫯‍🧑🏻' => 'нафарони гуштингирӣ карда истода: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '🧑🏼‍🫯‍🧑🏽' => 'нафарони гуштингирӣ карда истода: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '🧑🏼‍🫯‍🧑🏾' => 'нафарони гуштингирӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '🧑🏼‍🫯‍🧑🏿' => 'нафарони гуштингирӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '🧑🏽‍🫯‍🧑🏻' => 'нафарони гуштингирӣ карда истода: ранги миёнаи пӯст ва ранги равшани пӯст',
    '🧑🏽‍🫯‍🧑🏼' => 'нафарони гуштингирӣ карда истода: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏽‍🫯‍🧑🏾' => 'нафарони гуштингирӣ карда истода: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '🧑🏽‍🫯‍🧑🏿' => 'нафарони гуштингирӣ карда истода: ранги миёнаи пӯст ва ранги торики пӯст',
    '🧑🏾‍🫯‍🧑🏻' => 'нафарони гуштингирӣ карда истода: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '🧑🏾‍🫯‍🧑🏼' => 'нафарони гуштингирӣ карда истода: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏾‍🫯‍🧑🏽' => 'нафарони гуштингирӣ карда истода: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '🧑🏾‍🫯‍🧑🏿' => 'нафарони гуштингирӣ карда истода: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '🧑🏿‍🫯‍🧑🏻' => 'нафарони гуштингирӣ карда истода: ранги торики пӯст ва ранги равшани пӯст',
    '🧑🏿‍🫯‍🧑🏼' => 'нафарони гуштингирӣ карда истода: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏿‍🫯‍🧑🏽' => 'нафарони гуштингирӣ карда истода: ранги торики пӯст ва ранги миёнаи пӯст',
    '🧑🏿‍🫯‍🧑🏾' => 'нафарони гуштингирӣ карда истода: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '🧑🏻‍❤‍🧑🏼' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '🧑🏻‍❤‍🧑🏽' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшани пӯст, ранги миёнаи пӯст',
    '🧑🏻‍❤‍🧑🏾' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '🧑🏻‍❤‍🧑🏿' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшани пӯст, ранги торики пӯст',
    '🧑🏼‍❤‍🧑🏻' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '🧑🏼‍❤‍🧑🏽' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '🧑🏼‍❤‍🧑🏾' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '🧑🏼‍❤‍🧑🏿' => 'ҷуфт бо дил: калонсол, калонсол, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '🧑🏽‍❤‍🧑🏻' => 'ҷуфт бо дил: калонсол, калонсол, ранги миёнаи пӯст, ранги равшани пӯст',
    '🧑🏽‍❤‍🧑🏼' => 'ҷуфт бо дил: калонсол, калонсол, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '🧑🏽‍❤‍🧑🏾' => 'ҷуфт бо дил: калонсол, калонсол, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '🧑🏽‍❤‍🧑🏿' => 'ҷуфт бо дил: калонсол, калонсол, ранги миёнаи пӯст, ранги торики пӯст',
    '🧑🏾‍❤‍🧑🏻' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '🧑🏾‍❤‍🧑🏼' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '🧑🏾‍❤‍🧑🏽' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '🧑🏾‍❤‍🧑🏿' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики миёнаи пӯст, ранги торики пӯст',
    '🧑🏿‍❤‍🧑🏻' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики пӯст, ранги равшани пӯст',
    '🧑🏿‍❤‍🧑🏼' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '🧑🏿‍❤‍🧑🏽' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики пӯст, ранги миёнаи пӯст',
    '🧑🏿‍❤‍🧑🏾' => 'ҷуфт бо дил: калонсол, калонсол, ранги торики пӯст, ранги торики миёнаи пӯст',
    '🧑🏻‍🐰‍🧑🏼' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏻‍🐰‍🧑🏽' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги миёнаи пӯст',
    '🧑🏻‍🐰‍🧑🏾' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '🧑🏻‍🐰‍🧑🏿' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги торики пӯст',
    '🧑🏼‍🐰‍🧑🏻' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '🧑🏼‍🐰‍🧑🏽' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '🧑🏼‍🐰‍🧑🏾' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '🧑🏼‍🐰‍🧑🏿' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '🧑🏽‍🐰‍🧑🏻' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги равшани пӯст',
    '🧑🏽‍🐰‍🧑🏼' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏽‍🐰‍🧑🏾' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '🧑🏽‍🐰‍🧑🏿' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги торики пӯст',
    '🧑🏾‍🐰‍🧑🏻' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '🧑🏾‍🐰‍🧑🏼' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏾‍🐰‍🧑🏽' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '🧑🏾‍🐰‍🧑🏿' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '🧑🏿‍🐰‍🧑🏻' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги равшани пӯст',
    '🧑🏿‍🐰‍🧑🏼' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '🧑🏿‍🐰‍🧑🏽' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги миёнаи пӯст',
    '🧑🏿‍🐰‍🧑🏾' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👨🏻‍🫯‍👨🏼' => 'мардон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '👨🏻‍🫯‍👨🏽' => 'мардон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги миёнаи пӯст',
    '👨🏻‍🫯‍👨🏾' => 'мардон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '👨🏻‍🫯‍👨🏿' => 'мардон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги торики пӯст',
    '👨🏼‍🫯‍👨🏻' => 'мардон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '👨🏼‍🫯‍👨🏽' => 'мардон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '👨🏼‍🫯‍👨🏾' => 'мардон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👨🏼‍🫯‍👨🏿' => 'мардон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '👨🏽‍🫯‍👨🏻' => 'мардон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги равшани пӯст',
    '👨🏽‍🫯‍👨🏼' => 'мардон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👨🏽‍🫯‍👨🏾' => 'мардон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👨🏽‍🫯‍👨🏿' => 'мардон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги торики пӯст',
    '👨🏾‍🫯‍👨🏻' => 'мардон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '👨🏾‍🫯‍👨🏼' => 'мардон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👨🏾‍🫯‍👨🏽' => 'мардон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '👨🏾‍🫯‍👨🏿' => 'мардон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '👨🏿‍🫯‍👨🏻' => 'мардон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги равшани пӯст',
    '👨🏿‍🫯‍👨🏼' => 'мардон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '👨🏿‍🫯‍👨🏽' => 'мардон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги миёнаи пӯст',
    '👨🏿‍🫯‍👨🏾' => 'мардон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👨🏻‍❤‍👨🏻' => 'ҷуфт бо дил: мард, мард, ранги равшани пӯст',
    '👨🏻‍❤‍👨🏼' => 'ҷуфт бо дил: мард, мард, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '👨🏻‍❤‍👨🏽' => 'ҷуфт бо дил: мард, мард, ранги равшани пӯст, ранги миёнаи пӯст',
    '👨🏻‍❤‍👨🏾' => 'ҷуфт бо дил: мард, мард, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '👨🏻‍❤‍👨🏿' => 'ҷуфт бо дил: мард, мард, ранги равшани пӯст, ранги торики пӯст',
    '👨🏼‍❤‍👨🏻' => 'ҷуфт бо дил: мард, мард, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '👨🏼‍❤‍👨🏼' => 'ҷуфт бо дил: мард, мард, ранги равшании миёнаи пӯст',
    '👨🏼‍❤‍👨🏽' => 'ҷуфт бо дил: мард, мард, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '👨🏼‍❤‍👨🏾' => 'ҷуфт бо дил: мард, мард, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '👨🏼‍❤‍👨🏿' => 'ҷуфт бо дил: мард, мард, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '👨🏽‍❤‍👨🏻' => 'ҷуфт бо дил: мард, мард, ранги миёнаи пӯст, ранги равшани пӯст',
    '👨🏽‍❤‍👨🏼' => 'ҷуфт бо дил: мард, мард, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👨🏽‍❤‍👨🏽' => 'ҷуфт бо дил: мард, мард, ранги миёнаи пӯст',
    '👨🏽‍❤‍👨🏾' => 'ҷуфт бо дил: мард, мард, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '👨🏽‍❤‍👨🏿' => 'ҷуфт бо дил: мард, мард, ранги миёнаи пӯст, ранги торики пӯст',
    '👨🏾‍❤‍👨🏻' => 'ҷуфт бо дил: мард, мард, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '👨🏾‍❤‍👨🏼' => 'ҷуфт бо дил: мард, мард, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👨🏾‍❤‍👨🏽' => 'ҷуфт бо дил: мард, мард, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '👨🏾‍❤‍👨🏾' => 'ҷуфт бо дил: мард, мард, ранги торики миёнаи пӯст',
    '👨🏾‍❤‍👨🏿' => 'ҷуфт бо дил: мард, мард, ранги торики миёнаи пӯст, ранги торики пӯст',
    '👨🏿‍❤‍👨🏻' => 'ҷуфт бо дил: мард, мард, ранги торики пӯст, ранги равшани пӯст',
    '👨🏿‍❤‍👨🏼' => 'ҷуфт бо дил: мард, мард, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '👨🏿‍❤‍👨🏽' => 'ҷуфт бо дил: мард, мард, ранги торики пӯст, ранги миёнаи пӯст',
    '👨🏿‍❤‍👨🏾' => 'ҷуфт бо дил: мард, мард, ранги торики пӯст, ранги торики миёнаи пӯст',
    '👨🏿‍❤‍👨🏿' => 'ҷуфт бо дил: мард, мард, ранги торики пӯст',
    '👨🏻‍🐰‍👨🏼' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '👨🏻‍🐰‍👨🏽' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги миёнаи пӯст',
    '👨🏻‍🐰‍👨🏾' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '👨🏻‍🐰‍👨🏿' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги торики пӯст',
    '👨🏼‍🐰‍👨🏻' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '👨🏼‍🐰‍👨🏽' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '👨🏼‍🐰‍👨🏾' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👨🏼‍🐰‍👨🏿' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '👨🏽‍🐰‍👨🏻' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги равшани пӯст',
    '👨🏽‍🐰‍👨🏼' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👨🏽‍🐰‍👨🏾' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👨🏽‍🐰‍👨🏿' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги торики пӯст',
    '👨🏾‍🐰‍👨🏻' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '👨🏾‍🐰‍👨🏼' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👨🏾‍🐰‍👨🏽' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '👨🏾‍🐰‍👨🏿' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '👨🏿‍🐰‍👨🏻' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги равшани пӯст',
    '👨🏿‍🐰‍👨🏼' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '👨🏿‍🐰‍👨🏽' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги миёнаи пӯст',
    '👨🏿‍🐰‍👨🏾' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍🫯‍👩🏼' => 'занон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '👩🏻‍🫯‍👩🏽' => 'занон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги миёнаи пӯст',
    '👩🏻‍🫯‍👩🏾' => 'занон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍🫯‍👩🏿' => 'занон гуштингирӣ карда истодаанд: ранги равшани пӯст ва ранги торики пӯст',
    '👩🏼‍🫯‍👩🏻' => 'занон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '👩🏼‍🫯‍👩🏽' => 'занон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏼‍🫯‍👩🏾' => 'занон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏼‍🫯‍👩🏿' => 'занон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '👩🏽‍🫯‍👩🏻' => 'занон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги равшани пӯст',
    '👩🏽‍🫯‍👩🏼' => 'занон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏽‍🫯‍👩🏾' => 'занон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏽‍🫯‍👩🏿' => 'занон гуштингирӣ карда истодаанд: ранги миёнаи пӯст ва ранги торики пӯст',
    '👩🏾‍🫯‍👩🏻' => 'занон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '👩🏾‍🫯‍👩🏼' => 'занон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏾‍🫯‍👩🏽' => 'занон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏾‍🫯‍👩🏿' => 'занон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '👩🏿‍🫯‍👩🏻' => 'занон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги равшани пӯст',
    '👩🏿‍🫯‍👩🏼' => 'занон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '👩🏿‍🫯‍👩🏽' => 'занон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги миёнаи пӯст',
    '👩🏿‍🫯‍👩🏾' => 'занон гуштингирӣ карда истодаанд: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍❤‍👨🏻' => 'ҷуфт бо дил: зан, мард, ранги равшани пӯст',
    '👩🏻‍❤‍👨🏼' => 'ҷуфт бо дил: зан, мард, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '👩🏻‍❤‍👨🏽' => 'ҷуфт бо дил: зан, мард, ранги равшани пӯст, ранги миёнаи пӯст',
    '👩🏻‍❤‍👨🏾' => 'ҷуфт бо дил: зан, мард, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '👩🏻‍❤‍👨🏿' => 'ҷуфт бо дил: зан, мард, ранги равшани пӯст, ранги торики пӯст',
    '👩🏼‍❤‍👨🏻' => 'ҷуфт бо дил: зан, мард, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '👩🏼‍❤‍👨🏼' => 'ҷуфт бо дил: зан, мард, ранги равшании миёнаи пӯст',
    '👩🏼‍❤‍👨🏽' => 'ҷуфт бо дил: зан, мард, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏼‍❤‍👨🏾' => 'ҷуфт бо дил: зан, мард, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏼‍❤‍👨🏿' => 'ҷуфт бо дил: зан, мард, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '👩🏽‍❤‍👨🏻' => 'ҷуфт бо дил: зан, мард, ранги миёнаи пӯст, ранги равшани пӯст',
    '👩🏽‍❤‍👨🏼' => 'ҷуфт бо дил: зан, мард, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏽‍❤‍👨🏽' => 'ҷуфт бо дил: зан, мард, ранги миёнаи пӯст',
    '👩🏽‍❤‍👨🏾' => 'ҷуфт бо дил: зан, мард, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏽‍❤‍👨🏿' => 'ҷуфт бо дил: зан, мард, ранги миёнаи пӯст, ранги торики пӯст',
    '👩🏾‍❤‍👨🏻' => 'ҷуфт бо дил: зан, мард, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '👩🏾‍❤‍👨🏼' => 'ҷуфт бо дил: зан, мард, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏾‍❤‍👨🏽' => 'ҷуфт бо дил: зан, мард, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏾‍❤‍👨🏾' => 'ҷуфт бо дил: зан, мард, ранги торики миёнаи пӯст',
    '👩🏾‍❤‍👨🏿' => 'ҷуфт бо дил: зан, мард, ранги торики миёнаи пӯст, ранги торики пӯст',
    '👩🏿‍❤‍👨🏻' => 'ҷуфт бо дил: зан, мард, ранги торики пӯст, ранги равшани пӯст',
    '👩🏿‍❤‍👨🏼' => 'ҷуфт бо дил: зан, мард, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '👩🏿‍❤‍👨🏽' => 'ҷуфт бо дил: зан, мард, ранги торики пӯст, ранги миёнаи пӯст',
    '👩🏿‍❤‍👨🏾' => 'ҷуфт бо дил: зан, мард, ранги торики пӯст, ранги торики миёнаи пӯст',
    '👩🏿‍❤‍👨🏿' => 'ҷуфт бо дил: зан, мард, ранги торики пӯст',
    '👩🏻‍❤‍👩🏻' => 'ҷуфт бо дил: зан, зан, ранги равшани пӯст',
    '👩🏻‍❤‍👩🏼' => 'ҷуфт бо дил: зан, зан, ранги равшани пӯст, ранги равшании миёнаи пӯст',
    '👩🏻‍❤‍👩🏽' => 'ҷуфт бо дил: зан, зан, ранги равшани пӯст, ранги миёнаи пӯст',
    '👩🏻‍❤‍👩🏾' => 'ҷуфт бо дил: зан, зан, ранги равшани пӯст, ранги торики миёнаи пӯст',
    '👩🏻‍❤‍👩🏿' => 'ҷуфт бо дил: зан, зан, ранги равшани пӯст, ранги торики пӯст',
    '👩🏼‍❤‍👩🏻' => 'ҷуфт бо дил: зан, зан, ранги равшании миёнаи пӯст, ранги равшани пӯст',
    '👩🏼‍❤‍👩🏼' => 'ҷуфт бо дил: зан, зан, ранги равшании миёнаи пӯст',
    '👩🏼‍❤‍👩🏽' => 'ҷуфт бо дил: зан, зан, ранги равшании миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏼‍❤‍👩🏾' => 'ҷуфт бо дил: зан, зан, ранги равшании миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏼‍❤‍👩🏿' => 'ҷуфт бо дил: зан, зан, ранги равшании миёнаи пӯст, ранги торики пӯст',
    '👩🏽‍❤‍👩🏻' => 'ҷуфт бо дил: зан, зан, ранги миёнаи пӯст, ранги равшани пӯст',
    '👩🏽‍❤‍👩🏼' => 'ҷуфт бо дил: зан, зан, ранги миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏽‍❤‍👩🏽' => 'ҷуфт бо дил: зан, зан, ранги миёнаи пӯст',
    '👩🏽‍❤‍👩🏾' => 'ҷуфт бо дил: зан, зан, ранги миёнаи пӯст, ранги торики миёнаи пӯст',
    '👩🏽‍❤‍👩🏿' => 'ҷуфт бо дил: зан, зан, ранги миёнаи пӯст, ранги торики пӯст',
    '👩🏾‍❤‍👩🏻' => 'ҷуфт бо дил: зан, зан, ранги торики миёнаи пӯст, ранги равшани пӯст',
    '👩🏾‍❤‍👩🏼' => 'ҷуфт бо дил: зан, зан, ранги торики миёнаи пӯст, ранги равшании миёнаи пӯст',
    '👩🏾‍❤‍👩🏽' => 'ҷуфт бо дил: зан, зан, ранги торики миёнаи пӯст, ранги миёнаи пӯст',
    '👩🏾‍❤‍👩🏾' => 'ҷуфт бо дил: зан, зан, ранги торики миёнаи пӯст',
    '👩🏾‍❤‍👩🏿' => 'ҷуфт бо дил: зан, зан, ранги торики миёнаи пӯст, ранги торики пӯст',
    '👩🏿‍❤‍👩🏻' => 'ҷуфт бо дил: зан, зан, ранги торики пӯст, ранги равшани пӯст',
    '👩🏿‍❤‍👩🏼' => 'ҷуфт бо дил: зан, зан, ранги торики пӯст, ранги равшании миёнаи пӯст',
    '👩🏿‍❤‍👩🏽' => 'ҷуфт бо дил: зан, зан, ранги торики пӯст, ранги миёнаи пӯст',
    '👩🏿‍❤‍👩🏾' => 'ҷуфт бо дил: зан, зан, ранги торики пӯст, ранги торики миёнаи пӯст',
    '👩🏿‍❤‍👩🏿' => 'ҷуфт бо дил: зан, зан, ранги торики пӯст',
    '👩🏻‍🐰‍👩🏼' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '👩🏻‍🐰‍👩🏽' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги миёнаи пӯст',
    '👩🏻‍🐰‍👩🏾' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍🐰‍👩🏿' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст ва ранги торики пӯст',
    '👩🏼‍🐰‍👩🏻' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '👩🏼‍🐰‍👩🏽' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏼‍🐰‍👩🏾' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏼‍🐰‍👩🏿' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '👩🏽‍🐰‍👩🏻' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги равшани пӯст',
    '👩🏽‍🐰‍👩🏼' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏽‍🐰‍👩🏾' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏽‍🐰‍👩🏿' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст ва ранги торики пӯст',
    '👩🏾‍🐰‍👩🏻' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '👩🏾‍🐰‍👩🏼' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏾‍🐰‍👩🏽' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏾‍🐰‍👩🏿' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '👩🏿‍🐰‍👩🏻' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги равшани пӯст',
    '👩🏿‍🐰‍👩🏼' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '👩🏿‍🐰‍👩🏽' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги миёнаи пӯст',
    '👩🏿‍🐰‍👩🏾' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍🤝‍👩🏼' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '👩🏻‍🤝‍👩🏽' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги миёнаи пӯст',
    '👩🏻‍🤝‍👩🏾' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍🤝‍👩🏿' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги торики пӯст',
    '👩🏼‍🤝‍👩🏻' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '👩🏼‍🤝‍👩🏽' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏼‍🤝‍👩🏾' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏼‍🤝‍👩🏿' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '👩🏽‍🤝‍👩🏻' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги равшани пӯст',
    '👩🏽‍🤝‍👩🏼' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏽‍🤝‍👩🏾' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏽‍🤝‍👩🏿' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги торики пӯст',
    '👩🏾‍🤝‍👩🏻' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '👩🏾‍🤝‍👩🏼' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏾‍🤝‍👩🏽' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏾‍🤝‍👩🏿' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '👩🏿‍🤝‍👩🏻' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги равшани пӯст',
    '👩🏿‍🤝‍👩🏼' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '👩🏿‍🤝‍👩🏽' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги миёнаи пӯст',
    '👩🏿‍🤝‍👩🏾' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍🤝‍👨🏼' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '👩🏻‍🤝‍👨🏽' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги миёнаи пӯст',
    '👩🏻‍🤝‍👨🏾' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '👩🏻‍🤝‍👨🏿' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги торики пӯст',
    '👩🏼‍🤝‍👨🏻' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '👩🏼‍🤝‍👨🏽' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏼‍🤝‍👨🏾' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏼‍🤝‍👨🏿' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '👩🏽‍🤝‍👨🏻' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги равшани пӯст',
    '👩🏽‍🤝‍👨🏼' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏽‍🤝‍👨🏾' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👩🏽‍🤝‍👨🏿' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги торики пӯст',
    '👩🏾‍🤝‍👨🏻' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '👩🏾‍🤝‍👨🏼' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👩🏾‍🤝‍👨🏽' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '👩🏾‍🤝‍👨🏿' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '👩🏿‍🤝‍👨🏻' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги равшани пӯст',
    '👩🏿‍🤝‍👨🏼' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '👩🏿‍🤝‍👨🏽' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги миёнаи пӯст',
    '👩🏿‍🤝‍👨🏾' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👨🏻‍🤝‍👨🏼' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '👨🏻‍🤝‍👨🏽' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги миёнаи пӯст',
    '👨🏻‍🤝‍👨🏾' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '👨🏻‍🤝‍👨🏿' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст ва ранги торики пӯст',
    '👨🏼‍🤝‍👨🏻' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '👨🏼‍🤝‍👨🏽' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '👨🏼‍🤝‍👨🏾' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👨🏼‍🤝‍👨🏿' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '👨🏽‍🤝‍👨🏻' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги равшани пӯст',
    '👨🏽‍🤝‍👨🏼' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👨🏽‍🤝‍👨🏾' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '👨🏽‍🤝‍👨🏿' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст ва ранги торики пӯст',
    '👨🏾‍🤝‍👨🏻' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '👨🏾‍🤝‍👨🏼' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '👨🏾‍🤝‍👨🏽' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '👨🏾‍🤝‍👨🏿' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '👨🏿‍🤝‍👨🏻' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги равшани пӯст',
    '👨🏿‍🤝‍👨🏼' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '👨🏿‍🤝‍👨🏽' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги миёнаи пӯст',
    '👨🏿‍🤝‍👨🏾' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👩‍❤‍💋‍👨' => 'бӯса: зан ва мард',
    '👨‍❤‍💋‍👨' => 'бӯса: мард ва мард',
    '👩‍❤‍💋‍👩' => 'бӯса: зан ва зан',
    '👨‍👩‍👧‍👦' => 'оила: мард, зан, духтар, писар',
    '👨‍👩‍👦‍👦' => 'оила: мард, зан, писар, писар',
    '👨‍👩‍👧‍👧' => 'оила: мард, зан, духтар, духтар',
    '👨‍👨‍👧‍👦' => 'оила: мард, мард, духтар, писар',
    '👨‍👨‍👦‍👦' => 'оила: мард, мард, писар, писар',
    '👨‍👨‍👧‍👧' => 'оила: мард, мард, духтар, духтар',
    '👩‍👩‍👧‍👦' => 'оила: зан, зан, духтар, писар',
    '👩‍👩‍👦‍👦' => 'оила: зан, зан, писар, писар',
    '👩‍👩‍👧‍👧' => 'оила: зан, зан, духтар, духтар',
    '🫱🏻‍🫲🏼' => 'дастфишӯрӣ: ранги равшани пӯст ва ранги равшании миёнаи пӯст',
    '🫱🏻‍🫲🏽' => 'дастфишӯрӣ: ранги равшани пӯст ва ранги миёнаи пӯст',
    '🫱🏻‍🫲🏾' => 'дастфишӯрӣ: ранги равшани пӯст ва ранги торики миёнаи пӯст',
    '🫱🏻‍🫲🏿' => 'дастфишӯрӣ: ранги равшани пӯст ва ранги торики пӯст',
    '🫱🏼‍🫲🏻' => 'дастфишӯрӣ: ранги равшании миёнаи пӯст ва ранги равшани пӯст',
    '🫱🏼‍🫲🏽' => 'дастфишӯрӣ: ранги равшании миёнаи пӯст ва ранги миёнаи пӯст',
    '🫱🏼‍🫲🏾' => 'дастфишӯрӣ: ранги равшании миёнаи пӯст ва ранги торики миёнаи пӯст',
    '🫱🏼‍🫲🏿' => 'дастфишӯрӣ: ранги равшании миёнаи пӯст ва ранги торики пӯст',
    '🫱🏽‍🫲🏻' => 'дастфишӯрӣ: ранги миёнаи пӯст ва ранги равшани пӯст',
    '🫱🏽‍🫲🏼' => 'дастфишӯрӣ: ранги миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '🫱🏽‍🫲🏾' => 'дастфишӯрӣ: ранги миёнаи пӯст ва ранги торики миёнаи пӯст',
    '🫱🏽‍🫲🏿' => 'дастфишӯрӣ: ранги миёнаи пӯст ва ранги торики пӯст',
    '🫱🏾‍🫲🏻' => 'дастфишӯрӣ: ранги торики миёнаи пӯст ва ранги равшани пӯст',
    '🫱🏾‍🫲🏼' => 'дастфишӯрӣ: ранги торики миёнаи пӯст ва ранги равшании миёнаи пӯст',
    '🫱🏾‍🫲🏽' => 'дастфишӯрӣ: ранги торики миёнаи пӯст ва ранги миёнаи пӯст',
    '🫱🏾‍🫲🏿' => 'дастфишӯрӣ: ранги торики миёнаи пӯст ва ранги торики пӯст',
    '🫱🏿‍🫲🏻' => 'дастфишӯрӣ: ранги торики пӯст ва ранги равшани пӯст',
    '🫱🏿‍🫲🏼' => 'дастфишӯрӣ: ранги торики пӯст ва ранги равшании миёнаи пӯст',
    '🫱🏿‍🫲🏽' => 'дастфишӯрӣ: ранги торики пӯст ва ранги миёнаи пӯст',
    '🫱🏿‍🫲🏾' => 'дастфишӯрӣ: ранги торики пӯст ва ранги торики миёнаи пӯст',
    '👩‍❤‍👨' => 'ҷуфт бо дил: зан ва мард',
    '👨‍❤‍👨' => 'ҷуфт бо дил: мард ва мард',
    '👩‍❤‍👩' => 'ҷуфт бо дил: зан ва зан',
    '👨‍👩‍👦' => 'оила: мард, зан, писар',
    '👨‍👩‍👧' => 'оила: мард, зан, духтар',
    '👨‍👨‍👦' => 'оила: мард, мард, писар',
    '👨‍👨‍👧' => 'оила: мард, мард, духтар',
    '👩‍👩‍👦' => 'оила: зан, зан, писар',
    '👩‍👩‍👧' => 'оила: зан, зан, духтар',
    '👨‍👦‍👦' => 'оила: мард, писар, писар',
    '👨‍👧‍👦' => 'оила: мард, духтар, писар',
    '👨‍👧‍👧' => 'оила: мард, духтар, духтар',
    '👩‍👦‍👦' => 'оила: зан, писар, писар',
    '👩‍👧‍👦' => 'оила: зан, духтар, писар',
    '👩‍👧‍👧' => 'оила: зан, духтар, духтар',
    '👱🏻‍♂' => 'марди зардинамӯй: ранги равшани пӯст',
    '👱🏼‍♂' => 'марди зардинамӯй: ранги равшании миёнаи пӯст',
    '👱🏽‍♂' => 'марди зардинамӯй: ранги миёнаи пӯст',
    '👱🏾‍♂' => 'марди зардинамӯй: ранги торики миёнаи пӯст',
    '👱🏿‍♂' => 'марди зардинамӯй: ранги торики пӯст',
    '👱🏻‍♀' => 'зани зардинамӯй: ранги равшани пӯст',
    '👱🏼‍♀' => 'зани зардинамӯй: ранги равшании миёнаи пӯст',
    '👱🏽‍♀' => 'зани зардинамӯй: ранги миёнаи пӯст',
    '👱🏾‍♀' => 'зани зардинамӯй: ранги торики миёнаи пӯст',
    '👱🏿‍♀' => 'зани зардинамӯй: ранги торики пӯст',
    '🙍🏻‍♂' => 'марде, ки қавоқ андохта истодааст: ранги равшани пӯст',
    '🙍🏼‍♂' => 'марде, ки қавоқ андохта истодааст: ранги равшании миёнаи пӯст',
    '🙍🏽‍♂' => 'марде, ки қавоқ андохта истодааст: ранги миёнаи пӯст',
    '🙍🏾‍♂' => 'марде, ки қавоқ андохта истодааст: ранги торики миёнаи пӯст',
    '🙍🏿‍♂' => 'марде, ки қавоқ андохта истодааст: ранги торики пӯст',
    '🙍🏻‍♀' => 'зане, ки қавоқ андохта истодааст: ранги равшани пӯст',
    '🙍🏼‍♀' => 'зане, ки қавоқ андохта истодааст: ранги равшании миёнаи пӯст',
    '🙍🏽‍♀' => 'зане, ки қавоқ андохта истодааст: ранги миёнаи пӯст',
    '🙍🏾‍♀' => 'зане, ки қавоқ андохта истодааст: ранги торики миёнаи пӯст',
    '🙍🏿‍♀' => 'зане, ки қавоқ андохта истодааст: ранги торики пӯст',
    '🙎🏻‍♂' => 'марде, ки лабҳояшро каҷ карда истодааст: ранги равшани пӯст',
    '🙎🏼‍♂' => 'марде, ки лабҳояшро каҷ карда истодааст: ранги равшании миёнаи пӯст',
    '🙎🏽‍♂' => 'марде, ки лабҳояшро каҷ карда истодааст: ранги миёнаи пӯст',
    '🙎🏾‍♂' => 'марде, ки лабҳояшро каҷ карда истодааст: ранги торики миёнаи пӯст',
    '🙎🏿‍♂' => 'марде, ки лабҳояшро каҷ карда истодааст: ранги торики пӯст',
    '🙎🏻‍♀' => 'зане, ки лабҳояшро каҷ карда истодааст: ранги равшани пӯст',
    '🙎🏼‍♀' => 'зане, ки лабҳояшро каҷ карда истодааст: ранги равшании миёнаи пӯст',
    '🙎🏽‍♀' => 'зане, ки лабҳояшро каҷ карда истодааст: ранги миёнаи пӯст',
    '🙎🏾‍♀' => 'зане, ки лабҳояшро каҷ карда истодааст: ранги торики миёнаи пӯст',
    '🙎🏿‍♀' => 'зане, ки лабҳояшро каҷ карда истодааст: ранги торики пӯст',
    '🙅🏻‍♂' => 'марде, ки "НЕ" ишора карда истодааст: ранги равшани пӯст',
    '🙅🏼‍♂' => 'марде, ки "НЕ" ишора карда истодааст: ранги равшании миёнаи пӯст',
    '🙅🏽‍♂' => 'марде, ки "НЕ" ишора карда истодааст: ранги миёнаи пӯст',
    '🙅🏾‍♂' => 'марде, ки "НЕ" ишора карда истодааст: ранги торики миёнаи пӯст',
    '🙅🏿‍♂' => 'марде, ки "НЕ" ишора карда истодааст: ранги торики пӯст',
    '🙅🏻‍♀' => 'зане, ки "НЕ" ишора карда истодааст: ранги равшани пӯст',
    '🙅🏼‍♀' => 'зане, ки "НЕ" ишора карда истодааст: ранги равшании миёнаи пӯст',
    '🙅🏽‍♀' => 'зане, ки "НЕ" ишора карда истодааст: ранги миёнаи пӯст',
    '🙅🏾‍♀' => 'зане, ки "НЕ" ишора карда истодааст: ранги торики миёнаи пӯст',
    '🙅🏿‍♀' => 'зане, ки "НЕ" ишора карда истодааст: ранги торики пӯст',
    '🙆🏻‍♂' => 'марде, ки "ОК" ишора карда истодааст: ранги равшани пӯст',
    '🙆🏼‍♂' => 'марде, ки "ОК" ишора карда истодааст: ранги равшании миёнаи пӯст',
    '🙆🏽‍♂' => 'марде, ки "ОК" ишора карда истодааст: ранги миёнаи пӯст',
    '🙆🏾‍♂' => 'марде, ки "ОК" ишора карда истодааст: ранги торики миёнаи пӯст',
    '🙆🏿‍♂' => 'марде, ки "ОК" ишора карда истодааст: ранги торики пӯст',
    '🙆🏻‍♀' => 'зане, ки "ОК" ишора карда истодааст: ранги равшани пӯст',
    '🙆🏼‍♀' => 'зане, ки "ОК" ишора карда истодааст: ранги равшании миёнаи пӯст',
    '🙆🏽‍♀' => 'зане, ки "ОК" ишора карда истодааст: ранги миёнаи пӯст',
    '🙆🏾‍♀' => 'зане, ки "ОК" ишора карда истодааст: ранги торики миёнаи пӯст',
    '🙆🏿‍♀' => 'зане, ки "ОК" ишора карда истодааст: ранги торики пӯст',
    '💁🏻‍♂' => 'марде, ки бо дасташ ишора карда истодааст: ранги равшани пӯст',
    '💁🏼‍♂' => 'марде, ки бо дасташ ишора карда истодааст: ранги равшании миёнаи пӯст',
    '💁🏽‍♂' => 'марде, ки бо дасташ ишора карда истодааст: ранги миёнаи пӯст',
    '💁🏾‍♂' => 'марде, ки бо дасташ ишора карда истодааст: ранги торики миёнаи пӯст',
    '💁🏿‍♂' => 'марде, ки бо дасташ ишора карда истодааст: ранги торики пӯст',
    '💁🏻‍♀' => 'зане, ки бо дасташ ишора карда истодааст: ранги равшани пӯст',
    '💁🏼‍♀' => 'зане, ки бо дасташ ишора карда истодааст: ранги равшании миёнаи пӯст',
    '💁🏽‍♀' => 'зане, ки бо дасташ ишора карда истодааст: ранги миёнаи пӯст',
    '💁🏾‍♀' => 'зане, ки бо дасташ ишора карда истодааст: ранги торики миёнаи пӯст',
    '💁🏿‍♀' => 'зане, ки бо дасташ ишора карда истодааст: ранги торики пӯст',
    '🙋🏻‍♂' => 'марде, ки дасташро бардошта истодааст: ранги равшани пӯст',
    '🙋🏼‍♂' => 'марде, ки дасташро бардошта истодааст: ранги равшании миёнаи пӯст',
    '🙋🏽‍♂' => 'марде, ки дасташро бардошта истодааст: ранги миёнаи пӯст',
    '🙋🏾‍♂' => 'марде, ки дасташро бардошта истодааст: ранги торики миёнаи пӯст',
    '🙋🏿‍♂' => 'марде, ки дасташро бардошта истодааст: ранги торики пӯст',
    '🙋🏻‍♀' => 'зане, ки дасташро бардошта истодааст: ранги равшани пӯст',
    '🙋🏼‍♀' => 'зане, ки дасташро бардошта истодааст: ранги равшании миёнаи пӯст',
    '🙋🏽‍♀' => 'зане, ки дасташро бардошта истодааст: ранги миёнаи пӯст',
    '🙋🏾‍♀' => 'зане, ки дасташро бардошта истодааст: ранги торики миёнаи пӯст',
    '🙋🏿‍♀' => 'зане, ки дасташро бардошта истодааст: ранги торики пӯст',
    '🙇🏻‍♂' => 'марде, ки хам шуда истодааст: ранги равшани пӯст',
    '🙇🏼‍♂' => 'марде, ки хам шуда истодааст: ранги равшании миёнаи пӯст',
    '🙇🏽‍♂' => 'марде, ки хам шуда истодааст: ранги миёнаи пӯст',
    '🙇🏾‍♂' => 'марде, ки хам шуда истодааст: ранги торики миёнаи пӯст',
    '🙇🏿‍♂' => 'марде, ки хам шуда истодааст: ранги торики пӯст',
    '🙇🏻‍♀' => 'зане, ки хам шуда истодааст: ранги равшани пӯст',
    '🙇🏼‍♀' => 'зане, ки хам шуда истодааст: ранги равшании миёнаи пӯст',
    '🙇🏽‍♀' => 'зане, ки хам шуда истодааст: ранги миёнаи пӯст',
    '🙇🏾‍♀' => 'зане, ки хам шуда истодааст: ранги торики миёнаи пӯст',
    '🙇🏿‍♀' => 'зане, ки хам шуда истодааст: ранги торики пӯст',
    '🤦🏻‍♂' => 'марде, ки рӯяшро бо дастонаш пӯшида истодааст: ранги равшани пӯст',
    '🤦🏼‍♂' => 'марде, ки рӯяшро бо дастонаш пӯшида истодааст: ранги равшании миёнаи пӯст',
    '🤦🏽‍♂' => 'марде, ки рӯяшро бо дастонаш пӯшида истодааст: ранги миёнаи пӯст',
    '🤦🏾‍♂' => 'марде, ки рӯяшро бо дастонаш пӯшида истодааст: ранги торики миёнаи пӯст',
    '🤦🏿‍♂' => 'марде, ки рӯяшро бо дастонаш пӯшида истодааст: ранги торики пӯст',
    '🤦🏻‍♀' => 'зане, ки рӯяшро бо дастонаш пӯшида истодааст: ранги равшани пӯст',
    '🤦🏼‍♀' => 'зане, ки рӯяшро бо дастонаш пӯшида истодааст: ранги равшании миёнаи пӯст',
    '🤦🏽‍♀' => 'зане, ки рӯяшро бо дастонаш пӯшида истодааст: ранги миёнаи пӯст',
    '🤦🏾‍♀' => 'зане, ки рӯяшро бо дастонаш пӯшида истодааст: ранги торики миёнаи пӯст',
    '🤦🏿‍♀' => 'зане, ки рӯяшро бо дастонаш пӯшида истодааст: ранги торики пӯст',
    '🤷🏻‍♂' => 'марде, ки китф афшонда истодааст: ранги равшани пӯст',
    '🤷🏼‍♂' => 'марде, ки китф афшонда истодааст: ранги равшании миёнаи пӯст',
    '🤷🏽‍♂' => 'марде, ки китф афшонда истодааст: ранги миёнаи пӯст',
    '🤷🏾‍♂' => 'марде, ки китф афшонда истодааст: ранги торики миёнаи пӯст',
    '🤷🏿‍♂' => 'марде, ки китф афшонда истодааст: ранги торики пӯст',
    '🤷🏻‍♀' => 'зане, ки китф афшонда истодааст: ранги равшани пӯст',
    '🤷🏼‍♀' => 'зане, ки китф афшонда истодааст: ранги равшании миёнаи пӯст',
    '🤷🏽‍♀' => 'зане, ки китф афшонда истодааст: ранги миёнаи пӯст',
    '🤷🏾‍♀' => 'зане, ки китф афшонда истодааст: ранги торики миёнаи пӯст',
    '🤷🏿‍♀' => 'зане, ки китф афшонда истодааст: ранги торики пӯст',
    '👨🏻‍⚕' => 'марди корманди тандурустӣ: ранги равшани пӯст',
    '👨🏼‍⚕' => 'марди корманди тандурустӣ: ранги равшании миёнаи пӯст',
    '👨🏽‍⚕' => 'марди корманди тандурустӣ: ранги миёнаи пӯст',
    '👨🏾‍⚕' => 'марди корманди тандурустӣ: ранги торики миёнаи пӯст',
    '👨🏿‍⚕' => 'марди корманди тандурустӣ: ранги торики пӯст',
    '👩🏻‍⚕' => 'зани корманди тандурустӣ: ранги равшани пӯст',
    '👩🏼‍⚕' => 'зани корманди тандурустӣ: ранги равшании миёнаи пӯст',
    '👩🏽‍⚕' => 'зани корманди тандурустӣ: ранги миёнаи пӯст',
    '👩🏾‍⚕' => 'зани корманди тандурустӣ: ранги торики миёнаи пӯст',
    '👩🏿‍⚕' => 'зани корманди тандурустӣ: ранги торики пӯст',
    '👨🏻‍🎓' => 'марди донишҷӯ: ранги равшани пӯст',
    '👨🏼‍🎓' => 'марди донишҷӯ: ранги равшании миёнаи пӯст',
    '👨🏽‍🎓' => 'марди донишҷӯ: ранги миёнаи пӯст',
    '👨🏾‍🎓' => 'марди донишҷӯ: ранги торики миёнаи пӯст',
    '👨🏿‍🎓' => 'марди донишҷӯ: ранги торики пӯст',
    '👩🏻‍🎓' => 'зани донишҷӯ: ранги равшани пӯст',
    '👩🏼‍🎓' => 'зани донишҷӯ: ранги равшании миёнаи пӯст',
    '👩🏽‍🎓' => 'зани донишҷӯ: ранги миёнаи пӯст',
    '👩🏾‍🎓' => 'зани донишҷӯ: ранги торики миёнаи пӯст',
    '👩🏿‍🎓' => 'зани донишҷӯ: ранги торики пӯст',
    '👨🏻‍🏫' => 'марди муаллим: ранги равшани пӯст',
    '👨🏼‍🏫' => 'марди муаллим: ранги равшании миёнаи пӯст',
    '👨🏽‍🏫' => 'марди муаллим: ранги миёнаи пӯст',
    '👨🏾‍🏫' => 'марди муаллим: ранги торики миёнаи пӯст',
    '👨🏿‍🏫' => 'марди муаллим: ранги торики пӯст',
    '👩🏻‍🏫' => 'зани муаллим: ранги равшани пӯст',
    '👩🏼‍🏫' => 'зани муаллим: ранги равшании миёнаи пӯст',
    '👩🏽‍🏫' => 'зани муаллим: ранги миёнаи пӯст',
    '👩🏾‍🏫' => 'зани муаллим: ранги торики миёнаи пӯст',
    '👩🏿‍🏫' => 'зани муаллим: ранги торики пӯст',
    '👨🏻‍⚖' => 'марди судя: ранги равшани пӯст',
    '👨🏼‍⚖' => 'марди судя: ранги равшании миёнаи пӯст',
    '👨🏽‍⚖' => 'марди судя: ранги миёнаи пӯст',
    '👨🏾‍⚖' => 'марди судя: ранги торики миёнаи пӯст',
    '👨🏿‍⚖' => 'марди судя: ранги торики пӯст',
    '👩🏻‍⚖' => 'зани судя: ранги равшани пӯст',
    '👩🏼‍⚖' => 'зани судя: ранги равшании миёнаи пӯст',
    '👩🏽‍⚖' => 'зани судя: ранги миёнаи пӯст',
    '👩🏾‍⚖' => 'зани судя: ранги торики миёнаи пӯст',
    '👩🏿‍⚖' => 'зани судя: ранги торики пӯст',
    '👨🏻‍🌾' => 'марди фермер: ранги равшани пӯст',
    '👨🏼‍🌾' => 'марди фермер: ранги равшании миёнаи пӯст',
    '👨🏽‍🌾' => 'марди фермер: ранги миёнаи пӯст',
    '👨🏾‍🌾' => 'марди фермер: ранги торики миёнаи пӯст',
    '👨🏿‍🌾' => 'марди фермер: ранги торики пӯст',
    '👩🏻‍🌾' => 'зани фермер: ранги равшани пӯст',
    '👩🏼‍🌾' => 'зани фермер: ранги равшании миёнаи пӯст',
    '👩🏽‍🌾' => 'зани фермер: ранги миёнаи пӯст',
    '👩🏾‍🌾' => 'зани фермер: ранги торики миёнаи пӯст',
    '👩🏿‍🌾' => 'зани фермер: ранги торики пӯст',
    '👨🏻‍🍳' => 'марди ошпаз: ранги равшани пӯст',
    '👨🏼‍🍳' => 'марди ошпаз: ранги равшании миёнаи пӯст',
    '👨🏽‍🍳' => 'марди ошпаз: ранги миёнаи пӯст',
    '👨🏾‍🍳' => 'марди ошпаз: ранги торики миёнаи пӯст',
    '👨🏿‍🍳' => 'марди ошпаз: ранги торики пӯст',
    '👩🏻‍🍳' => 'зани ошпаз: ранги равшани пӯст',
    '👩🏼‍🍳' => 'зани ошпаз: ранги равшании миёнаи пӯст',
    '👩🏽‍🍳' => 'зани ошпаз: ранги миёнаи пӯст',
    '👩🏾‍🍳' => 'зани ошпаз: ранги торики миёнаи пӯст',
    '👩🏿‍🍳' => 'зани ошпаз: ранги торики пӯст',
    '👨🏻‍🔧' => 'марди механик: ранги равшани пӯст',
    '👨🏼‍🔧' => 'марди механик: ранги равшании миёнаи пӯст',
    '👨🏽‍🔧' => 'марди механик: ранги миёнаи пӯст',
    '👨🏾‍🔧' => 'марди механик: ранги торики миёнаи пӯст',
    '👨🏿‍🔧' => 'марди механик: ранги торики пӯст',
    '👩🏻‍🔧' => 'зани механик: ранги равшани пӯст',
    '👩🏼‍🔧' => 'зани механик: ранги равшании миёнаи пӯст',
    '👩🏽‍🔧' => 'зани механик: ранги миёнаи пӯст',
    '👩🏾‍🔧' => 'зани механик: ранги торики миёнаи пӯст',
    '👩🏿‍🔧' => 'зани механик: ранги торики пӯст',
    '👨🏻‍🏭' => 'марди коргари фабрика: ранги равшани пӯст',
    '👨🏼‍🏭' => 'марди коргари фабрика: ранги равшании миёнаи пӯст',
    '👨🏽‍🏭' => 'марди коргари фабрика: ранги миёнаи пӯст',
    '👨🏾‍🏭' => 'марди коргари фабрика: ранги торики миёнаи пӯст',
    '👨🏿‍🏭' => 'марди коргари фабрика: ранги торики пӯст',
    '👩🏻‍🏭' => 'зани коргари фабрика: ранги равшани пӯст',
    '👩🏼‍🏭' => 'зани коргари фабрика: ранги равшании миёнаи пӯст',
    '👩🏽‍🏭' => 'зани коргари фабрика: ранги миёнаи пӯст',
    '👩🏾‍🏭' => 'зани коргари фабрика: ранги торики миёнаи пӯст',
    '👩🏿‍🏭' => 'зани коргари фабрика: ранги торики пӯст',
    '👨🏻‍💼' => 'марди корманди идора: ранги равшани пӯст',
    '👨🏼‍💼' => 'марди корманди идора: ранги равшании миёнаи пӯст',
    '👨🏽‍💼' => 'марди корманди идора: ранги миёнаи пӯст',
    '👨🏾‍💼' => 'марди корманди идора: ранги торики миёнаи пӯст',
    '👨🏿‍💼' => 'марди корманди идора: ранги торики пӯст',
    '👩🏻‍💼' => 'зани корманди идора: ранги равшани пӯст',
    '👩🏼‍💼' => 'зани корманди идора: ранги равшании миёнаи пӯст',
    '👩🏽‍💼' => 'зани корманди идора: ранги миёнаи пӯст',
    '👩🏾‍💼' => 'зани корманди идора: ранги торики миёнаи пӯст',
    '👩🏿‍💼' => 'зани корманди идора: ранги торики пӯст',
    '👨🏻‍🔬' => 'марди олим: ранги равшани пӯст',
    '👨🏼‍🔬' => 'марди олим: ранги равшании миёнаи пӯст',
    '👨🏽‍🔬' => 'марди олим: ранги миёнаи пӯст',
    '👨🏾‍🔬' => 'марди олим: ранги торики миёнаи пӯст',
    '👨🏿‍🔬' => 'марди олим: ранги торики пӯст',
    '👩🏻‍🔬' => 'зани олим: ранги равшани пӯст',
    '👩🏼‍🔬' => 'зани олим: ранги равшании миёнаи пӯст',
    '👩🏽‍🔬' => 'зани олим: ранги миёнаи пӯст',
    '👩🏾‍🔬' => 'зани олим: ранги торики миёнаи пӯст',
    '👩🏿‍🔬' => 'зани олим: ранги торики пӯст',
    '👨🏻‍💻' => 'марди технолог: ранги равшани пӯст',
    '👨🏼‍💻' => 'марди технолог: ранги равшании миёнаи пӯст',
    '👨🏽‍💻' => 'марди технолог: ранги миёнаи пӯст',
    '👨🏾‍💻' => 'марди технолог: ранги торики миёнаи пӯст',
    '👨🏿‍💻' => 'марди технолог: ранги торики пӯст',
    '👩🏻‍💻' => 'зани технолог: ранги равшани пӯст',
    '👩🏼‍💻' => 'зани технолог: ранги равшании миёнаи пӯст',
    '👩🏽‍💻' => 'зани технолог: ранги миёнаи пӯст',
    '👩🏾‍💻' => 'зани технолог: ранги торики миёнаи пӯст',
    '👩🏿‍💻' => 'зани технолог: ранги торики пӯст',
    '👨🏻‍🎤' => 'марди сароянда: ранги равшани пӯст',
    '👨🏼‍🎤' => 'марди сароянда: ранги равшании миёнаи пӯст',
    '👨🏽‍🎤' => 'марди сароянда: ранги миёнаи пӯст',
    '👨🏾‍🎤' => 'марди сароянда: ранги торики миёнаи пӯст',
    '👨🏿‍🎤' => 'марди сароянда: ранги торики пӯст',
    '👩🏻‍🎤' => 'зани сароянда: ранги равшани пӯст',
    '👩🏼‍🎤' => 'зани сароянда: ранги равшании миёнаи пӯст',
    '👩🏽‍🎤' => 'зани сароянда: ранги миёнаи пӯст',
    '👩🏾‍🎤' => 'зани сароянда: ранги торики миёнаи пӯст',
    '👩🏿‍🎤' => 'зани сароянда: ранги торики пӯст',
    '👨🏻‍🎨' => 'марди рассом: ранги равшани пӯст',
    '👨🏼‍🎨' => 'марди рассом: ранги равшании миёнаи пӯст',
    '👨🏽‍🎨' => 'марди рассом: ранги миёнаи пӯст',
    '👨🏾‍🎨' => 'марди рассом: ранги торики миёнаи пӯст',
    '👨🏿‍🎨' => 'марди рассом: ранги торики пӯст',
    '👩🏻‍🎨' => 'зани рассом: ранги равшани пӯст',
    '👩🏼‍🎨' => 'зани рассом: ранги равшании миёнаи пӯст',
    '👩🏽‍🎨' => 'зани рассом: ранги миёнаи пӯст',
    '👩🏾‍🎨' => 'зани рассом: ранги торики миёнаи пӯст',
    '👩🏿‍🎨' => 'зани рассом: ранги торики пӯст',
    '👨🏻‍✈' => 'марди халабон: ранги равшани пӯст',
    '👨🏼‍✈' => 'марди халабон: ранги равшании миёнаи пӯст',
    '👨🏽‍✈' => 'марди халабон: ранги миёнаи пӯст',
    '👨🏾‍✈' => 'марди халабон: ранги торики миёнаи пӯст',
    '👨🏿‍✈' => 'марди халабон: ранги торики пӯст',
    '👩🏻‍✈' => 'зани халабон: ранги равшани пӯст',
    '👩🏼‍✈' => 'зани халабон: ранги равшании миёнаи пӯст',
    '👩🏽‍✈' => 'зани халабон: ранги миёнаи пӯст',
    '👩🏾‍✈' => 'зани халабон: ранги торики миёнаи пӯст',
    '👩🏿‍✈' => 'зани халабон: ранги торики пӯст',
    '👨🏻‍🚀' => 'марди кайҳоннавард: ранги равшани пӯст',
    '👨🏼‍🚀' => 'марди кайҳоннавард: ранги равшании миёнаи пӯст',
    '👨🏽‍🚀' => 'марди кайҳоннавард: ранги миёнаи пӯст',
    '👨🏾‍🚀' => 'марди кайҳоннавард: ранги торики миёнаи пӯст',
    '👨🏿‍🚀' => 'марди кайҳоннавард: ранги торики пӯст',
    '👩🏻‍🚀' => 'зани кайҳоннавард: ранги равшани пӯст',
    '👩🏼‍🚀' => 'зани кайҳоннавард: ранги равшании миёнаи пӯст',
    '👩🏽‍🚀' => 'зани кайҳоннавард: ранги миёнаи пӯст',
    '👩🏾‍🚀' => 'зани кайҳоннавард: ранги торики миёнаи пӯст',
    '👩🏿‍🚀' => 'зани кайҳоннавард: ранги торики пӯст',
    '👨🏻‍🚒' => 'марди сӯхторхомӯшкун: ранги равшани пӯст',
    '👨🏼‍🚒' => 'марди сӯхторхомӯшкун: ранги равшании миёнаи пӯст',
    '👨🏽‍🚒' => 'марди сӯхторхомӯшкун: ранги миёнаи пӯст',
    '👨🏾‍🚒' => 'марди сӯхторхомӯшкун: ранги торики миёнаи пӯст',
    '👨🏿‍🚒' => 'марди сӯхторхомӯшкун: ранги торики пӯст',
    '👩🏻‍🚒' => 'зани сӯхторхомӯшкун: ранги равшани пӯст',
    '👩🏼‍🚒' => 'зани сӯхторхомӯшкун: ранги равшании миёнаи пӯст',
    '👩🏽‍🚒' => 'зани сӯхторхомӯшкун: ранги миёнаи пӯст',
    '👩🏾‍🚒' => 'зани сӯхторхомӯшкун: ранги торики миёнаи пӯст',
    '👩🏿‍🚒' => 'зани сӯхторхомӯшкун: ранги торики пӯст',
    '👮🏻‍♂' => 'марди афсари пулис: ранги равшани пӯст',
    '👮🏼‍♂' => 'марди афсари пулис: ранги равшании миёнаи пӯст',
    '👮🏽‍♂' => 'марди афсари пулис: ранги миёнаи пӯст',
    '👮🏾‍♂' => 'марди афсари пулис: ранги торики миёнаи пӯст',
    '👮🏿‍♂' => 'марди афсари пулис: ранги торики пӯст',
    '👮🏻‍♀' => 'зани афсари пулис: ранги равшани пӯст',
    '👮🏼‍♀' => 'зани афсари пулис: ранги равшании миёнаи пӯст',
    '👮🏽‍♀' => 'зани афсари пулис: ранги миёнаи пӯст',
    '👮🏾‍♀' => 'зани афсари пулис: ранги торики миёнаи пӯст',
    '👮🏿‍♀' => 'зани афсари пулис: ранги торики пӯст',
    '🕵🏻‍♂' => 'марди детектив: ранги равшани пӯст',
    '🕵🏼‍♂' => 'марди детектив: ранги равшании миёнаи пӯст',
    '🕵🏽‍♂' => 'марди детектив: ранги миёнаи пӯст',
    '🕵🏾‍♂' => 'марди детектив: ранги торики миёнаи пӯст',
    '🕵🏿‍♂' => 'марди детектив: ранги торики пӯст',
    '🕵🏻‍♀' => 'зани детектив: ранги равшани пӯст',
    '🕵🏼‍♀' => 'зани детектив: ранги равшании миёнаи пӯст',
    '🕵🏽‍♀' => 'зани детектив: ранги миёнаи пӯст',
    '🕵🏾‍♀' => 'зани детектив: ранги торики миёнаи пӯст',
    '🕵🏿‍♀' => 'зани детектив: ранги торики пӯст',
    '💂🏻‍♂' => 'марди посбон: ранги равшани пӯст',
    '💂🏼‍♂' => 'марди посбон: ранги равшании миёнаи пӯст',
    '💂🏽‍♂' => 'марди посбон: ранги миёнаи пӯст',
    '💂🏾‍♂' => 'марди посбон: ранги торики миёнаи пӯст',
    '💂🏿‍♂' => 'марди посбон: ранги торики пӯст',
    '💂🏻‍♀' => 'зани посбон: ранги равшани пӯст',
    '💂🏼‍♀' => 'зани посбон: ранги равшании миёнаи пӯст',
    '💂🏽‍♀' => 'зани посбон: ранги миёнаи пӯст',
    '💂🏾‍♀' => 'зани посбон: ранги торики миёнаи пӯст',
    '💂🏿‍♀' => 'зани посбон: ранги торики пӯст',
    '👷🏻‍♂' => 'марди коргари сохтмон: ранги равшани пӯст',
    '👷🏼‍♂' => 'марди коргари сохтмон: ранги равшании миёнаи пӯст',
    '👷🏽‍♂' => 'марди коргари сохтмон: ранги миёнаи пӯст',
    '👷🏾‍♂' => 'марди коргари сохтмон: ранги торики миёнаи пӯст',
    '👷🏿‍♂' => 'марди коргари сохтмон: ранги торики пӯст',
    '👷🏻‍♀' => 'зани коргари сохтмон: ранги равшани пӯст',
    '👷🏼‍♀' => 'зани коргари сохтмон: ранги равшании миёнаи пӯст',
    '👷🏽‍♀' => 'зани коргари сохтмон: ранги миёнаи пӯст',
    '👷🏾‍♀' => 'зани коргари сохтмон: ранги торики миёнаи пӯст',
    '👷🏿‍♀' => 'зани коргари сохтмон: ранги торики пӯст',
    '👳🏻‍♂' => 'марде, ки дар сар салла дорад: ранги равшани пӯст',
    '👳🏼‍♂' => 'марде, ки дар сар салла дорад: ранги равшании миёнаи пӯст',
    '👳🏽‍♂' => 'марде, ки дар сар салла дорад: ранги миёнаи пӯст',
    '👳🏾‍♂' => 'марде, ки дар сар салла дорад: ранги торики миёнаи пӯст',
    '👳🏿‍♂' => 'марде, ки дар сар салла дорад: ранги торики пӯст',
    '👳🏻‍♀' => 'зане, ки дар сар салла дорад: ранги равшани пӯст',
    '👳🏼‍♀' => 'зане, ки дар сар салла дорад: ранги равшании миёнаи пӯст',
    '👳🏽‍♀' => 'зане, ки дар сар салла дорад: ранги миёнаи пӯст',
    '👳🏾‍♀' => 'зане, ки дар сар салла дорад: ранги торики миёнаи пӯст',
    '👳🏿‍♀' => 'зане, ки дар сар салла дорад: ранги торики пӯст',
    '🧙🏻‍♂' => 'марди коҳин: ранги равшани пӯст',
    '🧙🏼‍♂' => 'марди коҳин: ранги равшании миёнаи пӯст',
    '🧙🏽‍♂' => 'марди коҳин: ранги миёнаи пӯст',
    '🧙🏾‍♂' => 'марди коҳин: ранги торики миёнаи пӯст',
    '🧙🏿‍♂' => 'марди коҳин: ранги торики пӯст',
    '🧙🏻‍♀' => 'зани коҳин: ранги равшани пӯст',
    '🧙🏼‍♀' => 'зани коҳин: ранги равшании миёнаи пӯст',
    '🧙🏽‍♀' => 'зани коҳин: ранги миёнаи пӯст',
    '🧙🏾‍♀' => 'зани коҳин: ранги торики миёнаи пӯст',
    '🧙🏿‍♀' => 'зани коҳин: ранги торики пӯст',
    '🧚🏻‍♂' => 'парии мард: ранги равшани пӯст',
    '🧚🏼‍♂' => 'парии мард: ранги равшании миёнаи пӯст',
    '🧚🏽‍♂' => 'парии мард: ранги миёнаи пӯст',
    '🧚🏾‍♂' => 'парии мард: ранги торики миёнаи пӯст',
    '🧚🏿‍♂' => 'парии мард: ранги торики пӯст',
    '🧚🏻‍♀' => 'парии зан: ранги равшани пӯст',
    '🧚🏼‍♀' => 'парии зан: ранги равшании миёнаи пӯст',
    '🧚🏽‍♀' => 'парии зан: ранги миёнаи пӯст',
    '🧚🏾‍♀' => 'парии зан: ранги торики миёнаи пӯст',
    '🧚🏿‍♀' => 'парии зан: ранги торики пӯст',
    '🧛🏻‍♂' => 'мардии вампир: ранги равшани пӯст',
    '🧛🏼‍♂' => 'мардии вампир: ранги равшании миёнаи пӯст',
    '🧛🏽‍♂' => 'мардии вампир: ранги миёнаи пӯст',
    '🧛🏾‍♂' => 'мардии вампир: ранги торики миёнаи пӯст',
    '🧛🏿‍♂' => 'мардии вампир: ранги торики пӯст',
    '🧛🏻‍♀' => 'зани вампир: ранги равшани пӯст',
    '🧛🏼‍♀' => 'зани вампир: ранги равшании миёнаи пӯст',
    '🧛🏽‍♀' => 'зани вампир: ранги миёнаи пӯст',
    '🧛🏾‍♀' => 'зани вампир: ранги торики миёнаи пӯст',
    '🧛🏿‍♀' => 'зани вампир: ранги торики пӯст',
    '🧜🏻‍♂' => 'марди обӣ: ранги равшани пӯст',
    '🧜🏼‍♂' => 'марди обӣ: ранги равшании миёнаи пӯст',
    '🧜🏽‍♂' => 'марди обӣ: ранги миёнаи пӯст',
    '🧜🏾‍♂' => 'марди обӣ: ранги торики миёнаи пӯст',
    '🧜🏿‍♂' => 'марди обӣ: ранги торики пӯст',
    '🧜🏻‍♀' => 'парии обӣ: ранги равшани пӯст',
    '🧜🏼‍♀' => 'парии обӣ: ранги равшании миёнаи пӯст',
    '🧜🏽‍♀' => 'парии обӣ: ранги миёнаи пӯст',
    '🧜🏾‍♀' => 'парии обӣ: ранги торики миёнаи пӯст',
    '🧜🏿‍♀' => 'парии обӣ: ранги торики пӯст',
    '🧝🏻‍♂' => 'марди пакана: ранги равшани пӯст',
    '🧝🏼‍♂' => 'марди пакана: ранги равшании миёнаи пӯст',
    '🧝🏽‍♂' => 'марди пакана: ранги миёнаи пӯст',
    '🧝🏾‍♂' => 'марди пакана: ранги торики миёнаи пӯст',
    '🧝🏿‍♂' => 'марди пакана: ранги торики пӯст',
    '🧝🏻‍♀' => 'зани пакана: ранги равшани пӯст',
    '🧝🏼‍♀' => 'зани пакана: ранги равшании миёнаи пӯст',
    '🧝🏽‍♀' => 'зани пакана: ранги миёнаи пӯст',
    '🧝🏾‍♀' => 'зани пакана: ранги торики миёнаи пӯст',
    '🧝🏿‍♀' => 'зани пакана: ранги торики пӯст',
    '💆🏻‍♂' => 'марде, ки паём гирифта истодааст: ранги равшани пӯст',
    '💆🏼‍♂' => 'марде, ки паём гирифта истодааст: ранги равшании миёнаи пӯст',
    '💆🏽‍♂' => 'марде, ки паём гирифта истодааст: ранги миёнаи пӯст',
    '💆🏾‍♂' => 'марде, ки паём гирифта истодааст: ранги торики миёнаи пӯст',
    '💆🏿‍♂' => 'марде, ки паём гирифта истодааст: ранги торики пӯст',
    '💆🏻‍♀' => 'зане, ки паём гирифта истодааст: ранги равшани пӯст',
    '💆🏼‍♀' => 'зане, ки паём гирифта истодааст: ранги равшании миёнаи пӯст',
    '💆🏽‍♀' => 'зане, ки паём гирифта истодааст: ранги миёнаи пӯст',
    '💆🏾‍♀' => 'зане, ки паём гирифта истодааст: ранги торики миёнаи пӯст',
    '💆🏿‍♀' => 'зане, ки паём гирифта истодааст: ранги торики пӯст',
    '💇🏻‍♂' => 'марде, ки мӯи сарашро гирифта истодааст: ранги равшани пӯст',
    '💇🏼‍♂' => 'марде, ки мӯи сарашро гирифта истодааст: ранги равшании миёнаи пӯст',
    '💇🏽‍♂' => 'марде, ки мӯи сарашро гирифта истодааст: ранги миёнаи пӯст',
    '💇🏾‍♂' => 'марде, ки мӯи сарашро гирифта истодааст: ранги торики миёнаи пӯст',
    '💇🏿‍♂' => 'марде, ки мӯи сарашро гирифта истодааст: ранги торики пӯст',
    '💇🏻‍♀' => 'зане, ки мӯи сарашро гирифта истодааст: ранги равшани пӯст',
    '💇🏼‍♀' => 'зане, ки мӯи сарашро гирифта истодааст: ранги равшании миёнаи пӯст',
    '💇🏽‍♀' => 'зане, ки мӯи сарашро гирифта истодааст: ранги миёнаи пӯст',
    '💇🏾‍♀' => 'зане, ки мӯи сарашро гирифта истодааст: ранги торики миёнаи пӯст',
    '💇🏿‍♀' => 'зане, ки мӯи сарашро гирифта истодааст: ранги торики пӯст',
    '🚶🏻‍♂' => 'марде, роҳ гашта истодааст: ранги равшани пӯст',
    '🚶🏼‍♂' => 'марде, роҳ гашта истодааст: ранги равшании миёнаи пӯст',
    '🚶🏽‍♂' => 'марде, роҳ гашта истодааст: ранги миёнаи пӯст',
    '🚶🏾‍♂' => 'марде, роҳ гашта истодааст: ранги торики миёнаи пӯст',
    '🚶🏿‍♂' => 'марде, роҳ гашта истодааст: ранги торики пӯст',
    '🚶🏻‍♀' => 'зане, роҳ гашта истодааст: ранги равшани пӯст',
    '🚶🏼‍♀' => 'зане, роҳ гашта истодааст: ранги равшании миёнаи пӯст',
    '🚶🏽‍♀' => 'зане, роҳ гашта истодааст: ранги миёнаи пӯст',
    '🚶🏾‍♀' => 'зане, роҳ гашта истодааст: ранги торики миёнаи пӯст',
    '🚶🏿‍♀' => 'зане, роҳ гашта истодааст: ранги торики пӯст',
    '🏃🏻‍♂' => 'марде, ки давида истодааст: ранги равшани пӯст',
    '🏃🏼‍♂' => 'марде, ки давида истодааст: ранги равшании миёнаи пӯст',
    '🏃🏽‍♂' => 'марде, ки давида истодааст: ранги миёнаи пӯст',
    '🏃🏾‍♂' => 'марде, ки давида истодааст: ранги торики миёнаи пӯст',
    '🏃🏿‍♂' => 'марде, ки давида истодааст: ранги торики пӯст',
    '🏃🏻‍♀' => 'зане, ки давида истодааст: ранги равшани пӯст',
    '🏃🏼‍♀' => 'зане, ки давида истодааст: ранги равшании миёнаи пӯст',
    '🏃🏽‍♀' => 'зане, ки давида истодааст: ранги миёнаи пӯст',
    '🏃🏾‍♀' => 'зане, ки давида истодааст: ранги торики миёнаи пӯст',
    '🏃🏿‍♀' => 'зане, ки давида истодааст: ранги торики пӯст',
    '👯🏻‍♀' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст',
    '👯🏼‍♀' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст',
    '👯🏽‍♀' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст',
    '👯🏾‍♀' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст',
    '👯🏿‍♀' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст',
    '👯🏻‍♂' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст',
    '👯🏼‍♂' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст',
    '👯🏽‍♂' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст',
    '👯🏾‍♂' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст',
    '👯🏿‍♂' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст',
    '🧖🏻‍♂' => 'марде дар ҳуҷраи буғ: ранги равшани пӯст',
    '🧖🏼‍♂' => 'марде дар ҳуҷраи буғ: ранги равшании миёнаи пӯст',
    '🧖🏽‍♂' => 'марде дар ҳуҷраи буғ: ранги миёнаи пӯст',
    '🧖🏾‍♂' => 'марде дар ҳуҷраи буғ: ранги торики миёнаи пӯст',
    '🧖🏿‍♂' => 'марде дар ҳуҷраи буғ: ранги торики пӯст',
    '🧖🏻‍♀' => 'зане дар ҳуҷраи буғ: ранги равшани пӯст',
    '🧖🏼‍♀' => 'зане дар ҳуҷраи буғ: ранги равшании миёнаи пӯст',
    '🧖🏽‍♀' => 'зане дар ҳуҷраи буғ: ранги миёнаи пӯст',
    '🧖🏾‍♀' => 'зане дар ҳуҷраи буғ: ранги торики миёнаи пӯст',
    '🧖🏿‍♀' => 'зане дар ҳуҷраи буғ: ранги торики пӯст',
    '🧗🏻‍♂' => 'марде, ки баромада истодааст: ранги равшани пӯст',
    '🧗🏼‍♂' => 'марде, ки баромада истодааст: ранги равшании миёнаи пӯст',
    '🧗🏽‍♂' => 'марде, ки баромада истодааст: ранги миёнаи пӯст',
    '🧗🏾‍♂' => 'марде, ки баромада истодааст: ранги торики миёнаи пӯст',
    '🧗🏿‍♂' => 'марде, ки баромада истодааст: ранги торики пӯст',
    '🧗🏻‍♀' => 'зане, ки баромада истодааст: ранги равшани пӯст',
    '🧗🏼‍♀' => 'зане, ки баромада истодааст: ранги равшании миёнаи пӯст',
    '🧗🏽‍♀' => 'зане, ки баромада истодааст: ранги миёнаи пӯст',
    '🧗🏾‍♀' => 'зане, ки баромада истодааст: ранги торики миёнаи пӯст',
    '🧗🏿‍♀' => 'зане, ки баромада истодааст: ранги торики пӯст',
    '🏌🏻‍♂' => 'марде, ки голф бозӣ карда истодааст: ранги равшани пӯст',
    '🏌🏼‍♂' => 'марде, ки голф бозӣ карда истодааст: ранги равшании миёнаи пӯст',
    '🏌🏽‍♂' => 'марде, ки голф бозӣ карда истодааст: ранги миёнаи пӯст',
    '🏌🏾‍♂' => 'марде, ки голф бозӣ карда истодааст: ранги торики миёнаи пӯст',
    '🏌🏿‍♂' => 'марде, ки голф бозӣ карда истодааст: ранги торики пӯст',
    '🏌🏻‍♀' => 'зане, ки голф бозӣ карда истодааст: ранги равшани пӯст',
    '🏌🏼‍♀' => 'зане, ки голф бозӣ карда истодааст: ранги равшании миёнаи пӯст',
    '🏌🏽‍♀' => 'зане, ки голф бозӣ карда истодааст: ранги миёнаи пӯст',
    '🏌🏾‍♀' => 'зане, ки голф бозӣ карда истодааст: ранги торики миёнаи пӯст',
    '🏌🏿‍♀' => 'зане, ки голф бозӣ карда истодааст: ранги торики пӯст',
    '🏄🏻‍♂' => 'марде, ки серфинг карда истодаастмард: ранги равшани пӯст',
    '🏄🏼‍♂' => 'марде, ки серфинг карда истодаастмард: ранги равшании миёнаи пӯст',
    '🏄🏽‍♂' => 'марде, ки серфинг карда истодаастмард: ранги миёнаи пӯст',
    '🏄🏾‍♂' => 'марде, ки серфинг карда истодаастмард: ранги торики миёнаи пӯст',
    '🏄🏿‍♂' => 'марде, ки серфинг карда истодаастмард: ранги торики пӯст',
    '🏄🏻‍♀' => 'зане, ки серфинг карда истодааст: ранги равшани пӯст',
    '🏄🏼‍♀' => 'зане, ки серфинг карда истодааст: ранги равшании миёнаи пӯст',
    '🏄🏽‍♀' => 'зане, ки серфинг карда истодааст: ранги миёнаи пӯст',
    '🏄🏾‍♀' => 'зане, ки серфинг карда истодааст: ранги торики миёнаи пӯст',
    '🏄🏿‍♀' => 'зане, ки серфинг карда истодааст: ранги торики пӯст',
    '🚣🏻‍♂' => 'марди қаиқронӣ карда истода: ранги равшани пӯст',
    '🚣🏼‍♂' => 'марди қаиқронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚣🏽‍♂' => 'марди қаиқронӣ карда истода: ранги миёнаи пӯст',
    '🚣🏾‍♂' => 'марди қаиқронӣ карда истода: ранги торики миёнаи пӯст',
    '🚣🏿‍♂' => 'марди қаиқронӣ карда истода: ранги торики пӯст',
    '🚣🏻‍♀' => 'зани қаиқронӣ карда истода: ранги равшани пӯст',
    '🚣🏼‍♀' => 'зани қаиқронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚣🏽‍♀' => 'зани қаиқронӣ карда истода: ранги миёнаи пӯст',
    '🚣🏾‍♀' => 'зани қаиқронӣ карда истода: ранги торики миёнаи пӯст',
    '🚣🏿‍♀' => 'зани қаиқронӣ карда истода: ранги торики пӯст',
    '🏊🏻‍♂' => 'марди шино карда истода: ранги равшани пӯст',
    '🏊🏼‍♂' => 'марди шино карда истода: ранги равшании миёнаи пӯст',
    '🏊🏽‍♂' => 'марди шино карда истода: ранги миёнаи пӯст',
    '🏊🏾‍♂' => 'марди шино карда истода: ранги торики миёнаи пӯст',
    '🏊🏿‍♂' => 'марди шино карда истода: ранги торики пӯст',
    '🏊🏻‍♀' => 'зани шино карда истода: ранги равшани пӯст',
    '🏊🏼‍♀' => 'зани шино карда истода: ранги равшании миёнаи пӯст',
    '🏊🏽‍♀' => 'зани шино карда истода: ранги миёнаи пӯст',
    '🏊🏾‍♀' => 'зани шино карда истода: ранги торики миёнаи пӯст',
    '🏊🏿‍♀' => 'зани шино карда истода: ранги торики пӯст',
    '⛹🏻‍♂' => 'марде, ки тӯбро ба замин зада истодааст: ранги равшани пӯст',
    '⛹🏼‍♂' => 'марде, ки тӯбро ба замин зада истодааст: ранги равшании миёнаи пӯст',
    '⛹🏽‍♂' => 'марде, ки тӯбро ба замин зада истодааст: ранги миёнаи пӯст',
    '⛹🏾‍♂' => 'марде, ки тӯбро ба замин зада истодааст: ранги торики миёнаи пӯст',
    '⛹🏿‍♂' => 'марде, ки тӯбро ба замин зада истодааст: ранги торики пӯст',
    '⛹🏻‍♀' => 'зане, ки тӯбро ба замин зада истодааст: ранги равшани пӯст',
    '⛹🏼‍♀' => 'зане, ки тӯбро ба замин зада истодааст: ранги равшании миёнаи пӯст',
    '⛹🏽‍♀' => 'зане, ки тӯбро ба замин зада истодааст: ранги миёнаи пӯст',
    '⛹🏾‍♀' => 'зане, ки тӯбро ба замин зада истодааст: ранги торики миёнаи пӯст',
    '⛹🏿‍♀' => 'зане, ки тӯбро ба замин зада истодааст: ранги торики пӯст',
    '🏋🏻‍♂' => 'марде, ки бор мебардорад: ранги равшани пӯст',
    '🏋🏼‍♂' => 'марде, ки бор мебардорад: ранги равшании миёнаи пӯст',
    '🏋🏽‍♂' => 'марде, ки бор мебардорад: ранги миёнаи пӯст',
    '🏋🏾‍♂' => 'марде, ки бор мебардорад: ранги торики миёнаи пӯст',
    '🏋🏿‍♂' => 'марде, ки бор мебардорад: ранги торики пӯст',
    '🏋🏻‍♀' => 'зане, ки бор мебардорад: ранги равшани пӯст',
    '🏋🏼‍♀' => 'зане, ки бор мебардорад: ранги равшании миёнаи пӯст',
    '🏋🏽‍♀' => 'зане, ки бор мебардорад: ранги миёнаи пӯст',
    '🏋🏾‍♀' => 'зане, ки бор мебардорад: ранги торики миёнаи пӯст',
    '🏋🏿‍♀' => 'зане, ки бор мебардорад: ранги торики пӯст',
    '🚴🏻‍♂' => 'марди велосипедронӣ карда истода: ранги равшани пӯст',
    '🚴🏼‍♂' => 'марди велосипедронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚴🏽‍♂' => 'марди велосипедронӣ карда истода: ранги миёнаи пӯст',
    '🚴🏾‍♂' => 'марди велосипедронӣ карда истода: ранги торики миёнаи пӯст',
    '🚴🏿‍♂' => 'марди велосипедронӣ карда истода: ранги торики пӯст',
    '🚴🏻‍♀' => 'зани велосипедронӣ карда истода: ранги равшани пӯст',
    '🚴🏼‍♀' => 'зани велосипедронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚴🏽‍♀' => 'зани велосипедронӣ карда истода: ранги миёнаи пӯст',
    '🚴🏾‍♀' => 'зани велосипедронӣ карда истода: ранги торики миёнаи пӯст',
    '🚴🏿‍♀' => 'зани велосипедронӣ карда истода: ранги торики пӯст',
    '🚵🏻‍♂' => 'марди дар куҳ велосипедронӣ карда истода: ранги равшани пӯст',
    '🚵🏼‍♂' => 'марди дар куҳ велосипедронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚵🏽‍♂' => 'марди дар куҳ велосипедронӣ карда истода: ранги миёнаи пӯст',
    '🚵🏾‍♂' => 'марди дар куҳ велосипедронӣ карда истода: ранги торики миёнаи пӯст',
    '🚵🏿‍♂' => 'марди дар куҳ велосипедронӣ карда истода: ранги торики пӯст',
    '🚵🏻‍♀' => 'зани дар куҳ велосипедронӣ карда истода: ранги равшани пӯст',
    '🚵🏼‍♀' => 'зани дар куҳ велосипедронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚵🏽‍♀' => 'зани дар куҳ велосипедронӣ карда истода: ранги миёнаи пӯст',
    '🚵🏾‍♀' => 'зани дар куҳ велосипедронӣ карда истода: ранги торики миёнаи пӯст',
    '🚵🏿‍♀' => 'зани дар куҳ велосипедронӣ карда истода: ранги торики пӯст',
    '🤸🏻‍♂' => 'марди чарх зада истода: ранги равшани пӯст',
    '🤸🏼‍♂' => 'марди чарх зада истода: ранги равшании миёнаи пӯст',
    '🤸🏽‍♂' => 'марди чарх зада истода: ранги миёнаи пӯст',
    '🤸🏾‍♂' => 'марди чарх зада истода: ранги торики миёнаи пӯст',
    '🤸🏿‍♂' => 'марди чарх зада истода: ранги торики пӯст',
    '🤸🏻‍♀' => 'зани чарх зада истода: ранги равшани пӯст',
    '🤸🏼‍♀' => 'зани чарх зада истода: ранги равшании миёнаи пӯст',
    '🤸🏽‍♀' => 'зани чарх зада истода: ранги миёнаи пӯст',
    '🤸🏾‍♀' => 'зани чарх зада истода: ранги торики миёнаи пӯст',
    '🤸🏿‍♀' => 'зани чарх зада истода: ранги торики пӯст',
    '🤼🏻‍♀' => 'занон гуштингирӣ карда истодаанд: ранги равшани пӯст',
    '🤼🏼‍♀' => 'занон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст',
    '🤼🏽‍♀' => 'занон гуштингирӣ карда истодаанд: ранги миёнаи пӯст',
    '🤼🏾‍♀' => 'занон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст',
    '🤼🏿‍♀' => 'занон гуштингирӣ карда истодаанд: ранги торики пӯст',
    '🤼🏻‍♂' => 'мардон гуштингирӣ карда истодаанд: ранги равшани пӯст',
    '🤼🏼‍♂' => 'мардон гуштингирӣ карда истодаанд: ранги равшании миёнаи пӯст',
    '🤼🏽‍♂' => 'мардон гуштингирӣ карда истодаанд: ранги миёнаи пӯст',
    '🤼🏾‍♂' => 'мардон гуштингирӣ карда истодаанд: ранги торики миёнаи пӯст',
    '🤼🏿‍♂' => 'мардон гуштингирӣ карда истодаанд: ранги торики пӯст',
    '🤽🏻‍♂' => 'марди ватерполо бозӣ карда истода: ранги равшани пӯст',
    '🤽🏼‍♂' => 'марди ватерполо бозӣ карда истода: ранги равшании миёнаи пӯст',
    '🤽🏽‍♂' => 'марди ватерполо бозӣ карда истода: ранги миёнаи пӯст',
    '🤽🏾‍♂' => 'марди ватерполо бозӣ карда истода: ранги торики миёнаи пӯст',
    '🤽🏿‍♂' => 'марди ватерполо бозӣ карда истода: ранги торики пӯст',
    '🤽🏻‍♀' => 'зани ватерполо бозӣ карда истода: ранги равшани пӯст',
    '🤽🏼‍♀' => 'зани ватерполо бозӣ карда истода: ранги равшании миёнаи пӯст',
    '🤽🏽‍♀' => 'зани ватерполо бозӣ карда истода: ранги миёнаи пӯст',
    '🤽🏾‍♀' => 'зани ватерполо бозӣ карда истода: ранги торики миёнаи пӯст',
    '🤽🏿‍♀' => 'зани ватерполо бозӣ карда истода: ранги торики пӯст',
    '🤾🏻‍♂' => 'марди гандбол бозӣ карда истода: ранги равшани пӯст',
    '🤾🏼‍♂' => 'марди гандбол бозӣ карда истода: ранги равшании миёнаи пӯст',
    '🤾🏽‍♂' => 'марди гандбол бозӣ карда истода: ранги миёнаи пӯст',
    '🤾🏾‍♂' => 'марди гандбол бозӣ карда истода: ранги торики миёнаи пӯст',
    '🤾🏿‍♂' => 'марди гандбол бозӣ карда истода: ранги торики пӯст',
    '🤾🏻‍♀' => 'зани гандбол бозӣ карда истода: ранги равшани пӯст',
    '🤾🏼‍♀' => 'зани гандбол бозӣ карда истода: ранги равшании миёнаи пӯст',
    '🤾🏽‍♀' => 'зани гандбол бозӣ карда истода: ранги миёнаи пӯст',
    '🤾🏾‍♀' => 'зани гандбол бозӣ карда истода: ранги торики миёнаи пӯст',
    '🤾🏿‍♀' => 'зани гандбол бозӣ карда истода: ранги торики пӯст',
    '🤹🏻‍♂' => 'марди жонглёрӣ карда истода: ранги равшани пӯст',
    '🤹🏼‍♂' => 'марди жонглёрӣ карда истода: ранги равшании миёнаи пӯст',
    '🤹🏽‍♂' => 'марди жонглёрӣ карда истода: ранги миёнаи пӯст',
    '🤹🏾‍♂' => 'марди жонглёрӣ карда истода: ранги торики миёнаи пӯст',
    '🤹🏿‍♂' => 'марди жонглёрӣ карда истода: ранги торики пӯст',
    '🤹🏻‍♀' => 'зани жонглёрӣ карда истода: ранги равшани пӯст',
    '🤹🏼‍♀' => 'зани жонглёрӣ карда истода: ранги равшании миёнаи пӯст',
    '🤹🏽‍♀' => 'зани жонглёрӣ карда истода: ранги миёнаи пӯст',
    '🤹🏾‍♀' => 'зани жонглёрӣ карда истода: ранги торики миёнаи пӯст',
    '🤹🏿‍♀' => 'зани жонглёрӣ карда истода: ранги торики пӯст',
    '🧘🏻‍♂' => 'марди дар ҳолати лотус: ранги равшани пӯст',
    '🧘🏼‍♂' => 'марди дар ҳолати лотус: ранги равшании миёнаи пӯст',
    '🧘🏽‍♂' => 'марди дар ҳолати лотус: ранги миёнаи пӯст',
    '🧘🏾‍♂' => 'марди дар ҳолати лотус: ранги торики миёнаи пӯст',
    '🧘🏿‍♂' => 'марди дар ҳолати лотус: ранги торики пӯст',
    '🧘🏻‍♀' => 'зани дар ҳолати лотус: ранги равшани пӯст',
    '🧘🏼‍♀' => 'зани дар ҳолати лотус: ранги равшании миёнаи пӯст',
    '🧘🏽‍♀' => 'зани дар ҳолати лотус: ранги миёнаи пӯст',
    '🧘🏾‍♀' => 'зани дар ҳолати лотус: ранги торики миёнаи пӯст',
    '🧘🏿‍♀' => 'зани дар ҳолати лотус: ранги торики пӯст',
    '👨‍👦' => 'оила: мард ва писар',
    '👨‍👧' => 'оила: мард ва духтар',
    '👩‍👦' => 'оила: зан ва писар',
    '👩‍👧' => 'оила: зан ва духтар',
    '👁‍🗨' => 'чашм дар ҳуббоби гуфтугӯ',
    '👱‍♂' => 'марди зардинамӯй',
    '👱‍♀' => 'зани зардинамӯй',
    '🙍‍♂' => 'марде, ки қавоқ андохта истодааст',
    '🙍‍♀' => 'зане, ки қавоқ андохта истодааст',
    '🙎‍♂' => 'марде, ки лабҳояшро каҷ карда истодааст',
    '🙎‍♀' => 'зане, ки лабҳояшро каҷ карда истодааст',
    '🙅‍♂' => 'марде, ки "НЕ" ишора карда истодааст',
    '🙅‍♀' => 'зане, ки "НЕ" ишора карда истодааст',
    '🙆‍♂' => 'марде, ки "ОК" ишора карда истодааст',
    '🙆‍♀' => 'зане, ки "ОК" ишора карда истодааст',
    '💁‍♂' => 'марде, ки бо дасташ ишора карда истодааст',
    '💁‍♀' => 'зане, ки бо дасташ ишора карда истодааст',
    '🙋‍♂' => 'марде, ки дасташро бардошта истодааст',
    '🙋‍♀' => 'зане, ки дасташро бардошта истодааст',
    '🙇‍♂' => 'марде, ки хам шуда истодааст',
    '🙇‍♀' => 'зане, ки хам шуда истодааст',
    '🤦‍♂' => 'марде, ки рӯяшро бо дастонаш пӯшида истодааст',
    '🤦‍♀' => 'зане, ки рӯяшро бо дастонаш пӯшида истодааст',
    '🤷‍♂' => 'марде, ки китф афшонда истодааст',
    '🤷‍♀' => 'зане, ки китф афшонда истодааст',
    '👨‍⚕' => 'марди корманди тандурустӣ',
    '👩‍⚕' => 'зани корманди тандурустӣ',
    '👨‍🎓' => 'марди донишҷӯ',
    '👩‍🎓' => 'зани донишҷӯ',
    '👨‍🏫' => 'марди муаллим',
    '👩‍🏫' => 'зани муаллим',
    '👨‍⚖' => 'марди судя',
    '👩‍⚖' => 'зани судя',
    '👨‍🌾' => 'марди фермер',
    '👩‍🌾' => 'зани фермер',
    '👨‍🍳' => 'марди ошпаз',
    '👩‍🍳' => 'зани ошпаз',
    '👨‍🔧' => 'марди механик',
    '👩‍🔧' => 'зани механик',
    '👨‍🏭' => 'марди коргари фабрика',
    '👩‍🏭' => 'зани коргари фабрика',
    '👨‍💼' => 'марди корманди идора',
    '👩‍💼' => 'зани корманди идора',
    '👨‍🔬' => 'марди олим',
    '👩‍🔬' => 'зани олим',
    '👨‍💻' => 'марди технолог',
    '👩‍💻' => 'зани технолог',
    '👨‍🎤' => 'марди сароянда',
    '👩‍🎤' => 'зани сароянда',
    '👨‍🎨' => 'марди рассом',
    '👩‍🎨' => 'зани рассом',
    '👨‍✈' => 'марди халабон',
    '👩‍✈' => 'зани халабон',
    '👨‍🚀' => 'марди кайҳоннавард',
    '👩‍🚀' => 'зани кайҳоннавард',
    '👨‍🚒' => 'марди сӯхторхомӯшкун',
    '👩‍🚒' => 'зани сӯхторхомӯшкун',
    '👮‍♂' => 'марди афсари пулис',
    '👮‍♀' => 'зани афсари пулис',
    '🕵‍♂' => 'марди детектив',
    '🕵‍♀' => 'зани детектив',
    '💂‍♂' => 'марди посбон',
    '💂‍♀' => 'зани посбон',
    '👷‍♂' => 'марди коргари сохтмон',
    '👷‍♀' => 'зани коргари сохтмон',
    '👳‍♂' => 'марде, ки дар сар салла дорад',
    '👳‍♀' => 'зане, ки дар сар салла дорад',
    '🧙‍♂' => 'марди коҳин',
    '🧙‍♀' => 'зани коҳин',
    '🧚‍♂' => 'парии мард',
    '🧚‍♀' => 'парии зан',
    '🧛‍♂' => 'мардии вампир',
    '🧛‍♀' => 'зани вампир',
    '🧜‍♂' => 'марди обӣ',
    '🧜‍♀' => 'парии обӣ',
    '🧝‍♂' => 'марди пакана',
    '🧝‍♀' => 'зани пакана',
    '🧞‍♂' => 'марди ҷин',
    '🧞‍♀' => 'зани ҷин',
    '🧟‍♂' => 'марди зомби',
    '🧟‍♀' => 'зани зомби',
    '💆‍♂' => 'марде, ки паём гирифта истодааст',
    '💆‍♀' => 'зане, ки паём гирифта истодааст',
    '💇‍♂' => 'марде, ки мӯи сарашро гирифта истодааст',
    '💇‍♀' => 'зане, ки мӯи сарашро гирифта истодааст',
    '🚶‍♂' => 'марде, роҳ гашта истодааст',
    '🚶‍♀' => 'зане, роҳ гашта истодааст',
    '🏃‍♂' => 'марде, ки давида истодааст',
    '🏃‍♀' => 'зане, ки давида истодааст',
    '👯‍♂' => 'мардони бо гӯшҳои харгӯш хурсандӣ карда истода',
    '👯‍♀' => 'занони бо гӯшҳои харгӯш хурсандӣ карда истода',
    '🧖‍♂' => 'марде дар ҳуҷраи буғ',
    '🧖‍♀' => 'зане дар ҳуҷраи буғ',
    '🧗‍♂' => 'марде, ки баромада истодааст',
    '🧗‍♀' => 'зане, ки баромада истодааст',
    '🏌‍♂' => 'марде, ки голф бозӣ карда истодааст',
    '🏌‍♀' => 'зане, ки голф бозӣ карда истодааст',
    '🏄‍♂' => 'марде, ки серфинг карда истодаастмард',
    '🏄‍♀' => 'зане, ки серфинг карда истодааст',
    '🚣‍♂' => 'марди қаиқронӣ карда истода',
    '🚣‍♀' => 'зани қаиқронӣ карда истода',
    '🏊‍♂' => 'марди шино карда истода',
    '🏊‍♀' => 'зани шино карда истода',
    '⛹‍♂' => 'марде, ки тӯбро ба замин зада истодааст',
    '⛹‍♀' => 'зане, ки тӯбро ба замин зада истодааст',
    '🏋‍♂' => 'марде, ки бор мебардорад',
    '🏋‍♀' => 'зане, ки бор мебардорад',
    '🚴‍♂' => 'марди велосипедронӣ карда истода',
    '🚴‍♀' => 'зани велосипедронӣ карда истода',
    '🚵‍♂' => 'марди дар куҳ велосипедронӣ карда истода',
    '🚵‍♀' => 'зани дар куҳ велосипедронӣ карда истода',
    '🤸‍♂' => 'марди чарх зада истода',
    '🤸‍♀' => 'зани чарх зада истода',
    '🤼‍♂' => 'мардон гуштингирӣ карда истодаанд',
    '🤼‍♀' => 'занон гуштингирӣ карда истодаанд',
    '🤽‍♂' => 'марди ватерполо бозӣ карда истода',
    '🤽‍♀' => 'зани ватерполо бозӣ карда истода',
    '🤾‍♂' => 'марди гандбол бозӣ карда истода',
    '🤾‍♀' => 'зани гандбол бозӣ карда истода',
    '🤹‍♂' => 'марди жонглёрӣ карда истода',
    '🤹‍♀' => 'зани жонглёрӣ карда истода',
    '🧘‍♂' => 'марди дар ҳолати лотус',
    '🧘‍♀' => 'зани дар ҳолати лотус',
    '🏳‍🌈' => 'байрақи тирукамон',
    '👋🏻' => 'ҳаракати пешу қафои даст: ранги равшани пӯст',
    '👋🏼' => 'ҳаракати пешу қафои даст: ранги равшании миёнаи пӯст',
    '👋🏽' => 'ҳаракати пешу қафои даст: ранги миёнаи пӯст',
    '👋🏾' => 'ҳаракати пешу қафои даст: ранги торики миёнаи пӯст',
    '👋🏿' => 'ҳаракати пешу қафои даст: ранги торики пӯст',
    '🤚🏻' => 'пушти дасти бардошташуда: ранги равшани пӯст',
    '🤚🏼' => 'пушти дасти бардошташуда: ранги равшании миёнаи пӯст',
    '🤚🏽' => 'пушти дасти бардошташуда: ранги миёнаи пӯст',
    '🤚🏾' => 'пушти дасти бардошташуда: ранги торики миёнаи пӯст',
    '🤚🏿' => 'пушти дасти бардошташуда: ранги торики пӯст',
    '🖐🏻' => 'дасти бардошта бо ангуштони паҳнкарда: ранги равшани пӯст',
    '🖐🏼' => 'дасти бардошта бо ангуштони паҳнкарда: ранги равшании миёнаи пӯст',
    '🖐🏽' => 'дасти бардошта бо ангуштони паҳнкарда: ранги миёнаи пӯст',
    '🖐🏾' => 'дасти бардошта бо ангуштони паҳнкарда: ранги торики миёнаи пӯст',
    '🖐🏿' => 'дасти бардошта бо ангуштони паҳнкарда: ранги торики пӯст',
    '✋🏻' => 'дасти бардошта: ранги равшани пӯст',
    '✋🏼' => 'дасти бардошта: ранги равшании миёнаи пӯст',
    '✋🏽' => 'дасти бардошта: ранги миёнаи пӯст',
    '✋🏾' => 'дасти бардошта: ранги торики миёнаи пӯст',
    '✋🏿' => 'дасти бардошта: ранги торики пӯст',
    '🖖🏻' => 'саломдиҳии вулқонӣ: ранги равшани пӯст',
    '🖖🏼' => 'саломдиҳии вулқонӣ: ранги равшании миёнаи пӯст',
    '🖖🏽' => 'саломдиҳии вулқонӣ: ранги миёнаи пӯст',
    '🖖🏾' => 'саломдиҳии вулқонӣ: ранги торики миёнаи пӯст',
    '🖖🏿' => 'саломдиҳии вулқонӣ: ранги торики пӯст',
    '👌🏻' => 'Дасти ОК: ранги равшани пӯст',
    '👌🏼' => 'Дасти ОК: ранги равшании миёнаи пӯст',
    '👌🏽' => 'Дасти ОК: ранги миёнаи пӯст',
    '👌🏾' => 'Дасти ОК: ранги торики миёнаи пӯст',
    '👌🏿' => 'Дасти ОК: ранги торики пӯст',
    '✌🏻' => 'дасти зафар: ранги равшани пӯст',
    '✌🏼' => 'дасти зафар: ранги равшании миёнаи пӯст',
    '✌🏽' => 'дасти зафар: ранги миёнаи пӯст',
    '✌🏾' => 'дасти зафар: ранги торики миёнаи пӯст',
    '✌🏿' => 'дасти зафар: ранги торики пӯст',
    '🤞🏻' => 'ангуштони ба ҳам гузошташуда: ранги равшани пӯст',
    '🤞🏼' => 'ангуштони ба ҳам гузошташуда: ранги равшании миёнаи пӯст',
    '🤞🏽' => 'ангуштони ба ҳам гузошташуда: ранги миёнаи пӯст',
    '🤞🏾' => 'ангуштони ба ҳам гузошташуда: ранги торики миёнаи пӯст',
    '🤞🏿' => 'ангуштони ба ҳам гузошташуда: ранги торики пӯст',
    '🤟🏻' => 'имову ишораи "Туро дӯст медорам": ранги равшани пӯст',
    '🤟🏼' => 'имову ишораи "Туро дӯст медорам": ранги равшании миёнаи пӯст',
    '🤟🏽' => 'имову ишораи "Туро дӯст медорам": ранги миёнаи пӯст',
    '🤟🏾' => 'имову ишораи "Туро дӯст медорам": ранги торики миёнаи пӯст',
    '🤟🏿' => 'имову ишораи "Туро дӯст медорам": ранги торики пӯст',
    '🤘🏻' => 'ишораи шохҳо: ранги равшани пӯст',
    '🤘🏼' => 'ишораи шохҳо: ранги равшании миёнаи пӯст',
    '🤘🏽' => 'ишораи шохҳо: ранги миёнаи пӯст',
    '🤘🏾' => 'ишораи шохҳо: ранги торики миёнаи пӯст',
    '🤘🏿' => 'ишораи шохҳо: ранги торики пӯст',
    '🤙🏻' => 'ба ман занг занед: ранги равшани пӯст',
    '🤙🏼' => 'ба ман занг занед: ранги равшании миёнаи пӯст',
    '🤙🏽' => 'ба ман занг занед: ранги миёнаи пӯст',
    '🤙🏾' => 'ба ман занг занед: ранги торики миёнаи пӯст',
    '🤙🏿' => 'ба ман занг занед: ранги торики пӯст',
    '👈🏻' => 'ангушти ишорат ба тарафи чап ишора карда истода: ранги равшани пӯст',
    '👈🏼' => 'ангушти ишорат ба тарафи чап ишора карда истода: ранги равшании миёнаи пӯст',
    '👈🏽' => 'ангушти ишорат ба тарафи чап ишора карда истода: ранги миёнаи пӯст',
    '👈🏾' => 'ангушти ишорат ба тарафи чап ишора карда истода: ранги торики миёнаи пӯст',
    '👈🏿' => 'ангушти ишорат ба тарафи чап ишора карда истода: ранги торики пӯст',
    '👉🏻' => 'ангушти ишорат ба тарафи рост ишора карда истода: ранги равшани пӯст',
    '👉🏼' => 'ангушти ишорат ба тарафи рост ишора карда истода: ранги равшании миёнаи пӯст',
    '👉🏽' => 'ангушти ишорат ба тарафи рост ишора карда истода: ранги миёнаи пӯст',
    '👉🏾' => 'ангушти ишорат ба тарафи рост ишора карда истода: ранги торики миёнаи пӯст',
    '👉🏿' => 'ангушти ишорат ба тарафи рост ишора карда истода: ранги торики пӯст',
    '👆🏻' => 'пушти даст ангушти ишорат ба боло ишора карда истода: ранги равшани пӯст',
    '👆🏼' => 'пушти даст ангушти ишорат ба боло ишора карда истода: ранги равшании миёнаи пӯст',
    '👆🏽' => 'пушти даст ангушти ишорат ба боло ишора карда истода: ранги миёнаи пӯст',
    '👆🏾' => 'пушти даст ангушти ишорат ба боло ишора карда истода: ранги торики миёнаи пӯст',
    '👆🏿' => 'пушти даст ангушти ишорат ба боло ишора карда истода: ранги торики пӯст',
    '🖕🏻' => 'ангушти байн: ранги равшани пӯст',
    '🖕🏼' => 'ангушти байн: ранги равшании миёнаи пӯст',
    '🖕🏽' => 'ангушти байн: ранги миёнаи пӯст',
    '🖕🏾' => 'ангушти байн: ранги торики миёнаи пӯст',
    '🖕🏿' => 'ангушти байн: ранги торики пӯст',
    '👇🏻' => 'ангушти ишорат ба поён ишора карда истода: ранги равшани пӯст',
    '👇🏼' => 'ангушти ишорат ба поён ишора карда истода: ранги равшании миёнаи пӯст',
    '👇🏽' => 'ангушти ишорат ба поён ишора карда истода: ранги миёнаи пӯст',
    '👇🏾' => 'ангушти ишорат ба поён ишора карда истода: ранги торики миёнаи пӯст',
    '👇🏿' => 'ангушти ишорат ба поён ишора карда истода: ранги торики пӯст',
    '☝🏻' => 'ангушти ишорат ба боло ишора карда истода: ранги равшани пӯст',
    '☝🏼' => 'ангушти ишорат ба боло ишора карда истода: ранги равшании миёнаи пӯст',
    '☝🏽' => 'ангушти ишорат ба боло ишора карда истода: ранги миёнаи пӯст',
    '☝🏾' => 'ангушти ишорат ба боло ишора карда истода: ранги торики миёнаи пӯст',
    '☝🏿' => 'ангушти ишорат ба боло ишора карда истода: ранги торики пӯст',
    '👍🏻' => 'хуб: ранги равшани пӯст',
    '👍🏼' => 'хуб: ранги равшании миёнаи пӯст',
    '👍🏽' => 'хуб: ранги миёнаи пӯст',
    '👍🏾' => 'хуб: ранги торики миёнаи пӯст',
    '👍🏿' => 'хуб: ранги торики пӯст',
    '👎🏻' => 'бад: ранги равшани пӯст',
    '👎🏼' => 'бад: ранги равшании миёнаи пӯст',
    '👎🏽' => 'бад: ранги миёнаи пӯст',
    '👎🏾' => 'бад: ранги торики миёнаи пӯст',
    '👎🏿' => 'бад: ранги торики пӯст',
    '✊🏻' => 'мушти бардошта: ранги равшани пӯст',
    '✊🏼' => 'мушти бардошта: ранги равшании миёнаи пӯст',
    '✊🏽' => 'мушти бардошта: ранги миёнаи пӯст',
    '✊🏾' => 'мушти бардошта: ранги торики миёнаи пӯст',
    '✊🏿' => 'мушти бардошта: ранги торики пӯст',
    '👊🏻' => 'мушти муқобил: ранги равшани пӯст',
    '👊🏼' => 'мушти муқобил: ранги равшании миёнаи пӯст',
    '👊🏽' => 'мушти муқобил: ранги миёнаи пӯст',
    '👊🏾' => 'мушти муқобил: ранги торики миёнаи пӯст',
    '👊🏿' => 'мушти муқобил: ранги торики пӯст',
    '🤛🏻' => 'мушт аз тарафи чап: ранги равшани пӯст',
    '🤛🏼' => 'мушт аз тарафи чап: ранги равшании миёнаи пӯст',
    '🤛🏽' => 'мушт аз тарафи чап: ранги миёнаи пӯст',
    '🤛🏾' => 'мушт аз тарафи чап: ранги торики миёнаи пӯст',
    '🤛🏿' => 'мушт аз тарафи чап: ранги торики пӯст',
    '🤜🏻' => 'мушти тарафи рост: ранги равшани пӯст',
    '🤜🏼' => 'мушти тарафи рост: ранги равшании миёнаи пӯст',
    '🤜🏽' => 'мушти тарафи рост: ранги миёнаи пӯст',
    '🤜🏾' => 'мушти тарафи рост: ранги торики миёнаи пӯст',
    '🤜🏿' => 'мушти тарафи рост: ранги торики пӯст',
    '👏🏻' => 'дастҳои қарсакзананда: ранги равшани пӯст',
    '👏🏼' => 'дастҳои қарсакзананда: ранги равшании миёнаи пӯст',
    '👏🏽' => 'дастҳои қарсакзананда: ранги миёнаи пӯст',
    '👏🏾' => 'дастҳои қарсакзананда: ранги торики миёнаи пӯст',
    '👏🏿' => 'дастҳои қарсакзананда: ранги торики пӯст',
    '🙌🏻' => 'дастҳои бардоштаистода: ранги равшани пӯст',
    '🙌🏼' => 'дастҳои бардоштаистода: ранги равшании миёнаи пӯст',
    '🙌🏽' => 'дастҳои бардоштаистода: ранги миёнаи пӯст',
    '🙌🏾' => 'дастҳои бардоштаистода: ранги торики миёнаи пӯст',
    '🙌🏿' => 'дастҳои бардоштаистода: ранги торики пӯст',
    '👐🏻' => 'дастҳои кушода: ранги равшани пӯст',
    '👐🏼' => 'дастҳои кушода: ранги равшании миёнаи пӯст',
    '👐🏽' => 'дастҳои кушода: ранги миёнаи пӯст',
    '👐🏾' => 'дастҳои кушода: ранги торики миёнаи пӯст',
    '👐🏿' => 'дастҳои кушода: ранги торики пӯст',
    '🤲🏻' => 'дастҳо якҷоя боло: ранги равшани пӯст',
    '🤲🏼' => 'дастҳо якҷоя боло: ранги равшании миёнаи пӯст',
    '🤲🏽' => 'дастҳо якҷоя боло: ранги миёнаи пӯст',
    '🤲🏾' => 'дастҳо якҷоя боло: ранги торики миёнаи пӯст',
    '🤲🏿' => 'дастҳо якҷоя боло: ранги торики пӯст',
    '🤝🏻' => 'дастфишӯрӣ: ранги равшани пӯст',
    '🤝🏼' => 'дастфишӯрӣ: ранги равшании миёнаи пӯст',
    '🤝🏽' => 'дастфишӯрӣ: ранги миёнаи пӯст',
    '🤝🏾' => 'дастфишӯрӣ: ранги торики миёнаи пӯст',
    '🤝🏿' => 'дастфишӯрӣ: ранги торики пӯст',
    '🙏🏻' => 'дастҳои қат кардашуда: ранги равшани пӯст',
    '🙏🏼' => 'дастҳои қат кардашуда: ранги равшании миёнаи пӯст',
    '🙏🏽' => 'дастҳои қат кардашуда: ранги миёнаи пӯст',
    '🙏🏾' => 'дастҳои қат кардашуда: ранги торики миёнаи пӯст',
    '🙏🏿' => 'дастҳои қат кардашуда: ранги торики пӯст',
    '✍🏻' => 'дасти навишта истода: ранги равшани пӯст',
    '✍🏼' => 'дасти навишта истода: ранги равшании миёнаи пӯст',
    '✍🏽' => 'дасти навишта истода: ранги миёнаи пӯст',
    '✍🏾' => 'дасти навишта истода: ранги торики миёнаи пӯст',
    '✍🏿' => 'дасти навишта истода: ранги торики пӯст',
    '💅🏻' => 'лок барои нохунҳо: ранги равшани пӯст',
    '💅🏼' => 'лок барои нохунҳо: ранги равшании миёнаи пӯст',
    '💅🏽' => 'лок барои нохунҳо: ранги миёнаи пӯст',
    '💅🏾' => 'лок барои нохунҳо: ранги торики миёнаи пӯст',
    '💅🏿' => 'лок барои нохунҳо: ранги торики пӯст',
    '🤳🏻' => 'селфи: ранги равшани пӯст',
    '🤳🏼' => 'селфи: ранги равшании миёнаи пӯст',
    '🤳🏽' => 'селфи: ранги миёнаи пӯст',
    '🤳🏾' => 'селфи: ранги торики миёнаи пӯст',
    '🤳🏿' => 'селфи: ранги торики пӯст',
    '💪🏻' => 'мушаки битсепси қат кардашуда: ранги равшани пӯст',
    '💪🏼' => 'мушаки битсепси қат кардашуда: ранги равшании миёнаи пӯст',
    '💪🏽' => 'мушаки битсепси қат кардашуда: ранги миёнаи пӯст',
    '💪🏾' => 'мушаки битсепси қат кардашуда: ранги торики миёнаи пӯст',
    '💪🏿' => 'мушаки битсепси қат кардашуда: ранги торики пӯст',
    '👂🏻' => 'гуш: ранги равшани пӯст',
    '👂🏼' => 'гуш: ранги равшании миёнаи пӯст',
    '👂🏽' => 'гуш: ранги миёнаи пӯст',
    '👂🏾' => 'гуш: ранги торики миёнаи пӯст',
    '👂🏿' => 'гуш: ранги торики пӯст',
    '👃🏻' => 'бинӣ: ранги равшани пӯст',
    '👃🏼' => 'бинӣ: ранги равшании миёнаи пӯст',
    '👃🏽' => 'бинӣ: ранги миёнаи пӯст',
    '👃🏾' => 'бинӣ: ранги торики миёнаи пӯст',
    '👃🏿' => 'бинӣ: ранги торики пӯст',
    '👶🏻' => 'тифл: ранги равшани пӯст',
    '👶🏼' => 'тифл: ранги равшании миёнаи пӯст',
    '👶🏽' => 'тифл: ранги миёнаи пӯст',
    '👶🏾' => 'тифл: ранги торики миёнаи пӯст',
    '👶🏿' => 'тифл: ранги торики пӯст',
    '🧒🏻' => 'кӯдак: ранги равшани пӯст',
    '🧒🏼' => 'кӯдак: ранги равшании миёнаи пӯст',
    '🧒🏽' => 'кӯдак: ранги миёнаи пӯст',
    '🧒🏾' => 'кӯдак: ранги торики миёнаи пӯст',
    '🧒🏿' => 'кӯдак: ранги торики пӯст',
    '👦🏻' => 'писар: ранги равшани пӯст',
    '👦🏼' => 'писар: ранги равшании миёнаи пӯст',
    '👦🏽' => 'писар: ранги миёнаи пӯст',
    '👦🏾' => 'писар: ранги торики миёнаи пӯст',
    '👦🏿' => 'писар: ранги торики пӯст',
    '👧🏻' => 'духтар: ранги равшани пӯст',
    '👧🏼' => 'духтар: ранги равшании миёнаи пӯст',
    '👧🏽' => 'духтар: ранги миёнаи пӯст',
    '👧🏾' => 'духтар: ранги торики миёнаи пӯст',
    '👧🏿' => 'духтар: ранги торики пӯст',
    '🧑🏻' => 'калонсол: ранги равшани пӯст',
    '🧑🏼' => 'калонсол: ранги равшании миёнаи пӯст',
    '🧑🏽' => 'калонсол: ранги миёнаи пӯст',
    '🧑🏾' => 'калонсол: ранги торики миёнаи пӯст',
    '🧑🏿' => 'калонсол: ранги торики пӯст',
    '👱🏻' => 'шахси зардинамӯй: ранги равшани пӯст',
    '👱🏼' => 'шахси зардинамӯй: ранги равшании миёнаи пӯст',
    '👱🏽' => 'шахси зардинамӯй: ранги миёнаи пӯст',
    '👱🏾' => 'шахси зардинамӯй: ранги торики миёнаи пӯст',
    '👱🏿' => 'шахси зардинамӯй: ранги торики пӯст',
    '👨🏻' => 'мард: ранги равшани пӯст',
    '👨🏼' => 'мард: ранги равшании миёнаи пӯст',
    '👨🏽' => 'мард: ранги миёнаи пӯст',
    '👨🏾' => 'мард: ранги торики миёнаи пӯст',
    '👨🏿' => 'мард: ранги торики пӯст',
    '🧔🏻' => 'шахси ришдор: ранги равшани пӯст',
    '🧔🏼' => 'шахси ришдор: ранги равшании миёнаи пӯст',
    '🧔🏽' => 'шахси ришдор: ранги миёнаи пӯст',
    '🧔🏾' => 'шахси ришдор: ранги торики миёнаи пӯст',
    '🧔🏿' => 'шахси ришдор: ранги торики пӯст',
    '👩🏻' => 'зан: ранги равшани пӯст',
    '👩🏼' => 'зан: ранги равшании миёнаи пӯст',
    '👩🏽' => 'зан: ранги миёнаи пӯст',
    '👩🏾' => 'зан: ранги торики миёнаи пӯст',
    '👩🏿' => 'зан: ранги торики пӯст',
    '🧓🏻' => 'калонсоли пир: ранги равшани пӯст',
    '🧓🏼' => 'калонсоли пир: ранги равшании миёнаи пӯст',
    '🧓🏽' => 'калонсоли пир: ранги миёнаи пӯст',
    '🧓🏾' => 'калонсоли пир: ранги торики миёнаи пӯст',
    '🧓🏿' => 'калонсоли пир: ранги торики пӯст',
    '👴🏻' => 'марди пир: ранги равшани пӯст',
    '👴🏼' => 'марди пир: ранги равшании миёнаи пӯст',
    '👴🏽' => 'марди пир: ранги миёнаи пӯст',
    '👴🏾' => 'марди пир: ранги торики миёнаи пӯст',
    '👴🏿' => 'марди пир: ранги торики пӯст',
    '👵🏻' => 'зани пир: ранги равшани пӯст',
    '👵🏼' => 'зани пир: ранги равшании миёнаи пӯст',
    '👵🏽' => 'зани пир: ранги миёнаи пӯст',
    '👵🏾' => 'зани пир: ранги торики миёнаи пӯст',
    '👵🏿' => 'зани пир: ранги торики пӯст',
    '🙍🏻' => 'шахсе, ки қавоқ андохта истодааст: ранги равшани пӯст',
    '🙍🏼' => 'шахсе, ки қавоқ андохта истодааст: ранги равшании миёнаи пӯст',
    '🙍🏽' => 'шахсе, ки қавоқ андохта истодааст: ранги миёнаи пӯст',
    '🙍🏾' => 'шахсе, ки қавоқ андохта истодааст: ранги торики миёнаи пӯст',
    '🙍🏿' => 'шахсе, ки қавоқ андохта истодааст: ранги торики пӯст',
    '🙎🏻' => 'шахсе, ки лабҳояшро каҷ карда истодааст: ранги равшани пӯст',
    '🙎🏼' => 'шахсе, ки лабҳояшро каҷ карда истодааст: ранги равшании миёнаи пӯст',
    '🙎🏽' => 'шахсе, ки лабҳояшро каҷ карда истодааст: ранги миёнаи пӯст',
    '🙎🏾' => 'шахсе, ки лабҳояшро каҷ карда истодааст: ранги торики миёнаи пӯст',
    '🙎🏿' => 'шахсе, ки лабҳояшро каҷ карда истодааст: ранги торики пӯст',
    '🙅🏻' => 'шахсе, ки "НЕ" ишора карда истодааст: ранги равшани пӯст',
    '🙅🏼' => 'шахсе, ки "НЕ" ишора карда истодааст: ранги равшании миёнаи пӯст',
    '🙅🏽' => 'шахсе, ки "НЕ" ишора карда истодааст: ранги миёнаи пӯст',
    '🙅🏾' => 'шахсе, ки "НЕ" ишора карда истодааст: ранги торики миёнаи пӯст',
    '🙅🏿' => 'шахсе, ки "НЕ" ишора карда истодааст: ранги торики пӯст',
    '🙆🏻' => 'шахсе, ки "ОК" ишора карда истодааст: ранги равшани пӯст',
    '🙆🏼' => 'шахсе, ки "ОК" ишора карда истодааст: ранги равшании миёнаи пӯст',
    '🙆🏽' => 'шахсе, ки "ОК" ишора карда истодааст: ранги миёнаи пӯст',
    '🙆🏾' => 'шахсе, ки "ОК" ишора карда истодааст: ранги торики миёнаи пӯст',
    '🙆🏿' => 'шахсе, ки "ОК" ишора карда истодааст: ранги торики пӯст',
    '💁🏻' => 'шахсе, ки бо дасташ ишора карда истодааст: ранги равшани пӯст',
    '💁🏼' => 'шахсе, ки бо дасташ ишора карда истодааст: ранги равшании миёнаи пӯст',
    '💁🏽' => 'шахсе, ки бо дасташ ишора карда истодааст: ранги миёнаи пӯст',
    '💁🏾' => 'шахсе, ки бо дасташ ишора карда истодааст: ранги торики миёнаи пӯст',
    '💁🏿' => 'шахсе, ки бо дасташ ишора карда истодааст: ранги торики пӯст',
    '🙋🏻' => 'шахсе, ки дасташро бардошта истодааст: ранги равшани пӯст',
    '🙋🏼' => 'шахсе, ки дасташро бардошта истодааст: ранги равшании миёнаи пӯст',
    '🙋🏽' => 'шахсе, ки дасташро бардошта истодааст: ранги миёнаи пӯст',
    '🙋🏾' => 'шахсе, ки дасташро бардошта истодааст: ранги торики миёнаи пӯст',
    '🙋🏿' => 'шахсе, ки дасташро бардошта истодааст: ранги торики пӯст',
    '🙇🏻' => 'шахсе, ки хам шуда истодааст: ранги равшани пӯст',
    '🙇🏼' => 'шахсе, ки хам шуда истодааст: ранги равшании миёнаи пӯст',
    '🙇🏽' => 'шахсе, ки хам шуда истодааст: ранги миёнаи пӯст',
    '🙇🏾' => 'шахсе, ки хам шуда истодааст: ранги торики миёнаи пӯст',
    '🙇🏿' => 'шахсе, ки хам шуда истодааст: ранги торики пӯст',
    '🤦🏻' => 'шахсе, ки рӯяшро бо дастонаш пӯшида истодааст: ранги равшани пӯст',
    '🤦🏼' => 'шахсе, ки рӯяшро бо дастонаш пӯшида истодааст: ранги равшании миёнаи пӯст',
    '🤦🏽' => 'шахсе, ки рӯяшро бо дастонаш пӯшида истодааст: ранги миёнаи пӯст',
    '🤦🏾' => 'шахсе, ки рӯяшро бо дастонаш пӯшида истодааст: ранги торики миёнаи пӯст',
    '🤦🏿' => 'шахсе, ки рӯяшро бо дастонаш пӯшида истодааст: ранги торики пӯст',
    '🤷🏻' => 'шахсе, ки китф афшонда истодааст: ранги равшани пӯст',
    '🤷🏼' => 'шахсе, ки китф афшонда истодааст: ранги равшании миёнаи пӯст',
    '🤷🏽' => 'шахсе, ки китф афшонда истодааст: ранги миёнаи пӯст',
    '🤷🏾' => 'шахсе, ки китф афшонда истодааст: ранги торики миёнаи пӯст',
    '🤷🏿' => 'шахсе, ки китф афшонда истодааст: ранги торики пӯст',
    '👮🏻' => 'афсари пулис: ранги равшани пӯст',
    '👮🏼' => 'афсари пулис: ранги равшании миёнаи пӯст',
    '👮🏽' => 'афсари пулис: ранги миёнаи пӯст',
    '👮🏾' => 'афсари пулис: ранги торики миёнаи пӯст',
    '👮🏿' => 'афсари пулис: ранги торики пӯст',
    '🕵🏻' => 'детектив: ранги равшани пӯст',
    '🕵🏼' => 'детектив: ранги равшании миёнаи пӯст',
    '🕵🏽' => 'детектив: ранги миёнаи пӯст',
    '🕵🏾' => 'детектив: ранги торики миёнаи пӯст',
    '🕵🏿' => 'детектив: ранги торики пӯст',
    '💂🏻' => 'посбон: ранги равшани пӯст',
    '💂🏼' => 'посбон: ранги равшании миёнаи пӯст',
    '💂🏽' => 'посбон: ранги миёнаи пӯст',
    '💂🏾' => 'посбон: ранги торики миёнаи пӯст',
    '💂🏿' => 'посбон: ранги торики пӯст',
    '👷🏻' => 'коргари сохтмон: ранги равшани пӯст',
    '👷🏼' => 'коргари сохтмон: ранги равшании миёнаи пӯст',
    '👷🏽' => 'коргари сохтмон: ранги миёнаи пӯст',
    '👷🏾' => 'коргари сохтмон: ранги торики миёнаи пӯст',
    '👷🏿' => 'коргари сохтмон: ранги торики пӯст',
    '🤴🏻' => 'шоҳзода: ранги равшани пӯст',
    '🤴🏼' => 'шоҳзода: ранги равшании миёнаи пӯст',
    '🤴🏽' => 'шоҳзода: ранги миёнаи пӯст',
    '🤴🏾' => 'шоҳзода: ранги торики миёнаи пӯст',
    '🤴🏿' => 'шоҳзода: ранги торики пӯст',
    '👸🏻' => 'шоҳдухтар: ранги равшани пӯст',
    '👸🏼' => 'шоҳдухтар: ранги равшании миёнаи пӯст',
    '👸🏽' => 'шоҳдухтар: ранги миёнаи пӯст',
    '👸🏾' => 'шоҳдухтар: ранги торики миёнаи пӯст',
    '👸🏿' => 'шоҳдухтар: ранги торики пӯст',
    '👳🏻' => 'шахсе, ки дар сар салла дорад: ранги равшани пӯст',
    '👳🏼' => 'шахсе, ки дар сар салла дорад: ранги равшании миёнаи пӯст',
    '👳🏽' => 'шахсе, ки дар сар салла дорад: ранги миёнаи пӯст',
    '👳🏾' => 'шахсе, ки дар сар салла дорад: ранги торики миёнаи пӯст',
    '👳🏿' => 'шахсе, ки дар сар салла дорад: ранги торики пӯст',
    '👲🏻' => 'мард бо сарпӯши хитоӣ: ранги равшани пӯст',
    '👲🏼' => 'мард бо сарпӯши хитоӣ: ранги равшании миёнаи пӯст',
    '👲🏽' => 'мард бо сарпӯши хитоӣ: ранги миёнаи пӯст',
    '👲🏾' => 'мард бо сарпӯши хитоӣ: ранги торики миёнаи пӯст',
    '👲🏿' => 'мард бо сарпӯши хитоӣ: ранги торики пӯст',
    '🧕🏻' => 'зан бо рӯймол: ранги равшани пӯст',
    '🧕🏼' => 'зан бо рӯймол: ранги равшании миёнаи пӯст',
    '🧕🏽' => 'зан бо рӯймол: ранги миёнаи пӯст',
    '🧕🏾' => 'зан бо рӯймол: ранги торики миёнаи пӯст',
    '🧕🏿' => 'зан бо рӯймол: ранги торики пӯст',
    '🤵🏻' => 'мард бо смокинг: ранги равшани пӯст',
    '🤵🏼' => 'мард бо смокинг: ранги равшании миёнаи пӯст',
    '🤵🏽' => 'мард бо смокинг: ранги миёнаи пӯст',
    '🤵🏾' => 'мард бо смокинг: ранги торики миёнаи пӯст',
    '🤵🏿' => 'мард бо смокинг: ранги торики пӯст',
    '👰🏻' => 'арӯс бо сарандоз: ранги равшани пӯст',
    '👰🏼' => 'арӯс бо сарандоз: ранги равшании миёнаи пӯст',
    '👰🏽' => 'арӯс бо сарандоз: ранги миёнаи пӯст',
    '👰🏾' => 'арӯс бо сарандоз: ранги торики миёнаи пӯст',
    '👰🏿' => 'арӯс бо сарандоз: ранги торики пӯст',
    '🤰🏻' => 'зани ҳомила: ранги равшани пӯст',
    '🤰🏼' => 'зани ҳомила: ранги равшании миёнаи пӯст',
    '🤰🏽' => 'зани ҳомила: ранги миёнаи пӯст',
    '🤰🏾' => 'зани ҳомила: ранги торики миёнаи пӯст',
    '🤰🏿' => 'зани ҳомила: ранги торики пӯст',
    '🤱🏻' => 'синамакконӣ: ранги равшани пӯст',
    '🤱🏼' => 'синамакконӣ: ранги равшании миёнаи пӯст',
    '🤱🏽' => 'синамакконӣ: ранги миёнаи пӯст',
    '🤱🏾' => 'синамакконӣ: ранги торики миёнаи пӯст',
    '🤱🏿' => 'синамакконӣ: ранги торики пӯст',
    '👼🏻' => 'кӯдаки фаришта: ранги равшани пӯст',
    '👼🏼' => 'кӯдаки фаришта: ранги равшании миёнаи пӯст',
    '👼🏽' => 'кӯдаки фаришта: ранги миёнаи пӯст',
    '👼🏾' => 'кӯдаки фаришта: ранги торики миёнаи пӯст',
    '👼🏿' => 'кӯдаки фаришта: ранги торики пӯст',
    '🎅🏻' => 'бобои барфӣ: ранги равшани пӯст',
    '🎅🏼' => 'бобои барфӣ: ранги равшании миёнаи пӯст',
    '🎅🏽' => 'бобои барфӣ: ранги миёнаи пӯст',
    '🎅🏾' => 'бобои барфӣ: ранги торики миёнаи пӯст',
    '🎅🏿' => 'бобои барфӣ: ранги торики пӯст',
    '🤶🏻' => 'Хонум Клаус: ранги равшани пӯст',
    '🤶🏼' => 'Хонум Клаус: ранги равшании миёнаи пӯст',
    '🤶🏽' => 'Хонум Клаус: ранги миёнаи пӯст',
    '🤶🏾' => 'Хонум Клаус: ранги торики миёнаи пӯст',
    '🤶🏿' => 'Хонум Клаус: ранги торики пӯст',
    '🧙🏻' => 'коҳин: ранги равшани пӯст',
    '🧙🏼' => 'коҳин: ранги равшании миёнаи пӯст',
    '🧙🏽' => 'коҳин: ранги миёнаи пӯст',
    '🧙🏾' => 'коҳин: ранги торики миёнаи пӯст',
    '🧙🏿' => 'коҳин: ранги торики пӯст',
    '🧚🏻' => 'парӣ: ранги равшани пӯст',
    '🧚🏼' => 'парӣ: ранги равшании миёнаи пӯст',
    '🧚🏽' => 'парӣ: ранги миёнаи пӯст',
    '🧚🏾' => 'парӣ: ранги торики миёнаи пӯст',
    '🧚🏿' => 'парӣ: ранги торики пӯст',
    '🧛🏻' => 'вампир: ранги равшани пӯст',
    '🧛🏼' => 'вампир: ранги равшании миёнаи пӯст',
    '🧛🏽' => 'вампир: ранги миёнаи пӯст',
    '🧛🏾' => 'вампир: ранги торики миёнаи пӯст',
    '🧛🏿' => 'вампир: ранги торики пӯст',
    '🧜🏻' => 'шахси обӣ: ранги равшани пӯст',
    '🧜🏼' => 'шахси обӣ: ранги равшании миёнаи пӯст',
    '🧜🏽' => 'шахси обӣ: ранги миёнаи пӯст',
    '🧜🏾' => 'шахси обӣ: ранги торики миёнаи пӯст',
    '🧜🏿' => 'шахси обӣ: ранги торики пӯст',
    '🧝🏻' => 'пакана: ранги равшани пӯст',
    '🧝🏼' => 'пакана: ранги равшании миёнаи пӯст',
    '🧝🏽' => 'пакана: ранги миёнаи пӯст',
    '🧝🏾' => 'пакана: ранги торики миёнаи пӯст',
    '🧝🏿' => 'пакана: ранги торики пӯст',
    '💆🏻' => 'шахсе, ки паём гирифта истодааст: ранги равшани пӯст',
    '💆🏼' => 'шахсе, ки паём гирифта истодааст: ранги равшании миёнаи пӯст',
    '💆🏽' => 'шахсе, ки паём гирифта истодааст: ранги миёнаи пӯст',
    '💆🏾' => 'шахсе, ки паём гирифта истодааст: ранги торики миёнаи пӯст',
    '💆🏿' => 'шахсе, ки паём гирифта истодааст: ранги торики пӯст',
    '💇🏻' => 'шахсе, ки мӯи сарашро гирифта истодааст: ранги равшани пӯст',
    '💇🏼' => 'шахсе, ки мӯи сарашро гирифта истодааст: ранги равшании миёнаи пӯст',
    '💇🏽' => 'шахсе, ки мӯи сарашро гирифта истодааст: ранги миёнаи пӯст',
    '💇🏾' => 'шахсе, ки мӯи сарашро гирифта истодааст: ранги торики миёнаи пӯст',
    '💇🏿' => 'шахсе, ки мӯи сарашро гирифта истодааст: ранги торики пӯст',
    '🚶🏻' => 'шахсе, ки роҳ гашта истодааст: ранги равшани пӯст',
    '🚶🏼' => 'шахсе, ки роҳ гашта истодааст: ранги равшании миёнаи пӯст',
    '🚶🏽' => 'шахсе, ки роҳ гашта истодааст: ранги миёнаи пӯст',
    '🚶🏾' => 'шахсе, ки роҳ гашта истодааст: ранги торики миёнаи пӯст',
    '🚶🏿' => 'шахсе, ки роҳ гашта истодааст: ранги торики пӯст',
    '🏃🏻' => 'шахсе, ки давида истодааст: ранги равшани пӯст',
    '🏃🏼' => 'шахсе, ки давида истодааст: ранги равшании миёнаи пӯст',
    '🏃🏽' => 'шахсе, ки давида истодааст: ранги миёнаи пӯст',
    '🏃🏾' => 'шахсе, ки давида истодааст: ранги торики миёнаи пӯст',
    '🏃🏿' => 'шахсе, ки давида истодааст: ранги торики пӯст',
    '💃🏻' => 'зане, ки рақс карда истодааст: ранги равшани пӯст',
    '💃🏼' => 'зане, ки рақс карда истодааст: ранги равшании миёнаи пӯст',
    '💃🏽' => 'зане, ки рақс карда истодааст: ранги миёнаи пӯст',
    '💃🏾' => 'зане, ки рақс карда истодааст: ранги торики миёнаи пӯст',
    '💃🏿' => 'зане, ки рақс карда истодааст: ранги торики пӯст',
    '🕺🏻' => 'марде, ки рақс карда истодааст: ранги равшани пӯст',
    '🕺🏼' => 'марде, ки рақс карда истодааст: ранги равшании миёнаи пӯст',
    '🕺🏽' => 'марде, ки рақс карда истодааст: ранги миёнаи пӯст',
    '🕺🏾' => 'марде, ки рақс карда истодааст: ранги торики миёнаи пӯст',
    '🕺🏿' => 'марде, ки рақс карда истодааст: ранги торики пӯст',
    '🕴🏻' => 'марде, ки бо костюми корӣ баланд шуда истодааст: ранги равшани пӯст',
    '🕴🏼' => 'марде, ки бо костюми корӣ баланд шуда истодааст: ранги равшании миёнаи пӯст',
    '🕴🏽' => 'марде, ки бо костюми корӣ баланд шуда истодааст: ранги миёнаи пӯст',
    '🕴🏾' => 'марде, ки бо костюми корӣ баланд шуда истодааст: ранги торики миёнаи пӯст',
    '🕴🏿' => 'марде, ки бо костюми корӣ баланд шуда истодааст: ранги торики пӯст',
    '👯🏻' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшани пӯст',
    '👯🏼' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги равшании миёнаи пӯст',
    '👯🏽' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги миёнаи пӯст',
    '👯🏾' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики миёнаи пӯст',
    '👯🏿' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода: ранги торики пӯст',
    '🧖🏻' => 'шахсе дар ҳуҷраи буғ: ранги равшани пӯст',
    '🧖🏼' => 'шахсе дар ҳуҷраи буғ: ранги равшании миёнаи пӯст',
    '🧖🏽' => 'шахсе дар ҳуҷраи буғ: ранги миёнаи пӯст',
    '🧖🏾' => 'шахсе дар ҳуҷраи буғ: ранги торики миёнаи пӯст',
    '🧖🏿' => 'шахсе дар ҳуҷраи буғ: ранги торики пӯст',
    '🧗🏻' => 'шахсе, ки баромада истодааст: ранги равшани пӯст',
    '🧗🏼' => 'шахсе, ки баромада истодааст: ранги равшании миёнаи пӯст',
    '🧗🏽' => 'шахсе, ки баромада истодааст: ранги миёнаи пӯст',
    '🧗🏾' => 'шахсе, ки баромада истодааст: ранги торики миёнаи пӯст',
    '🧗🏿' => 'шахсе, ки баромада истодааст: ранги торики пӯст',
    '🏇🏻' => 'аспдавонӣ: ранги равшани пӯст',
    '🏇🏼' => 'аспдавонӣ: ранги равшании миёнаи пӯст',
    '🏇🏽' => 'аспдавонӣ: ранги миёнаи пӯст',
    '🏇🏾' => 'аспдавонӣ: ранги торики миёнаи пӯст',
    '🏇🏿' => 'аспдавонӣ: ранги торики пӯст',
    '🏂🏻' => 'сноубордист: ранги равшани пӯст',
    '🏂🏼' => 'сноубордист: ранги равшании миёнаи пӯст',
    '🏂🏽' => 'сноубордист: ранги миёнаи пӯст',
    '🏂🏾' => 'сноубордист: ранги торики миёнаи пӯст',
    '🏂🏿' => 'сноубордист: ранги торики пӯст',
    '🏌🏻' => 'шахсе, ки голф бозӣ карда истодааст: ранги равшани пӯст',
    '🏌🏼' => 'шахсе, ки голф бозӣ карда истодааст: ранги равшании миёнаи пӯст',
    '🏌🏽' => 'шахсе, ки голф бозӣ карда истодааст: ранги миёнаи пӯст',
    '🏌🏾' => 'шахсе, ки голф бозӣ карда истодааст: ранги торики миёнаи пӯст',
    '🏌🏿' => 'шахсе, ки голф бозӣ карда истодааст: ранги торики пӯст',
    '🏄🏻' => 'шахси серфинг карда истода: ранги равшани пӯст',
    '🏄🏼' => 'шахси серфинг карда истода: ранги равшании миёнаи пӯст',
    '🏄🏽' => 'шахси серфинг карда истода: ранги миёнаи пӯст',
    '🏄🏾' => 'шахси серфинг карда истода: ранги торики миёнаи пӯст',
    '🏄🏿' => 'шахси серфинг карда истода: ранги торики пӯст',
    '🚣🏻' => 'шахси қаиқронӣ карда истода: ранги равшани пӯст',
    '🚣🏼' => 'шахси қаиқронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚣🏽' => 'шахси қаиқронӣ карда истода: ранги миёнаи пӯст',
    '🚣🏾' => 'шахси қаиқронӣ карда истода: ранги торики миёнаи пӯст',
    '🚣🏿' => 'шахси қаиқронӣ карда истода: ранги торики пӯст',
    '🏊🏻' => 'шахси шино карда истода: ранги равшани пӯст',
    '🏊🏼' => 'шахси шино карда истода: ранги равшании миёнаи пӯст',
    '🏊🏽' => 'шахси шино карда истода: ранги миёнаи пӯст',
    '🏊🏾' => 'шахси шино карда истода: ранги торики миёнаи пӯст',
    '🏊🏿' => 'шахси шино карда истода: ранги торики пӯст',
    '⛹🏻' => 'шахсе, ки тӯбро ба замин зада истодааст: ранги равшани пӯст',
    '⛹🏼' => 'шахсе, ки тӯбро ба замин зада истодааст: ранги равшании миёнаи пӯст',
    '⛹🏽' => 'шахсе, ки тӯбро ба замин зада истодааст: ранги миёнаи пӯст',
    '⛹🏾' => 'шахсе, ки тӯбро ба замин зада истодааст: ранги торики миёнаи пӯст',
    '⛹🏿' => 'шахсе, ки тӯбро ба замин зада истодааст: ранги торики пӯст',
    '🏋🏻' => 'шахсе, ки бор мебардорад: ранги равшани пӯст',
    '🏋🏼' => 'шахсе, ки бор мебардорад: ранги равшании миёнаи пӯст',
    '🏋🏽' => 'шахсе, ки бор мебардорад: ранги миёнаи пӯст',
    '🏋🏾' => 'шахсе, ки бор мебардорад: ранги торики миёнаи пӯст',
    '🏋🏿' => 'шахсе, ки бор мебардорад: ранги торики пӯст',
    '🚴🏻' => 'шахси велосипедронӣ карда истода: ранги равшани пӯст',
    '🚴🏼' => 'шахси велосипедронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚴🏽' => 'шахси велосипедронӣ карда истода: ранги миёнаи пӯст',
    '🚴🏾' => 'шахси велосипедронӣ карда истода: ранги торики миёнаи пӯст',
    '🚴🏿' => 'шахси велосипедронӣ карда истода: ранги торики пӯст',
    '🚵🏻' => 'шахси дар куҳ велосипедронӣ карда истода: ранги равшани пӯст',
    '🚵🏼' => 'шахси дар куҳ велосипедронӣ карда истода: ранги равшании миёнаи пӯст',
    '🚵🏽' => 'шахси дар куҳ велосипедронӣ карда истода: ранги миёнаи пӯст',
    '🚵🏾' => 'шахси дар куҳ велосипедронӣ карда истода: ранги торики миёнаи пӯст',
    '🚵🏿' => 'шахси дар куҳ велосипедронӣ карда истода: ранги торики пӯст',
    '🤸🏻' => 'шахси чарх зада истода: ранги равшани пӯст',
    '🤸🏼' => 'шахси чарх зада истода: ранги равшании миёнаи пӯст',
    '🤸🏽' => 'шахси чарх зада истода: ранги миёнаи пӯст',
    '🤸🏾' => 'шахси чарх зада истода: ранги торики миёнаи пӯст',
    '🤸🏿' => 'шахси чарх зада истода: ранги торики пӯст',
    '🤼🏻' => 'нафарони гуштингирӣ карда истода: ранги равшани пӯст',
    '🤼🏼' => 'нафарони гуштингирӣ карда истода: ранги равшании миёнаи пӯст',
    '🤼🏽' => 'нафарони гуштингирӣ карда истода: ранги миёнаи пӯст',
    '🤼🏾' => 'нафарони гуштингирӣ карда истода: ранги торики миёнаи пӯст',
    '🤼🏿' => 'нафарони гуштингирӣ карда истода: ранги торики пӯст',
    '🤽🏻' => 'шахси ватерполо бозӣ карда истода: ранги равшани пӯст',
    '🤽🏼' => 'шахси ватерполо бозӣ карда истода: ранги равшании миёнаи пӯст',
    '🤽🏽' => 'шахси ватерполо бозӣ карда истода: ранги миёнаи пӯст',
    '🤽🏾' => 'шахси ватерполо бозӣ карда истода: ранги торики миёнаи пӯст',
    '🤽🏿' => 'шахси ватерполо бозӣ карда истода: ранги торики пӯст',
    '🤾🏻' => 'шахси гандбол бозӣ карда истода: ранги равшани пӯст',
    '🤾🏼' => 'шахси гандбол бозӣ карда истода: ранги равшании миёнаи пӯст',
    '🤾🏽' => 'шахси гандбол бозӣ карда истода: ранги миёнаи пӯст',
    '🤾🏾' => 'шахси гандбол бозӣ карда истода: ранги торики миёнаи пӯст',
    '🤾🏿' => 'шахси гандбол бозӣ карда истода: ранги торики пӯст',
    '🤹🏻' => 'шахси жонглёрӣ карда истода: ранги равшани пӯст',
    '🤹🏼' => 'шахси жонглёрӣ карда истода: ранги равшании миёнаи пӯст',
    '🤹🏽' => 'шахси жонглёрӣ карда истода: ранги миёнаи пӯст',
    '🤹🏾' => 'шахси жонглёрӣ карда истода: ранги торики миёнаи пӯст',
    '🤹🏿' => 'шахси жонглёрӣ карда истода: ранги торики пӯст',
    '🧘🏻' => 'шахси дар ҳолати лотус: ранги равшани пӯст',
    '🧘🏼' => 'шахси дар ҳолати лотус: ранги равшании миёнаи пӯст',
    '🧘🏽' => 'шахси дар ҳолати лотус: ранги миёнаи пӯст',
    '🧘🏾' => 'шахси дар ҳолати лотус: ранги торики миёнаи пӯст',
    '🧘🏿' => 'шахси дар ҳолати лотус: ранги торики пӯст',
    '🛀🏻' => 'нафаре, ки душ карда истодааст: ранги равшани пӯст',
    '🛀🏼' => 'нафаре, ки душ карда истодааст: ранги равшании миёнаи пӯст',
    '🛀🏽' => 'нафаре, ки душ карда истодааст: ранги миёнаи пӯст',
    '🛀🏾' => 'нафаре, ки душ карда истодааст: ранги торики миёнаи пӯст',
    '🛀🏿' => 'нафаре, ки душ карда истодааст: ранги торики пӯст',
    '🛌🏻' => 'одам дар бистар: ранги равшани пӯст',
    '🛌🏼' => 'одам дар бистар: ранги равшании миёнаи пӯст',
    '🛌🏽' => 'одам дар бистар: ранги миёнаи пӯст',
    '🛌🏾' => 'одам дар бистар: ранги торики миёнаи пӯст',
    '🛌🏿' => 'одам дар бистар: ранги торики пӯст',
    '👭🏻' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст',
    '👭🏼' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст',
    '👭🏽' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст',
    '👭🏾' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст',
    '👭🏿' => 'ду зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст',
    '👫🏻' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст',
    '👫🏼' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст',
    '👫🏽' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст',
    '👫🏾' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст',
    '👫🏿' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст',
    '👬🏻' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшани пӯст',
    '👬🏼' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги равшании миёнаи пӯст',
    '👬🏽' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги миёнаи пӯст',
    '👬🏾' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики миёнаи пӯст',
    '👬🏿' => 'ду марде, ки дастҳои якдигарро дошта истодаанд: ранги торики пӯст',
    '💏🏻' => 'бӯса: ранги равшани пӯст',
    '💏🏼' => 'бӯса: ранги равшании миёнаи пӯст',
    '💏🏽' => 'бӯса: ранги миёнаи пӯст',
    '💏🏾' => 'бӯса: ранги торики миёнаи пӯст',
    '💏🏿' => 'бӯса: ранги торики пӯст',
    '💑🏻' => 'ҷуфт бо дил: ранги равшани пӯст',
    '💑🏼' => 'ҷуфт бо дил: ранги равшании миёнаи пӯст',
    '💑🏽' => 'ҷуфт бо дил: ранги миёнаи пӯст',
    '💑🏾' => 'ҷуфт бо дил: ранги торики миёнаи пӯст',
    '💑🏿' => 'ҷуфт бо дил: ранги торики пӯст',
    '🏻' => 'ранги равшани пӯст',
    '🏼' => 'ранги равшании миёнаи пӯст',
    '🏽' => 'ранги миёнаи пӯст',
    '🏾' => 'ранги торики миёнаи пӯст',
    '🏿' => 'ранги торики пӯст',
    '😀' => 'рӯи хандон',
    '😃' => 'рӯи хандон бо даҳони кушода',
    '😄' => 'рӯи хандон бо даҳони кушода ва чашмони хандон',
    '😁' => 'чеҳраи писхандкунанда бо чашмони табассумкунанда',
    '😆' => 'рӯи хандон бо даҳони кушода ва чашмони пӯшида',
    '😅' => 'рӯи хандон бо даҳони кушода ва арақи хунук',
    '🤣' => 'аз ханда рӯдакан шудан',
    '😂' => 'рӯи бо ашкҳои хурсандӣ',
    '🙂' => 'тӯи каме хандон',
    '🙃' => 'рӯи сарчаппа',
    '😉' => 'рӯи чашмакзананда',
    '😊' => 'рӯи хандон бо чашмони хандон',
    '😇' => 'рӯи хандон бо ҳола',
    '😍' => 'рӯи хандон бо чашмони дилмонанд',
    '🤩' => 'дарди ситорашавӣ',
    '😘' => 'рӯи бӯсаи ҳавоӣ равонкунанда',
    '😗' => 'рӯи бӯсакунанда',
    '☺' => 'рӯи табассумкунанда',
    '😚' => 'рӯи бӯсакунанда бо чашмони пӯшида',
    '😙' => 'рӯи бӯсакунанда бо чашмони хандон',
    '😋' => 'рӯе, ки ғизои бомазаро маза карда хӯрда истодааст',
    '😛' => 'рӯй бо забони баровардашуда',
    '😜' => 'рӯй бо забони баровардашуда ва чашми чашмакизананда',
    '🤪' => 'рӯи девона',
    '😝' => 'рӯй бо забони баровардашуда ва чашмони пӯшида',
    '🤑' => 'рӯи дорои даҳони пулӣ',
    '🤗' => 'рӯи оғӯшкунанда',
    '🤭' => 'рӯй бо даст дар болои даҳон',
    '🤫' => 'рӯи хомӯшкунанда',
    '🤔' => 'рӯи аднешакунанда',
    '🤐' => 'рӯи дорои даҳони заҷиракдор',
    '🤨' => 'рӯе, ки қошҳояш бардошта шудааст',
    '😐' => 'рӯи нейтралӣ',
    '😑' => 'рӯи беифода',
    '😶' => 'рӯи бедаҳон',
    '😏' => 'рӯи писхандакунанда',
    '😒' => 'рӯи норозӣ',
    '🙄' => 'рӯй бо чашмони даврзананда',
    '😬' => 'рӯи туршкунанда',
    '🤥' => 'рӯи дурӯғгӯ',
    '😌' => 'рӯи бароҳат',
    '😔' => 'рӯи андуҳгин',
    '😪' => 'рӯи хоболуд',
    '🤤' => 'рӯи оби даҳон чакидаистода',
    '😴' => 'рӯи хуфта',
    '😷' => 'рӯй бо ниқоби тиббӣ',
    '🤒' => 'рӯй бо ҳароратсанҷ',
    '🤕' => 'рӯй бо бандинаи сар',
    '🤢' => 'рӯи дилбеҳузурӣ',
    '🤮' => 'рӯи партофта истода',
    '🤧' => 'Рӯи атсазананда',
    '😵' => 'рӯи сарчархзанӣ',
    '🤯' => 'сари тарканда',
    '🤠' => 'рӯи дорои кулоҳи ковбой',
    '😎' => 'рӯи хандон бо айнаки офтобӣ',
    '🤓' => 'рӯи соддалавҳ',
    '🧐' => 'рӯй бо айнаки якчашма',
    '😕' => 'рӯи ошуфта',
    '😟' => 'рӯи мушавваш',
    '🙁' => 'рӯи каме қавоқандохта',
    '☹' => 'рӯи қавоқандохта',
    '😮' => 'рӯй бо даҳони кушода',
    '😯' => 'рӯи хомӯш',
    '😲' => 'рӯи ҳайрон',
    '😳' => 'рӯи сурхшуда',
    '😦' => 'рӯи турш бо даҳони кушода',
    '😧' => 'рӯи дилтанг',
    '😨' => 'рӯи тарсон',
    '😰' => 'рӯи бо даҳони кушода ва арақи хунук',
    '😥' => 'ғамгин, вале рӯи бароҳат',
    '😢' => 'рӯи гирён',
    '😭' => 'рӯи баланд гириста истода',
    '😱' => 'рӯи аз тарс дод задаистода',
    '😖' => 'рӯи хиҷил',
    '😣' => 'рӯи истодагарикунанда',
    '😞' => 'рӯи ғамгин',
    '😓' => 'рӯй бо арақи хунук',
    '😩' => 'рӯи афгор',
    '😫' => 'рӯи хаста',
    '😤' => 'рӯй бо дуд аз бинӣ',
    '😡' => 'рӯи бадқавоқ',
    '😠' => 'рӯи хашмгин',
    '🤬' => 'рӯй бо аломатҳо дар болои даҳон',
    '😈' => 'рӯи хандон бо шохҳо',
    '👿' => 'рӯи хашмгин бо шохҳо',
    '💀' => 'косахонаи сар',
    '☠' => 'косахонаи сар ва устухонҳо дар шакли салиб',
    '💩' => 'тӯдаи гуҳ',
    '🤡' => 'рӯи масхарабоз',
    '👹' => 'одамхӯр',
    '👺' => 'аҷинаи хона',
    '👻' => 'руҳ',
    '👽' => 'бегона',
    '👾' => 'аъҷубаи бегона',
    '🤖' => 'рӯи робот',
    '😺' => 'рӯи гурбаи хандон бо даҳони кушода',
    '😸' => 'рӯи писхандакунандаи гурба бо чашмони хандон',
    '😹' => 'рӯи гурба бо ашки хурсандӣ',
    '😻' => 'рӯи хандони гурба бо чашмони дилмонанд',
    '😼' => 'рӯи гурба бо табассуми каҷ',
    '😽' => 'рӯи бӯсакунандаи гурба бо чашмони пӯшида',
    '🙀' => 'рӯи афгори гурба',
    '😿' => 'рӯи гирёни гурба',
    '😾' => 'рӯи бадқавоқи гурба',
    '🙈' => 'маймуне, ки бадиро намебинад',
    '🙉' => 'маймуне, ки бадиро намешунавад',
    '🙊' => 'маймуне, ки гапи бад намезанад',
    '💌' => 'мактуби ошиқӣ',
    '💘' => 'дил бо тир',
    '💝' => 'дил бо лента',
    '💖' => 'дили ҷилодор',
    '💗' => 'дили афзоянда',
    '💓' => 'дили тапишзананда',
    '💞' => 'дилҳои даврзананда',
    '💕' => 'ду дил',
    '💟' => 'ороиши дил',
    '❣' => 'хитоби дили вазнин',
    '💔' => 'дили шикаста',
    '❤' => 'дили сурх',
    '🧡' => 'дили норанҷӣ',
    '💛' => 'дили зард',
    '💚' => 'дили сабз',
    '💙' => 'дили кабуд',
    '💜' => 'дили арғувонӣ',
    '🖤' => 'дили сиёҳ',
    '💋' => 'нишонаи бӯса',
    '💯' => 'сад хол',
    '💢' => 'аломати ғазаб',
    '💥' => 'бархӯрд',
    '💫' => 'сархчархзанӣ',
    '💦' => 'қатраҳои арақ',
    '💨' => 'тез гурехтан',
    '🕳' => 'сурох',
    '💬' => 'ҳубоби нутқ',
    '🗨' => 'ҳубоби чапи гуфтугӯ',
    '🗯' => 'ҳубоби рости ғазаб',
    '💭' => 'ҳубоби андеша',
    '💤' => 'ххх',
    '👋' => 'ҳаракати пешу қафои даст',
    '🤚' => 'пушти дасти бардошташуда',
    '🖐' => 'дасти бардошта бо ангуштони паҳнкарда',
    '✋' => 'дасти бардошта',
    '🖖' => 'саломдиҳии вулқонӣ',
    '👌' => 'Дасти ОК',
    '✌' => 'дасти зафар',
    '🤞' => 'ангуштони ба ҳам гузошташуда',
    '🤟' => 'имову ишораи "Туро дӯст медорам"',
    '🤘' => 'ишораи шохҳо',
    '🤙' => 'ба ман занг занед',
    '👈' => 'ангушти ишорат ба тарафи чап ишора карда истода',
    '👉' => 'ангушти ишорат ба тарафи рост ишора карда истода',
    '👆' => 'пушти даст ангушти ишорат ба боло ишора карда истода',
    '🖕' => 'ангушти байн',
    '👇' => 'ангушти ишорат ба поён ишора карда истода',
    '☝' => 'ангушти ишорат ба боло ишора карда истода',
    '👍' => 'хуб',
    '👎' => 'бад',
    '✊' => 'мушти бардошта',
    '👊' => 'мушти муқобил',
    '🤛' => 'мушт аз тарафи чап',
    '🤜' => 'мушти тарафи рост',
    '👏' => 'дастҳои қарсакзананда',
    '🙌' => 'дастҳои бардоштаистода',
    '👐' => 'дастҳои кушода',
    '🤲' => 'дастҳо якҷоя боло',
    '🤝' => 'дастфишӯрӣ',
    '🙏' => 'дастҳои қат кардашуда',
    '✍' => 'дасти навишта истода',
    '💅' => 'лок барои нохунҳо',
    '🤳' => 'селфи',
    '💪' => 'мушаки битсепси қат кардашуда',
    '👂' => 'гуш',
    '👃' => 'бинӣ',
    '🧠' => 'майнаи сар',
    '👀' => 'чашмон',
    '👁' => 'чашм',
    '👅' => 'забон',
    '👄' => 'даҳон',
    '👶' => 'тифл',
    '🧒' => 'кӯдак',
    '👦' => 'писар',
    '👧' => 'духтар',
    '🧑' => 'калонсол',
    '👱' => 'шахси зардинамӯй',
    '👨' => 'мард',
    '🧔' => 'шахси ришдор',
    '👩' => 'зан',
    '🧓' => 'калонсоли пир',
    '👴' => 'марди пир',
    '👵' => 'зани пир',
    '🙍' => 'шахсе, ки қавоқ андохта истодааст',
    '🙎' => 'шахсе, ки лабҳояшро каҷ карда истодааст',
    '🙅' => 'шахсе, ки "НЕ" ишора карда истодааст',
    '🙆' => 'шахсе, ки "ОК" ишора карда истодааст',
    '💁' => 'шахсе, ки бо дасташ ишора карда истодааст',
    '🙋' => 'шахсе, ки дасташро бардошта истодааст',
    '🙇' => 'шахсе, ки хам шуда истодааст',
    '🤦' => 'шахсе, ки рӯяшро бо дастонаш пӯшида истодааст',
    '🤷' => 'шахсе, ки китф афшонда истодааст',
    '👮' => 'афсари пулис',
    '🕵' => 'детектив',
    '💂' => 'посбон',
    '👷' => 'коргари сохтмон',
    '🤴' => 'шоҳзода',
    '👸' => 'шоҳдухтар',
    '👳' => 'шахсе, ки дар сар салла дорад',
    '👲' => 'мард бо сарпӯши хитоӣ',
    '🧕' => 'зан бо рӯймол',
    '🤵' => 'мард бо смокинг',
    '👰' => 'арӯс бо сарандоз',
    '🤰' => 'зани ҳомила',
    '🤱' => 'синамакконӣ',
    '👼' => 'кӯдаки фаришта',
    '🎅' => 'бобои барфӣ',
    '🤶' => 'Хонум Клаус',
    '🧙' => 'коҳин',
    '🧚' => 'парӣ',
    '🧛' => 'вампир',
    '🧜' => 'шахси обӣ',
    '🧝' => 'пакана',
    '🧞' => 'ҷин',
    '🧟' => 'зомби',
    '💆' => 'шахсе, ки паём гирифта истодааст',
    '💇' => 'шахсе, ки мӯи сарашро гирифта истодааст',
    '🚶' => 'шахсе, ки роҳ гашта истодааст',
    '🏃' => 'шахсе, ки давида истодааст',
    '💃' => 'зане, ки рақс карда истодааст',
    '🕺' => 'марде, ки рақс карда истодааст',
    '🕴' => 'марде, ки бо костюми корӣ баланд шуда истодааст',
    '👯' => 'нафарони бо гӯшҳои харгӯш хурсандӣ карда истода',
    '🧖' => 'шахсе дар ҳуҷраи буғ',
    '🧗' => 'шахсе, ки баромада истодааст',
    '🤺' => 'шахси шамшербозӣ карда истода',
    '🏇' => 'аспдавонӣ',
    '⛷' => 'лижарон',
    '🏂' => 'сноубордист',
    '🏌' => 'шахсе, ки голф бозӣ карда истодааст',
    '🏄' => 'шахси серфинг карда истода',
    '🚣' => 'шахси қаиқронӣ карда истода',
    '🏊' => 'шахси шино карда истода',
    '⛹' => 'шахсе, ки тӯбро ба замин зада истодааст',
    '🏋' => 'шахсе, ки бор мебардорад',
    '🚴' => 'шахси велосипедронӣ карда истода',
    '🚵' => 'шахси дар куҳ велосипедронӣ карда истода',
    '🤸' => 'шахси чарх зада истода',
    '🤼' => 'нафарони гуштингирӣ карда истода',
    '🤽' => 'шахси ватерполо бозӣ карда истода',
    '🤾' => 'шахси гандбол бозӣ карда истода',
    '🤹' => 'шахси жонглёрӣ карда истода',
    '🧘' => 'шахси дар ҳолати лотус',
    '🛀' => 'нафаре, ки душ карда истодааст',
    '🛌' => 'одам дар бистар',
    '👭' => 'ду зане, ки дастҳои якдигарро дошта истодаанд',
    '👫' => 'мард ва зане, ки дастҳои якдигарро дошта истодаанд',
    '👬' => 'ду марде, ки дастҳои якдигарро дошта истодаанд',
    '💏' => 'бӯса',
    '💑' => 'ҷуфт бо дил',
    '🗣' => 'сари гап зада истода',
    '👤' => 'нимпайкара дар суроб',
    '👥' => 'нимпайкараҳо дар суроб',
    '👪' => 'оила',
    '👣' => 'изҳои пой',
    '🐵' => 'рӯи маймун',
    '🐒' => 'маймун',
    '🦍' => 'горилла',
    '🐶' => 'афти саг',
    '🐕' => 'саг',
    '🐩' => 'пудел',
    '🐺' => 'афти гург',
    '🦊' => 'афти рӯбоҳ',
    '🐱' => 'афти гурба',
    '🐈' => 'гурба',
    '🦁' => 'афти шер',
    '🐯' => 'афти паланг',
    '🐅' => 'паланг',
    '🐆' => 'леопард',
    '🐴' => 'афти асп',
    '🐎' => 'асп',
    '🦄' => 'афти якшоха',
    '🦓' => 'гӯрхар',
    '🦌' => 'оҳу',
    '🐮' => 'афти гов',
    '🐂' => 'буққа',
    '🐃' => 'говмеши обӣ',
    '🐄' => 'гов',
    '🐷' => 'афти хук',
    '🐖' => 'хук',
    '🐗' => 'хуки ваҳшӣ',
    '🐽' => 'бинии хук',
    '🐏' => 'қӯшқор',
    '🐑' => 'меш',
    '🐐' => 'буз',
    '🐪' => 'шутур',
    '🐫' => 'шутури дукуҳона',
    '🦒' => 'зарофа',
    '🐘' => 'фил',
    '🦏' => 'карк',
    '🐭' => 'афти муш',
    '🐁' => 'муш',
    '🐀' => 'каламуш',
    '🐹' => 'афти миримушон',
    '🐰' => 'афти заргӯш',
    '🐇' => 'заргӯш',
    '🐿' => 'бурундуқ',
    '🦔' => 'хорпушт',
    '🦇' => 'муши паррон',
    '🐻' => 'афти хирс',
    '🐨' => 'коала',
    '🐼' => 'афти панда',
    '🐾' => 'изҳои панҷа',
    '🦃' => 'мурғи марҷон',
    '🐔' => 'чӯҷа',
    '🐓' => 'хурӯс',
    '🐣' => 'чӯҷаи аз тухм баромада истода',
    '🐤' => 'чӯҷаи хурд',
    '🐥' => 'чӯҷаи хурди ба тарафи пеш нигоҳ карда истода',
    '🐦' => 'парранда',
    '🐧' => 'пингвин',
    '🕊' => 'кафтар',
    '🦅' => 'уқоб',
    '🦆' => 'мурғобӣ',
    '🦉' => 'бум',
    '🐸' => 'афти қурбоққа',
    '🐊' => 'тимсоҳ',
    '🐢' => 'сангпушти обӣ',
    '🦎' => 'калтакалос',
    '🐍' => 'мор',
    '🐲' => 'афти аждаҳор',
    '🐉' => 'аждаҳор',
    '🦕' => 'динозаври завропод',
    '🦖' => 'Т-Рекс',
    '🐳' => 'наҳанги фаввора зада истода',
    '🐋' => 'наҳанг',
    '🐬' => 'делфин',
    '🐟' => 'моҳӣ',
    '🐠' => 'моҳии тропикӣ',
    '🐡' => 'сагмоҳӣ',
    '🦈' => 'кӯсамоҳӣ',
    '🐙' => 'ҳаштпо',
    '🐚' => 'садафи морпеч',
    '🦀' => 'харчанг',
    '🦐' => 'гамбусакча',
    '🦑' => 'калмар',
    '🐌' => 'тӯқумшуллуқ',
    '🦋' => 'шапалак',
    '🐛' => 'гамбуск',
    '🐜' => 'мурча',
    '🐝' => 'занбури асал',
    '🐞' => 'ҳасанак',
    '🦗' => 'крикет',
    '🕷' => 'тортанак',
    '🕸' => 'тори тортанак',
    '🦂' => 'каждум',
    '💐' => 'Гулдаста',
    '🌸' => 'гули гелос',
    '💮' => 'гули сафед',
    '🏵' => 'гулдоира',
    '🌹' => 'садбарг',
    '🥀' => 'гули пажмурда',
    '🌺' => 'гибискус',
    '🌻' => 'офтобпараст',
    '🌼' => 'гул кардан',
    '🌷' => 'лола',
    '🌱' => 'навниҳол',
    '🌲' => 'дарахти ҳамешасабз',
    '🌳' => 'дарахти паҳнбарг',
    '🌴' => 'дарахти нахл',
    '🌵' => 'гули ханҷарӣ',
    '🌾' => 'дарзаи биринҷ',
    '🌿' => 'алаф',
    '☘' => 'себарга',
    '🍀' => 'бедаи чорбарга',
    '🍁' => 'барги заранг',
    '🍂' => 'барги хазон',
    '🍃' => 'барги дар шамол лаппида истода',
    '🍄' => 'занбӯруғ',
    '🍇' => 'ангур',
    '🍈' => 'харбуза',
    '🍉' => 'тарбуз',
    '🍊' => 'мандарин',
    '🍋' => 'лиму',
    '🍌' => 'банан',
    '🍍' => 'ананас',
    '🍎' => 'себи сурх',
    '🍏' => 'себи сабз',
    '🍐' => 'нок',
    '🍑' => 'шафтолу',
    '🍒' => 'гелос',
    '🍓' => 'тути заминӣ',
    '🥝' => 'меваи киви',
    '🍅' => 'помидор',
    '🥥' => 'норҷил',
    '🥑' => 'авакадо',
    '🍆' => 'бодимҷон',
    '🥔' => 'картошка',
    '🥕' => 'сабзӣ',
    '🌽' => 'сӯтаи ҷуворимакка',
    '🌶' => 'қаланфури тез',
    '🥒' => 'бодиринг',
    '🥦' => 'брокколи',
    '🥜' => 'чормағзи заминӣ',
    '🌰' => 'кастона',
    '🍞' => 'нон',
    '🥐' => 'кулчақанди "Рогалик"',
    '🥖' => 'батон',
    '🥨' => 'кулчаи қоқи ҳалқашакл',
    '🥞' => 'чалпак',
    '🧀' => 'пораи фонашакли панир',
    '🍖' => 'гушт дар устухон',
    '🍗' => 'линги мурғ',
    '🥩' => 'буридаи гушт',
    '🥓' => 'гушти хук',
    '🍔' => 'гамбургер',
    '🍟' => 'картошка бирён',
    '🍕' => 'питса',
    '🌭' => 'хот дог',
    '🥪' => 'сендвич',
    '🌮' => 'тако',
    '🌯' => 'буритто',
    '🥙' => 'нони қима андохташуда',
    '🥚' => 'тухм',
    '🍳' => 'пухта истодааст',
    '🥘' => 'дегчаи хурди ғизо',
    '🍲' => 'деги ғизо',
    '🥣' => 'табақ бо қошуқ',
    '🥗' => 'хӯриши сабз',
    '🍿' => 'ҷуворипақак',
    '🥫' => 'маҳсулоти консервагӣ',
    '🍱' => 'қуттии бенто',
    '🍘' => 'брекери биринҷӣ',
    '🍙' => 'курачаи биринҷӣ',
    '🍚' => 'биринҷи пухташуда',
    '🍛' => 'биринҷ бо карри',
    '🍜' => 'зарф барои ҷӯшондан',
    '🍝' => 'спагетти',
    '🍠' => 'картошкаи ширини пухташуда',
    '🍢' => 'оден',
    '🍣' => 'суши',
    '🍤' => 'креветкаи хурди бирён',
    '🍥' => 'торт аз моҳӣ бо гирдоб',
    '🍡' => 'данго',
    '🥟' => 'ғелаккабоб',
    '🥠' => 'кулчаҳои қандини туҳфадор',
    '🥡' => 'қуттии хӯроки бо худ гирифташаванда',
    '🍦' => 'яхмоси мулоим',
    '🍧' => 'тарошаи ях',
    '🍨' => 'яхмос',
    '🍩' => 'кулча',
    '🍪' => 'кулчақанд',
    '🎂' => 'торти зодрӯзӣ',
    '🍰' => 'кулчақанди регак-регак',
    '🥧' => 'пирог',
    '🍫' => 'як тахтача шоколад',
    '🍬' => 'конфет',
    '🍭' => 'оби дандон',
    '🍮' => 'крем',
    '🍯' => 'кӯзаи асал',
    '🍼' => 'шишаи кӯдак',
    '🥛' => 'стакани шир',
    '☕' => 'нӯшокии гарм',
    '🍵' => 'пиёлаи чой бе даста',
    '🍶' => 'саке',
    '🍾' => 'шиша бо пӯкаи он парида рафта истода',
    '🍷' => 'стакани май',
    '🍸' => 'стакани коктейл',
    '🍹' => 'нӯшокии тропикӣ',
    '🍺' => 'дӯлчаи пиво',
    '🍻' => 'ҷирингос задани дӯлчаҳои пиво',
    '🥂' => 'ҷирингос задани стаканҳо',
    '🥃' => 'стакан барои нӯшокиҳои спиртӣ',
    '🥤' => 'пиёла бо чӯбак',
    '🥢' => 'чӯбҳои хӯрокхӯрӣ',
    '🍽' => 'чангол ва корд бо табақча',
    '🍴' => 'чангол ва корд',
    '🥄' => 'қошуқ',
    '🔪' => 'корди ошхона',
    '🏺' => 'амфора',
    '🌍' => 'глобусе, ки Аврупо-Африкаро намоиш медиҳад',
    '🌎' => 'глобусе, ки Америкаҳоро намоиш медиҳад',
    '🌏' => 'глобусе, ки Осиё-Австралияро намоиш медиҳад',
    '🌐' => 'глобус бо меридианаҳо',
    '🗺' => 'харитаи ҷаҳон',
    '🗾' => 'харитаи Ҷопон',
    '🏔' => 'куҳи бо барф пӯшида',
    '⛰' => 'куҳ',
    '🌋' => 'вулқон',
    '🗻' => 'теппаи Фуҷи',
    '🏕' => 'хаймазанӣ',
    '🏖' => 'соҳил бо чатр',
    '🏜' => 'биёбон',
    '🏝' => 'ҷазираи биёбон',
    '🏞' => 'парки миллӣ',
    '🏟' => 'варзишгоҳ',
    '🏛' => 'бинои классикӣ',
    '🏗' => 'сохтмони бино',
    '🏘' => 'хонаҳо',
    '🏚' => 'хонаи бесоҳиб',
    '🏠' => 'хона',
    '🏡' => 'хона бо боғ',
    '🏢' => 'бинои идора',
    '🏣' => 'идораи почтаи ҷопонӣ',
    '🏤' => 'идораи почта',
    '🏥' => 'беморхона',
    '🏦' => 'бонк',
    '🏨' => 'меҳмонхона',
    '🏩' => 'меҳмонхонаи муҳаббат',
    '🏪' => 'мағозаи шабонарӯзӣ',
    '🏫' => 'мактаб',
    '🏬' => 'универмаг',
    '🏭' => 'фабрика',
    '🏯' => 'қалъаи ҷопонӣ',
    '🏰' => 'қалъа',
    '💒' => 'тӯй',
    '🗼' => 'бурҷи Токио',
    '🗽' => 'ҳайкали Озодӣ',
    '⛪' => 'калисо',
    '🕌' => 'масҷид',
    '🕍' => 'каниса',
    '⛩' => 'ҷои муқаддаси синто',
    '🕋' => 'каъба',
    '⛲' => 'фаввора',
    '⛺' => 'хайма',
    '🌁' => 'тумандор',
    '🌃' => 'шаби ситорадор',
    '🏙' => 'манзараи шаҳр',
    '🌄' => 'Тулӯи офтоб аз болои куҳҳо',
    '🌅' => 'тулӯъ',
    '🌆' => 'манзараи шаҳр дар шом',
    '🌇' => 'ғуруб',
    '🌉' => 'кӯпрук дар шаб',
    '♨' => 'чашмаҳои гарм',
    '🎠' => 'аспаки чархуфалак',
    '🎡' => 'чархуфалак',
    '🎢' => 'роҳи оҳани лағжишбозӣ',
    '💈' => 'сутун бо ранги сурху сафеди морпеч',
    '🎪' => 'хаймаи сирк',
    '🚂' => 'локомотив',
    '🚃' => 'вагони роҳи оҳан',
    '🚄' => 'қатораи баландсуръат',
    '🚅' => 'қатораи баландсуръат бо нӯги тирмонанд',
    '🚆' => 'қатора',
    '🚇' => 'метро',
    '🚈' => 'метрои сабук',
    '🚉' => 'истгоҳ',
    '🚊' => 'трамвай',
    '🚝' => 'якрелса',
    '🚞' => 'роҳи оҳани куҳӣ',
    '🚋' => 'вагони трамвай',
    '🚌' => 'автобус',
    '🚍' => 'автобуси самти муқобил',
    '🚎' => 'троллейбус',
    '🚐' => 'микроавтобус',
    '🚑' => 'мошини ёрии таъҷилӣ',
    '🚒' => 'мошини сӯхторхомӯшкунӣ',
    '🚓' => 'мошини пулис',
    '🚔' => 'мошини пулис аз самти муқобил',
    '🚕' => 'такси',
    '🚖' => 'такси аз самти муқобил',
    '🚗' => 'автомобил',
    '🚘' => 'автомобили самти муқобил',
    '🚙' => 'кроссовер',
    '🚚' => 'автомобили боркаш',
    '🚛' => 'нақлиёти боркаш',
    '🚜' => 'трактор',
    '🏎' => 'автомобили пойга',
    '🏍' => 'мотосикл',
    '🛵' => 'скутер',
    '🚲' => 'дучарха',
    '🛴' => 'самокат',
    '🚏' => 'истгоҳи автобусҳо',
    '🛣' => 'роҳи автомобилгард',
    '🛤' => 'роҳи оҳан',
    '🛢' => 'чалаки нафт',
    '⛽' => 'насоси сӯзишворӣ',
    '🚨' => 'рӯшноии мошини пулис',
    '🚥' => 'чароғи раҳнамои уфуқӣ',
    '🚦' => 'чароғи раҳнамои амудӣ',
    '🛑' => 'аломати "Ист"',
    '🚧' => 'сохтмон',
    '⚓' => 'лангар',
    '⛵' => 'заврақи бодбондор',
    '🛶' => 'заврақ',
    '🚤' => 'катери тезгард',
    '🛳' => 'киштии мусофиркаш',
    '⛴' => 'киштии гузора',
    '🛥' => 'қаиқи муҳаррикдор',
    '🚢' => 'киштӣ',
    '✈' => 'тайёра',
    '🛩' => 'тайёраи хурд',
    '🛫' => 'парвози тайёра',
    '🛬' => 'омадани тайёра',
    '💺' => 'ҷои нишаст',
    '🚁' => 'чархбол',
    '🚟' => 'роҳи оҳани овезон',
    '🚠' => 'фуникулёр',
    '🚡' => 'трамваи ҳавоӣ',
    '🛰' => 'моҳвора',
    '🚀' => 'ракета',
    '🛸' => 'лаълии паррон',
    '🛎' => 'зангулаи хизматгори меҳмонхона',
    '⌛' => 'соати регӣ',
    '⏳' => 'соати регӣ бо ҷорӣ шудани рег',
    '⌚' => 'соати дастӣ',
    '⏰' => 'соати зангдор',
    '⏱' => 'сониясанҷ',
    '⏲' => 'соати вақтсанҷ',
    '🕰' => 'соати сангӣ',
    '🕛' => 'соат дувоздаҳ',
    '🕧' => 'дувоздаҳу сӣ',
    '🕐' => 'соат як',
    '🕜' => 'яку сӣ',
    '🕑' => 'соат ду',
    '🕝' => 'дую сӣ',
    '🕒' => 'соат се',
    '🕞' => 'севу сӣ',
    '🕓' => 'соат чор',
    '🕟' => 'чору сӣ',
    '🕔' => 'соат панҷ',
    '🕠' => 'панҷу сӣ',
    '🕕' => 'соат шаш',
    '🕡' => 'шашу сӣ',
    '🕖' => 'соат ҳафт',
    '🕢' => 'ҳафту сӣ',
    '🕗' => 'соат ҳашт',
    '🕣' => 'ҳашту сӣ',
    '🕘' => 'соат нуҳ',
    '🕤' => 'нуҳу сӣ',
    '🕙' => 'соат даҳ',
    '🕥' => 'даҳу сӣ',
    '🕚' => 'соат ёздаҳ',
    '🕦' => 'ёздаҳу сӣ',
    '🌑' => 'моҳи нав',
    '🌒' => 'ҳилоли нав',
    '🌓' => 'марҳилаи чоряки якуми моҳ',
    '🌔' => 'марҳилаи калон шудани моҳ',
    '🌕' => 'моҳи пурра',
    '🌖' => 'марҳилаи хурд шудани моҳ',
    '🌗' => 'марҳилаи чоряки охири моҳ',
    '🌘' => 'марҳилаи хурд шудани ҳилол',
    '🌙' => 'ҳилол',
    '🌚' => 'чеҳраи моҳи нав',
    '🌛' => 'чоряки якуми моҳ бо чеҳра',
    '🌜' => 'чоряки охири моҳ бо чеҳра',
    '🌡' => 'ҳароратсанҷ',
    '☀' => 'офтоб',
    '🌝' => 'моҳи пурра бо чеҳра',
    '🌞' => 'офтоб бо чеҳра',
    '⭐' => 'ситораи миёнаи сафед',
    '🌟' => 'ситораи дурахшон',
    '🌠' => 'ситораи думдор',
    '🌌' => 'роҳи Каҳкашон',
    '☁' => 'абр',
    '⛅' => 'офтоб паси абр',
    '⛈' => 'абр бо чароғак ва борон',
    '🌤' => 'офтоб паси абри хурд',
    '🌥' => 'офтоб паси абри калон',
    '🌦' => 'офтоб паси абри боронӣ',
    '🌧' => 'абр бо борон',
    '🌨' => 'абр бо барф',
    '🌩' => 'абр бо чароғак',
    '🌪' => 'торнадо',
    '🌫' => 'туман',
    '🌬' => 'рӯи шамол',
    '🌀' => 'сиклон',
    '🌈' => 'тирукамон',
    '🌂' => 'чатри пӯшида',
    '☂' => 'чатр',
    '☔' => 'чатр бо қатраҳои борон',
    '⛱' => 'чатр дар замин',
    '⚡' => 'шиддати баланд',
    '❄' => 'зарраи барф',
    '☃' => 'одами барфӣ',
    '⛄' => 'одами барфӣ бе барф',
    '☄' => 'комета',
    '🔥' => 'оташ',
    '💧' => 'қатра',
    '🌊' => 'мавҷи об',
    '🎃' => 'чароғак аз каду бо сӯрохиҳои даҳон, бинӣ ва чашмон',
    '🎄' => 'дарахти Мавлуди Исо',
    '🎆' => 'оташфаввора',
    '🎇' => 'мушаки маҳтобӣ',
    '✨' => 'шарора',
    '🎈' => 'ҳубоб',
    '🎉' => 'маводи тарфгарӣ (хлопушка)',
    '🎊' => 'кӯраи конфетти',
    '🎋' => 'дарахти Танабата',
    '🎍' => 'ороиши дарахти санавбар',
    '🎎' => 'лухтакҳои ҷопонӣ',
    '🎏' => 'летнаи ҳиллиросзанандаи ба шакли зағорамоҳӣ',
    '🎐' => 'мусиқии шамол',
    '🎑' => 'маросими тамошои моҳтоб',
    '🎀' => 'лента',
    '🎁' => 'туҳфаи печондашуда',
    '🎗' => 'лентаи ёдрасон',
    '🎟' => 'чиптаҳои қабул',
    '🎫' => 'чипта',
    '🎖' => 'медали ҳарбӣ',
    '🏆' => 'мукофот',
    '🏅' => 'медали варзишӣ',
    '🥇' => 'медал барои ҷои 1-ум',
    '🥈' => 'медал барои ҷои 2-юм',
    '🥉' => 'медал барои ҷои 3-юм',
    '⚽' => 'тӯби футбол',
    '⚾' => 'бейсбол',
    '🏀' => 'баскетбол',
    '🏐' => 'волейбол',
    '🏈' => 'футболи амрикоӣ',
    '🏉' => 'регби',
    '🎾' => 'тенис',
    '🎳' => 'боулинг',
    '🏏' => 'бозии крикет',
    '🏑' => 'майдони хоккей',
    '🏒' => 'хоккей дар рӯи ях',
    '🏓' => 'пинг понг',
    '🏸' => 'бадминтон',
    '🥊' => 'дастпӯшак барои бокс',
    '🥋' => 'либоси санъати ҳарбӣ',
    '🥅' => 'тӯри дарвозаи футбол',
    '⛳' => 'байрақ дар сӯрохӣ',
    '⛸' => 'яхмолак',
    '🎣' => 'шаст',
    '🎽' => 'курта барои давидан',
    '🎿' => 'лижа',
    '🛷' => 'чана',
    '🥌' => 'санги бозии кёрлинг',
    '🎯' => 'рост рафта расидан',
    '🔫' => 'таппонча',
    '🎱' => 'билярди 8 саққадор',
    '🔮' => 'кураи булӯрӣ',
    '🎮' => 'бозии видеоӣ',
    '🕹' => 'ҷойстик',
    '🎰' => 'мошинаи қиморбозӣ',
    '🎲' => 'бозии зарикҳо',
    '♠' => 'қарамашшоқ',
    '♥' => 'таппон',
    '♦' => 'хиштхол',
    '♣' => 'чилликхол',
    '🃏' => 'ҳазлбоз',
    '🀄' => 'аждаҳори сурхи маҳҷонг',
    '🎴' => 'кортҳои бозии "Гул"',
    '🎭' => 'намдуҳои санъати иҷро',
    '🖼' => 'сурати чорчӯбадор',
    '🎨' => 'лавҳачаи рассомии рассом',
    '👓' => 'айнак',
    '🕶' => 'айнаки офтобӣ',
    '👔' => 'галстук',
    '👕' => 'футболка',
    '👖' => 'ҷинс',
    '🧣' => 'шарф',
    '🧤' => 'дастпӯшак',
    '🧥' => 'палто',
    '🧦' => 'ҷуроб',
    '👗' => 'куртаи занона',
    '👘' => 'кимоно',
    '👙' => 'либоси оббозӣ',
    '👚' => 'либосҳои занона',
    '👛' => 'ҳамён',
    '👜' => 'сумка',
    '👝' => 'клатч',
    '🛍' => 'сумкаҳо барои харид кардан',
    '🎒' => 'борхалтаи мактабӣ',
    '👞' => 'пойафзоли мардона',
    '👟' => 'пойафзол барои давидан',
    '👠' => 'пойафзоли пошнабаланд',
    '👡' => 'кафши сабуки занона',
    '👢' => 'мӯзаи занона',
    '👑' => 'тоҷ',
    '👒' => 'кулоҳи занона',
    '🎩' => 'кулоҳи баланд',
    '🎓' => 'конфедератка',
    '🧢' => 'кепкаи лапардор',
    '⛑' => 'тоскулоҳи корманди наҷотдиҳӣ',
    '📿' => 'тасбеҳ',
    '💄' => 'лабсурхкунак',
    '💍' => 'ангуштарин',
    '💎' => 'санги қиматбаҳо',
    '🔇' => 'баландгӯяки хомӯш',
    '🔈' => 'садои пасти баландгӯяк',
    '🔉' => 'садои миёнаи баландгӯяк',
    '🔊' => 'садои баланди баландгӯяк',
    '📢' => 'баландгӯяк',
    '📣' => 'мегафон',
    '📯' => 'сурнаи почта',
    '🔔' => 'зангӯлача',
    '🔕' => 'зангӯлача бо хати каср',
    '🎼' => 'партитура',
    '🎵' => 'нотаи мусиқӣ',
    '🎶' => 'нотаҳои мусиқӣ',
    '🎙' => 'микрофони студия',
    '🎚' => 'василаи лағжандаи сатҳ',
    '🎛' => 'дастаҳои идора',
    '🎤' => 'микрофон',
    '🎧' => 'гӯшмонак',
    '📻' => 'радио',
    '🎷' => 'саксофон',
    '🎺' => 'карнай',
    '🎸' => 'гитар',
    '🎹' => 'клавиатураи мусиқӣ',
    '🎻' => 'ғиҷҷак',
    '🥁' => 'нақора',
    '📱' => 'телефони мобилӣ',
    '📲' => 'телефони мобилӣ бо тир',
    '☎' => 'телефон',
    '📞' => 'гӯшаки телефон',
    '📟' => 'пейҷер',
    '📠' => 'дастгоҳи факс',
    '🔋' => 'батарея',
    '🔌' => 'васлаки электрикӣ',
    '💻' => 'компютери лэптоп',
    '🖥' => 'компютери рӯимизӣ',
    '🖨' => 'принтер',
    '⌨' => 'клавиатура',
    '🖱' => 'муши компютер',
    '🖲' => 'трекбол',
    '💽' => 'диски компютер',
    '💾' => 'диски нарм',
    '💿' => 'диски оптикӣ',
    '📀' => 'dvd',
    '🎥' => 'камераи киногирӣ',
    '🎞' => 'кадрҳои навор',
    '📽' => 'проектори филм',
    '🎬' => 'нумератор',
    '📺' => 'телевизор',
    '📷' => 'камера',
    '📸' => 'камера бо дурахш',
    '📹' => 'видеокамера',
    '📼' => 'кассетаи видео',
    '🔍' => 'пурбини ба тарафи чап ишоракунанда',
    '🔎' => 'пурбини ба тарфи рост ишоракунанда',
    '🕯' => 'шамъ',
    '💡' => 'чароғак',
    '🔦' => 'фонус',
    '🏮' => 'чароғ аз қозаи сурх',
    '📔' => 'дафтар бо муқоваи ороишӣ',
    '📕' => 'китоби пӯшида',
    '📖' => 'китоби кушода',
    '📗' => 'китоби сабз',
    '📘' => 'китоби кабуд',
    '📙' => 'китоби норанҷӣ',
    '📚' => 'китобҳо',
    '📓' => 'дафтар',
    '📒' => 'дафтари бухғалтерӣ',
    '📃' => 'саҳифа бо қатшавӣ',
    '📜' => 'навори ҳаракат',
    '📄' => 'саҳифа бо рӯйгардонкунӣ',
    '📰' => 'газета',
    '🗞' => 'газетаи гардондашуда',
    '📑' => 'варақаҳои хатбарак',
    '🔖' => 'хатбарак',
    '🏷' => 'тамға',
    '💰' => 'халтаи пул',
    '💴' => 'қоғази пули йен',
    '💵' => 'қоғази пули доллар',
    '💶' => 'қоғази пули евро',
    '💷' => 'қоғази пули фунт',
    '💸' => 'пул бо қанотҳо',
    '💳' => 'корти кредитӣ',
    '💹' => 'диаграммаи афзоиш бо йен',
    '✉' => 'лифофа',
    '📧' => 'почтаи электронӣ',
    '📨' => 'лифофаи воридотӣ',
    '📩' => 'лифофа бо тир',
    '📤' => 'лавҳаи паёмдони баромад',
    '📥' => 'лавҳаи паёмдони даромад',
    '📦' => 'баста',
    '📫' => 'қуттии почтаи пӯшида бо байрақчаи бардошаташуда',
    '📪' => 'қутии почтаи пӯшида бо байрақчаи паст кардашуда',
    '📬' => 'қуттии почтаи кушода бо байрақчаи бардошаташуда',
    '📭' => 'қуттии почтаи кушода бо байрақчаи паст кардашуда',
    '📮' => 'қуттии почта',
    '🗳' => 'қуттии бюллетенҳо бо бюллетен',
    '✏' => 'қалам',
    '✒' => 'нӯги сиёҳ',
    '🖋' => 'авторучка',
    '🖊' => 'ручка',
    '🖌' => 'мӯқаллам',
    '🖍' => 'пастел',
    '📝' => 'мемо',
    '💼' => 'ҷузвгир',
    '📁' => 'ҷузвдони файлҳо',
    '📂' => 'кушодани ҷузвдони фалҳо',
    '🗂' => 'тақсимкунандаҳои индекси кортҳо',
    '📅' => 'тақвим',
    '📆' => 'тақвими дарондашаванда',
    '🗒' => 'дафтари ёддошти печдор',
    '🗓' => 'тақвими печдор',
    '📇' => 'индекси корт',
    '📈' => 'диаграммаи афзоишёбанда',
    '📉' => 'диаграммаи коҳишёбанда',
    '📊' => 'диаграммаи хаттӣ',
    '📋' => 'ҳофизаи муваққатӣ',
    '📌' => 'тугмачаи сӯзандор',
    '📍' => 'тугмачаи сӯзандори даврашакл',
    '📎' => 'бандак',
    '🖇' => 'бандаки пайвандшуда',
    '📏' => 'ҷадвали рост',
    '📐' => 'ҷадвали секунҷа',
    '✂' => 'қайчӣ',
    '🗃' => 'қуттии файли кортҳо',
    '🗄' => 'кабинети файлҳо',
    '🗑' => 'сабади партовҳо',
    '🔒' => 'қулфшуда',
    '🔓' => 'кушодашуда',
    '🔏' => 'бо қалам қулф шудааст',
    '🔐' => 'бо калид қулф шудааст',
    '🔑' => 'калид',
    '🗝' => 'калиди куҳна',
    '🔨' => 'болға',
    '⛏' => 'зоғнӯл',
    '⚒' => 'болға ва зоғнӯл',
    '🛠' => 'болға ва калиди гайкатобӣ',
    '🗡' => 'ханҷар',
    '⚔' => 'шамшерҳои ба ҳам гузошташуда',
    '💣' => 'бомба',
    '🏹' => 'камон ва тир',
    '🛡' => 'сипар',
    '🔧' => 'калиди гайкатобӣ',
    '🔩' => 'гайка ва мурват',
    '⚙' => 'чархи дандонадор',
    '🗜' => 'хамут',
    '⚖' => 'тарозу',
    '🔗' => 'пайванд',
    '⛓' => 'занҷирҳо',
    '⚗' => 'аламбик',
    '🔬' => 'микроскоп',
    '🔭' => 'телескоп',
    '📡' => 'антеннаи моҳвораӣ',
    '💉' => 'сӯзандору',
    '💊' => 'дору',
    '🚪' => 'дар',
    '🛏' => 'бистар',
    '🛋' => 'диван ва чароғ',
    '🚽' => 'ҳоҷатхона',
    '🚿' => 'душ',
    '🛁' => 'ванна',
    '🛒' => 'аробача барои харид кардан',
    '🚬' => 'сигор',
    '⚰' => 'тобут',
    '⚱' => 'устадони ҷаноза',
    '🗿' => 'моаи',
    '🏧' => 'аломати "Банкомат"',
    '🚮' => 'аломати "Партов ба қуттӣ"',
    '🚰' => 'оби нӯшокӣ',
    '♿' => 'аломати "Курсии чархдор"',
    '🚹' => 'ҳоҷатхона барои мардон',
    '🚺' => 'ҳоҷатхона барои занон',
    '🚻' => 'ташноб',
    '🚼' => 'аломати "Кӯдак"',
    '🚾' => 'мабраз',
    '🛂' => 'назорати шиносномаҳо',
    '🛃' => 'гумрук',
    '🛄' => 'гирифтани бағочҳо',
    '🛅' => 'бағочҳои боқимонда',
    '⚠' => 'огоҳӣ',
    '🚸' => 'гузариши кӯдакон',
    '⛔' => 'ворид шудан манъ аст',
    '🚫' => 'манъ аст',
    '🚳' => 'ҳаракати велосипедҳо манъ аст',
    '🚭' => 'тамоку кашидан манъ аст',
    '🚯' => 'партов партофтан манъ аст',
    '🚱' => 'оби ғайринӯшокӣ',
    '🚷' => 'ҳаракати пиёдагардон манъ аст',
    '📵' => 'истифодаи телефонҳои мобилӣ манъ аст',
    '🔞' => 'шахсони аз синни ҳаждаҳ манъ аст',
    '☢' => 'радиоактивӣ',
    '☣' => 'хатари биологӣ',
    '⬆' => 'тири "боло"',
    '↗' => 'тири болову рост',
    '➡' => 'тири рост',
    '↘' => 'тири поёну рост',
    '⬇' => 'тири поён',
    '↙' => 'тири поёну чап',
    '⬅' => 'тири чап',
    '↖' => 'тири болову чап',
    '↕' => 'тири поёну боло',
    '↔' => 'тири чапу рост',
    '↩' => 'тири рости ба тарафи чап каҷшаванда',
    '↪' => 'тири чапи ба тарафи рост каҷшаванда',
    '⤴' => 'тири рости ба тарафи боло каҷшаванда',
    '⤵' => 'тири рости ба тарафи поён каҷшаванда',
    '🔃' => 'тирҳои амудии самти ҳаракати ақрабҳои соат',
    '🔄' => 'Тугмаи "Тирҳои самти муқобили ҳаракати ақрабҳои соат"',
    '🔙' => 'тири "бозгашт"',
    '🔚' => 'тири "охир"',
    '🔛' => 'тири "фаъол!"',
    '🔜' => 'тири "ба қарибӣ"',
    '🔝' => 'тири "БОЛОЙ"',
    '🛐' => 'ҷои ибодат',
    '⚛' => 'аломати "атом"',
    '🕉' => 'ом',
    '✡' => 'ситораи Дейвид',
    '☸' => 'чархи дарма',
    '☯' => 'йин янг',
    '✝' => 'салиби лотинӣ',
    '☦' => 'салиби православӣ',
    '☪' => 'ситора ва салиб',
    '☮' => 'аломати "сулҳ"',
    '🕎' => 'менораҳ',
    '🔯' => 'ситораи холдори шашгӯша',
    '♈' => 'Ҳамал',
    '♉' => 'Савр',
    '♊' => 'Ҷавзо',
    '♋' => 'Саратон',
    '♌' => 'Асад',
    '♍' => 'Сунбула',
    '♎' => 'Мизон',
    '♏' => 'Ақраб',
    '♐' => 'Қавс',
    '♑' => 'Ҷадӣ',
    '♒' => 'Далв',
    '♓' => 'Ҳут',
    '⛎' => 'Ophiuchus',
    '🔀' => 'тугмаи "Аралаш кардани суруд"',
    '🔁' => 'тугмаи "Такрор"',
    '🔂' => 'тугмаи "Такрори ягона"',
    '▶' => 'тугмаи "пахш"',
    '⏩' => 'тугмаи "Гузариш ба пеш"',
    '⏭' => 'тугмаи "Суруди навбатӣ"',
    '⏯' => 'тугмаи "Пахш ё таваққуф"',
    '◀' => 'тугмаи "Гузариш ба қафо"',
    '⏪' => 'тугмаи "Гузариши зуд ба қафо"',
    '⏮' => 'тугмаи "Суруди охирин"',
    '🔼' => 'тугмаи "Боло"',
    '⏫' => 'тугмаи "Зуд ба боло"',
    '🔽' => 'тугмаи "Поён"',
    '⏬' => 'тугмаи "Зуд ба поён"',
    '⏸' => 'Тугмаи "Таваққуф"',
    '⏹' => 'тугмаи "Ист"',
    '⏺' => 'тугмаи "Сабт"',
    '⏏' => 'тугмаи "Баровардан"',
    '🎦' => 'кино',
    '🔅' => 'тугмаи "Камнуршавӣ"',
    '🔆' => 'тугмаи "Рӯшноӣ"',
    '📶' => 'хатҳои антенна',
    '📳' => 'реҷаи ларзиш',
    '📴' => 'хомӯш кардани телефони мобилӣ',
    '♀' => 'аломати зан',
    '♂' => 'аломати мард',
    '✖' => 'зарбзании вазнин х',
    '➕' => 'аломати вазнини ҷамъ',
    '➖' => 'аломати вазнини тарҳ',
    '➗' => 'аломати вазнини тақсим',
    '‼' => 'аломати хитоби дукарата',
    '⁉' => 'аломати хитобу савол',
    '❓' => 'аломати савол',
    '❔' => 'аломати саволи сафед',
    '❕' => 'аломати хитоби сафед',
    '❗' => 'аломати хитоб',
    '〰' => 'тиреи мавҷдор',
    '💱' => 'мубодилаи асъор',
    '💲' => 'аломати доллари вазнин',
    '⚕' => 'аломати тиббӣ',
    '♻' => 'аломати "азнавкоркардкунӣ"',
    '⚜' => 'савсан',
    '🔱' => 'нишони Соскан',
    '📛' => 'нишонаи ном',
    '🔰' => 'аломати ҷопонӣ барои навомӯз',
    '⭕' => 'давраи калони вазнин',
    '✅' => 'аломати вазнини қайди сафед',
    '☑' => 'қуттии бюллетенҳо бо қайд',
    '✔' => 'аломати вазнини қайд',
    '❌' => 'аломати салиб',
    '❎' => 'тугмаи "Аломати салиб"',
    '➰' => 'ҳалқаи пурпечутоб',
    '➿' => 'ҳалқаи дутарафа пурпечутоб',
    '〽' => 'аломати тағйирёбии қисм',
    '✳' => 'ситорачаи ҳашт паррадор',
    '✴' => 'ситораи ҳашт нӯгдор',
    '❇' => 'ялаққос задан',
    '™' => 'тамғаи савдо',
    '🔠' => 'ҳарфҳои калони вуруди лотинӣ',
    '🔡' => 'ҳарфҳои хурди вуруди лотинӣ',
    '🔢' => 'рақамҳои вуруд',
    '🔣' => 'аломатҳои вуруд',
    '🔤' => 'ҳарфҳои вуруди лотинӣ',
    '🅰' => 'тугмаи "А" (гуруҳи хун)',
    '🆎' => 'тугмаи "АВ" (гуруҳи хун)',
    '🅱' => 'тугмаи "В" (гуруҳи хун)',
    '🆑' => 'тугмаи "CL"',
    '🆒' => 'тугмаи "ЗӮР"',
    '🆓' => 'тугмаи "ОЗОД"',
    'ℹ' => 'маълумот',
    '🆔' => 'тугмаи "ID"',
    'Ⓜ' => 'М бо давра қайд шуд',
    '🆕' => 'тугмаи "НАВ"',
    '🆖' => 'тугмаи "NG"',
    '🅾' => 'тугмаи "О" (гуруҳи хун)',
    '🆗' => 'тугмаи "OK"',
    '🅿' => 'тугмаи "P"',
    '🆘' => 'тугмаи "SOS"',
    '🆚' => 'тугмаи "VS"',
    '🈁' => 'тугмаи "инҷо"-и ҷопонӣ',
    '🈂' => 'тугмаи "Маблағи хизматрасонӣ"-и ҷопонӣ',
    '🈷' => 'тугмаи "арзиши моҳона"-и ҷопонӣ',
    '🈶' => 'тугмаи "Ройгон нест"-и ҷопонӣ',
    '🈯' => 'тугмаи "нигоҳ дошташуда"-и ҷопонӣ',
    '🉐' => 'тугмаи "Хариду фурӯш"-и ҷопонӣ',
    '🈹' => 'тугмаи "Тахфиф"-и ҷопонӣ',
    '🈚' => 'тугмаи "Ройгон"-и ҷопонӣ',
    '🈲' => 'тугмаи "манъ аст"-и ҷопонӣ',
    '🉑' => 'тугмаи "Қобили қабул"-и ҷопонӣ',
    '🈸' => 'тугмаи "барномаи"-и ҷопонӣ',
    '🈴' => 'тугмаи "Баҳои гузариш"-и ҷопонӣ',
    '🈳' => 'тугмаи "Ҷои кори холӣ"-и ҷопонӣ',
    '㊗' => 'тугмаи "Табрик"-и ҷопонӣ',
    '㊙' => 'тугмаи "Махфӣ"-и ҷопонӣ',
    '🈺' => 'тугмаи "Барои тиҷорат кушода аст"-и ҷопонӣ',
    '🈵' => 'тугмаи "Ҷои кори холӣ нест"-и ҷопонӣ',
    '🔴' => 'доираи сурх',
    '🔵' => 'доираи кабуд',
    '⚫' => 'доираи сиёҳ',
    '⚪' => 'доираи сафед',
    '⬛' => 'чоркунҷаи калони сиёҳ',
    '⬜' => 'чоркунҷаи калони сафед',
    '◼' => 'чоркунҷаи миёнаи сиёҳ',
    '◻' => 'чоркунҷаи миёнаи сафед',
    '◾' => 'чоркунҷаи хурди миёнаи сиёҳ',
    '◽' => 'чоркунҷаи хурди миёнаи сафед',
    '▪' => 'чоркунҷаи хурди сиёҳ',
    '▫' => 'чоркунҷаи хурди сафед',
    '🔶' => 'алмоси калони норинҷӣ',
    '🔷' => 'алмоси калони кабуд',
    '🔸' => 'алмоси хурди норинҷӣ',
    '🔹' => 'алмоси хурди кабуд',
    '🔺' => 'секунҷаи сурхи ба боло равонашуда',
    '🔻' => 'секунҷаи сурхи ба поён равонашуда',
    '💠' => 'алмос бо як нуқта',
    '🔘' => 'тугмаи "Радио"',
    '🔳' => 'тугмаи "Чоркунҷаи сафед"',
    '🔲' => 'тугмаи "Чоркунҷаи сиёҳ"',
    '🏁' => 'байрақи чорхона',
    '🚩' => 'байрақи секунҷа',
    '🎌' => 'байрақҳои чиллик гузошташуда',
    '🏴' => 'байрақи сиёҳ',
    '🏳' => 'байрақи сафед',
];
